<?php

$LANG = array(
    'organization' => 'Empresa',
    'name' => 'Nombre',
    'website' => 'Página Web',
    'work_phone' => 'Teléfono',
    'address' => 'Dirección',
    'address1' => 'Calle',
    'address2' => 'Bloq/Pta',
    'city' => 'Ciudad',
    'state' => 'Provincia',
    'postal_code' => 'Código Postal',
    'country_id' => 'País',
    'contacts' => 'Contactos',
    'first_name' => 'Nombre',
    'last_name' => 'Apellidos',
    'phone' => 'Teléfono',
    'email' => 'Email',
    'additional_info' => 'Información Adicional',
    'payment_terms' => 'Términos de Pago',
    'currency_id' => 'Divisa',
    'size_id' => 'Tamaño',
    'industry_id' => 'Sector',
    'private_notes' => 'Notas Privadas',
    'invoice' => 'Factura',
    'client' => 'Cliente',
    'invoice_date' => 'Fecha de Factura',
    'due_date' => 'Vencimiento',
    'invoice_number' => 'Número de Factura',
    'invoice_number_short' => 'Factura Nº',
    'po_number' => 'Número de Pedido',
    'po_number_short' => 'Nº Pedido',
    'frequency_id' => 'Frecuencia',
    'discount' => 'Descuento',
    'taxes' => 'Impuestos',
    'tax' => 'Impuesto',
    'item' => 'Concepto',
    'description' => 'Descripción',
    'unit_cost' => 'Precio Unitario',
    'quantity' => 'Cantidad',
    'line_total' => 'Total',
    'subtotal' => 'Subtotal',
    'paid_to_date' => 'Pagado',
    'balance_due' => 'Pendiente',
    'invoice_design_id' => 'Diseño',
    'terms' => 'Términos',
    'your_invoice' => 'Tu Factura',
    'remove_contact' => 'Eliminar Contacto',
    'add_contact' => 'Añadir Contacto',
    'create_new_client' => 'Crear Nuevo Cliente',
    'edit_client_details' => 'Editar Detalles del Cliente',
    'enable' => 'Activar',
    'learn_more' => 'Saber más',
    'manage_rates' => 'Administrar Tarifas',
    'note_to_client' => 'Nota para el Cliente',
    'invoice_terms' => 'Términos de Facturación',
    'save_as_default_terms' => 'Guardar como Términos Predefinidos',
    'download_pdf' => 'Descargar PDF',
    'pay_now' => 'Pagar Ahora',
    'save_invoice' => 'Guardar Factura',
    'clone_invoice' => 'Clonar Factura',
    'archive_invoice' => 'Archivar Factura',
    'delete_invoice' => 'Eliminar Factura',
    'email_invoice' => 'Enviar Factura por EMail',
    'enter_payment' => 'Agregar Pago',
    'tax_rates' => 'Impuestos',
    'rate' => 'Precio',
    'settings' => 'Configuración',
    'enable_invoice_tax' => 'Activar la selección de un Impuesto para el <b>Total de la Factura</b>',
    'enable_line_item_tax' => 'Activar la selección de un Impuesto <b>por Línea de Factura</b>',
    'dashboard' => 'Inicio',
    'dashboard_totals_in_all_currencies_help' => 'Nota: añade un :link llamado ":name" para mostrar los totales usando una única divisa base.',
    'clients' => 'Clientes',
    'invoices' => 'Facturas',
    'payments' => 'Pagos',
    'credits' => 'Créditos',
    'history' => 'Historial',
    'search' => 'Búsqueda',
    'sign_up' => 'Registrarse',
    'guest' => 'Invitado',
    'company_details' => 'Detalles de la Empresa',
    'online_payments' => 'Pagos Online',
    'notifications' => 'Notificaciones',
    'import_export' => 'Importar/Exportar',
    'done' => 'Hecho',
    'save' => 'Guardar',
    'create' => 'Crear',
    'upload' => 'Subir',
    'import' => 'Importar',
    'download' => 'Descargar',
    'cancel' => 'Cancelar',
    'close' => 'Cerrar',
    'provide_email' => 'Por favor indica una dirección de correo electrónico válida.',
    'powered_by' => 'Creado por',
    'no_items' => 'No hay Conceptos',
    'recurring_invoices' => 'Facturas Recurrentes',
    'recurring_help' => '<p>Enviar Facturas automáticamente a clientes semanalmente, bi-mensualmente, mensualmente, trimestral o anualmente. </p>
    <p>Usando :MONTH, :QUARTER or :YEAR para fechas dinámicas. Y utilizando tambien Matemáticas básicas. Por ejemplo: :MONTH-1.</p>
    <p>Ejemplos de Variables Dinámicas de Factura:</p>
    <ul>
    <li>"Mensualidad del gimnasio para el mes de :MONTH" >> Mensualidad del gimnasio para el mes de Julio"</li>
    <li>":YEAR+1 suscripción anual" >> "2015 suscripción anual"</li>
    <li>"Pago retenido para :QUARTER+1" >> "Pago retenido para T2"</li>
    </ul>',
    'recurring_quotes' => 'Presupuestos Recurrentes',
    'in_total_revenue' => 'Ingreso Total',
    'billed_client' => 'Cliente Facturado',
    'billed_clients' => 'Clientes Facturados',
    'active_client' => 'Cliente Activo',
    'active_clients' => 'Clientes Activos',
    'invoices_past_due' => 'Facturas Vencidas',
    'upcoming_invoices' => 'Próximas Facturas',
    'average_invoice' => 'Promedio de Facturación',
    'archive' => 'Archivar',
    'delete' => 'Eliminar',
    'archive_client' => 'Archivar Cliente',
    'delete_client' => 'Eliminar Cliente',
    'archive_payment' => 'Archivar Pago',
    'delete_payment' => 'Eliminar Pago',
    'archive_credit' => 'Archivar Crédito',
    'delete_credit' => 'Eliminar Crédito',
    'show_archived_deleted' => 'Mostrar archivados/eliminados',
    'filter' => 'Filtrar',
    'new_client' => 'Nuevo Cliente',
    'new_invoice' => 'Nueva Factura',
    'new_payment' => 'Introduzca el Pago',
    'new_credit' => 'Introducir el Crédito',
    'contact' => 'Contacto',
    'date_created' => 'Fecha de Creación',
    'last_login' => 'Último Acceso',
    'balance' => 'Saldo',
    'action' => 'Acción',
    'status' => 'Estado',
    'invoice_total' => 'Total Facturado',
    'frequency' => 'Frecuencia',
    'range' => 'Rango',
    'start_date' => 'Fecha de Inicio',
    'end_date' => 'Fecha de Fin',
    'transaction_reference' => 'Referencia de Transacción',
    'method' => 'Método',
    'payment_amount' => 'Valor del Pago',
    'payment_date' => 'Fecha de Pago',
    'credit_amount' => 'Cantidad de Crédito',
    'credit_balance' => 'Saldo de Crédito',
    'credit_date' => 'Fecha de Crédito',
    'empty_table' => 'Tabla vacía',
    'select' => 'Seleccionar',
    'edit_client' => 'Editar Cliente',
    'edit_invoice' => 'Editar Factura',
    'create_invoice' => 'Crear Factura',
    'enter_credit' => 'Agregar Crédito',
    'last_logged_in' => 'Último inicio de sesión',
    'details' => 'Detalles',
    'standing' => 'Situación',
    'credit' => 'Crédito',
    'activity' => 'Actividad',
    'date' => 'Fecha',
    'message' => 'Mensaje',
    'adjustment' => 'Ajustes',
    'are_you_sure' => '¿Está Seguro?',
    'payment_type_id' => 'Tipo de Pago',
    'amount' => 'Cantidad',
    'work_email' => 'Correo electrónico de la empresa',
    'language_id' => 'Idioma',
    'timezone_id' => 'Zona horaria',
    'date_format_id' => 'Formato de fecha',
    'datetime_format_id' => 'Formato de fecha/hora',
    'users' => 'Usuarios',
    'localization' => 'Localización',
    'remove_logo' => 'Eliminar logo',
    'logo_help' => 'Formatos aceptados: JPEG, GIF y PNG',
    'payment_gateway' => 'Pasarela de Pago',
    'gateway_id' => 'Proveedor',
    'email_notifications' => 'Notificaciones de correo',
    'email_sent' => 'Avísame por correo cuando una Factura <b>se envía</b>',
    'email_viewed' => 'Avísame por correo cuando una Factura <b>se visualiza</b>',
    'email_paid' => 'Avísame por correo cuando una Factura <b>se paga</b>',
    'site_updates' => 'Actualizaciones del sitio',
    'custom_messages' => 'Mensajes Personalizados',
    'default_email_footer' => 'Configurar <b>firma de email</b> por defecto',
    'select_file' => 'Seleccionar archivo',
    'first_row_headers' => 'Usar la primera fila como encabezados',
    'column' => 'Columna',
    'sample' => 'Ejemplo',
    'import_to' => 'Importar a',
    'client_will_create' => 'cliente se creará',
    'clients_will_create' => 'clientes se crearan',
    'email_settings' => 'Configuración del Correo Electrónico',
    'client_view_styling' => 'Estilo de visualización para el cliente',
    'pdf_email_attachment' => 'Adjuntar PDF',
    'custom_css' => 'CSS personalizado',
    'import_clients' => 'Importar Clientes',
    'csv_file' => 'Seleccionar archivo CSV',
    'export_clients' => 'Exportar Clientes',
    'created_client' => 'Cliente creado correctamente',
    'created_clients' => ':count cliente(s) creado(s) correctamente',
    'updated_settings' => 'Configuración actualizada correctamente',
    'removed_logo' => 'Logo eliminado correctamente',
    'sent_message' => 'Mensaje enviado correctamente',
    'invoice_error' => 'Seleccionar cliente y corregir errores.',
    'limit_clients' => 'Lo sentimos, se ha pasado del límite de :count clientes',
    'payment_error' => 'Ha habido un error en el proceso de tu Pago. Inténtalo de nuevo más tarde.',
    'registration_required' => 'Inscríbete para enviar una factura',
    'confirmation_required' => 'Por favor, confirma tu dirección de correo electrónico, :link para reenviar el email de confirmación.',
    'updated_client' => 'Cliente actualizado correctamente',
    'archived_client' => 'Cliente archivado correctamente',
    'archived_clients' => ':count clientes archivados correctamente',
    'deleted_client' => 'Cliente eliminado correctamente',
    'deleted_clients' => ':count clientes eliminados correctamente',
    'updated_invoice' => 'Factura actualizada correctamente',
    'created_invoice' => 'Factura creada correctamente',
    'cloned_invoice' => 'Factura clonada correctamente',
    'emailed_invoice' => 'Factura enviada correctamente',
    'and_created_client' => 'y cliente creado ',
    'archived_invoice' => 'Factura archivada correctamente',
    'archived_invoices' => ':count facturas archivadas correctamente',
    'deleted_invoice' => 'Factura eliminada correctamente',
    'deleted_invoices' => ':count facturas eliminadas correctamente',
    'created_payment' => 'Pago creado correctamente',
    'created_payments' => ':count pago(s) creado(s) correctamente.',
    'archived_payment' => 'Pago archivado correctamente',
    'archived_payments' => ':count pagos archivados correctamente',
    'deleted_payment' => 'Pago eliminado correctamente',
    'deleted_payments' => ':count pagos eliminados correctamente',
    'applied_payment' => 'Pago aplicado correctamente',
    'created_credit' => 'Crédito creado correctamente',
    'archived_credit' => 'Crédito archivado correctamente',
    'archived_credits' => ':count créditos archivados correctamente',
    'deleted_credit' => 'Créditos eliminados correctamente',
    'deleted_credits' => ':count créditos eliminados correctamente',
    'imported_file' => 'Fichero importado correctamente',
    'updated_vendor' => 'Proveedor actualizado correctamente',
    'created_vendor' => 'Proveedor creado correctamente',
    'archived_vendor' => 'Proveedor archivado correctamente',
    'archived_vendors' => ':count proveedores actualizados correctamente',
    'deleted_vendor' => 'Proveedor eliminado correctamente',
    'deleted_vendors' => ':count proveedores actualizados correctamente',
    'confirmation_subject' => 'Corfimación de tu cuenta en el sistema',
    'confirmation_header' => 'Confirmación de Cuenta',
    'confirmation_message' => 'Por favor, haz clic en el enlace de abajo para confirmar tu cuenta.',
    'invoice_subject' => 'Nueva factura Nº :number de :account',
    'invoice_message' => 'Para visualizar tu factura por el valor de :amount, haz click en el enlace de abajo.',
    'payment_subject' => 'Pago recibido',
    'payment_message' => 'Gracias por su pago de :amount.',
    'email_salutation' => 'Estimado :name,',
    'email_signature' => 'Un cordial saludo,',
    'email_from' => 'El equipo de Invoice Ninja ',
    'invoice_link_message' => 'Para visualizar la factura de cliente, haz clic en el enlace de abajo:',
    'notification_invoice_paid_subject' => 'La Factura :invoice ha sido pagada por el cliente :client',
    'notification_invoice_sent_subject' => 'La Factura :invoice ha sido enviada al cliente :client',
    'notification_invoice_viewed_subject' => 'La Factura :invoice ha sido visualizada por el cliente :client',
    'notification_invoice_paid' => 'Un Pago por importe de :amount ha sido realizado por el cliente :client correspondiente a la Factura :invoice.',
    'notification_invoice_sent' => 'La Factura :invoice por importe de :amount fue enviada al cliente :client.',
    'notification_invoice_viewed' => 'La Factura :invoice por importe de :amount fue visualizada por el cliente :client.',
    'reset_password' => 'Puedes reconfigurar la contraseña de tu cuenta haciendo clic en el siguiente enlace:',
    'secure_payment' => 'Pago seguro',
    'card_number' => 'Número de tarjeta',
    'expiration_month' => 'Mes de caducidad',
    'expiration_year' => 'Año de caducidad',
    'cvv' => 'CVV',
    'logout' => 'Cerrar sesión',
    'sign_up_to_save' => 'Registrate para guardar tu trabajo',
    'agree_to_terms' => 'Estoy de acuerdo con los :terms',
    'terms_of_service' => 'Términos de servicio',
    'email_taken' => 'Esta dirección de correo electrónico ya se ha registrado',
    'working' => 'Procesando',
    'success' => 'Éxito',
    'success_message' => 'Te has registrado con éxito. Por favor, haz clic en el enlace del correo de confirmación para verificar tu dirección de correo electrónico.',
    'erase_data' => 'Borrar datos',
    'password' => 'Contraseña',
    'pro_plan_product' => 'Plan Pro',
    'pro_plan_success' => '¡Gracias por unirte a Invoice Ninja! Al realizar el Pago de tu Factura, se iniciara tu PLAN PRO.',
    'unsaved_changes' => 'Tienes cambios no guardados',
    'custom_fields' => 'Campos Personalizados',
    'company_fields' => 'Campos de la empresa',
    'client_fields' => 'Campos del cliente',
    'field_label' => 'Etiqueta del campo',
    'field_value' => 'Valor del campo',
    'edit' => 'Editar',
    'set_name' => 'Indica el nombre de tu Empresa',
    'view_as_recipient' => 'Ver como Destinatario',
    'product_library' => 'Listado de Productos',
    'product' => 'Producto',
    'products' => 'Productos',
    'fill_products' => 'Auto-rellenar Productos',
    'fill_products_help' => 'Seleccionar un producto automáticamente <b>configurará la descripción y coste</b>',
    'update_products' => 'Auto-actualizar Productos',
    'update_products_help' => 'Actualizar una Factura automáticamente <b>actualizará los Productos</b>',
    'create_product' => 'Crear Producto',
    'edit_product' => 'Editar Producto',
    'archive_product' => 'Archivar Producto',
    'updated_product' => 'Producto actualizado correctamente',
    'created_product' => 'Producto creado correctamente',
    'archived_product' => 'Producto archivado correctamente',
    'pro_plan_custom_fields' => ':link haz click para para activar campos a medida',
    'advanced_settings' => 'Configuración Avanzada',
    'pro_plan_advanced_settings' => ':link haz click para para activar la configuración avanzada',
    'invoice_design' => 'Diseño de Factura',
    'specify_colors' => 'Especificar colores',
    'specify_colors_label' => 'Seleccionar los colores para usar en las Facturas',
    'chart_builder' => 'Constructor de Gráficas',
    'ninja_email_footer' => 'Creado por :site | Crea. Envia. Recibe tus Pagos.',
    'go_pro' => 'Hazte Pro',
    'quote' => 'Presupuesto',
    'quotes' => 'Presupuestos',
    'quote_number' => 'Número de Presupuesto',
    'quote_number_short' => 'Presupuesto Nº ',
    'quote_date' => 'Fecha Presupuesto',
    'quote_total' => 'Total Presupuestado',
    'your_quote' => 'Su Presupuesto',
    'total' => 'Total',
    'clone' => 'Clonar',
    'new_quote' => 'Nuevo Presupuesto',
    'create_quote' => 'Crear Presupuesto',
    'edit_quote' => 'Editar Presupuesto',
    'archive_quote' => 'Archivar Presupuesto',
    'delete_quote' => 'Eliminar Presupuesto',
    'save_quote' => 'Guardar Presupuesto',
    'email_quote' => 'Enviar Presupuesto',
    'clone_quote' => 'Clonar Presupuesto',
    'convert_to_invoice' => 'Convertir a Factura',
    'view_invoice' => 'Ver Factura',
    'view_client' => 'Ver Cliente',
    'view_quote' => 'Ver Presupuesto',
    'updated_quote' => 'Presupuesto actualizado correctamente',
    'created_quote' => 'Presupuesto creado correctamente',
    'cloned_quote' => 'Presupuesto clonado correctamente',
    'emailed_quote' => 'Presupuesto enviado correctamente',
    'archived_quote' => 'Presupuesto archivado correctamente',
    'archived_quotes' => ':count Presupuestos archivados correctamente',
    'deleted_quote' => 'Presupuesto eliminado correctamente',
    'deleted_quotes' => ':count Presupuestos eliminados correctamente',
    'converted_to_invoice' => 'Presupuesto convertido a factura correctamente',
    'quote_subject' => 'Nuevo presupuesto :number de :account',
    'quote_message' => 'Para ver el presupuesto por un importe de :amount, haga click en el enlace de abajo.',
    'quote_link_message' => 'Para ver su presupuesto haga click en el enlace de abajo:',
    'notification_quote_sent_subject' => 'El presupuesto :invoice se ha enviado al cliente :client',
    'notification_quote_viewed_subject' => 'El presupuesto :invoice fue visto por el cliente :client',
    'notification_quote_sent' => 'El presupuesto :invoice por un valor de :amount, ha sido enviado al cliente :client.',
    'notification_quote_viewed' => 'El presupuesto :invoice por un valor de :amount ha sido visto por el cliente :client.',
    'session_expired' => 'Su Sesión ha Caducado.',
    'invoice_fields' => 'Campos de Factura',
    'invoice_options' => 'Opciones de Factura',
    'hide_paid_to_date' => 'Ocultar el valor <i>Pagado a la Fecha</i>',
    'hide_paid_to_date_help' => 'Solo mostrará el valor <i>Pagado a la Fecha</i> en sus Facturas cuando se ha recibido un Pago.',
    'charge_taxes' => 'Cargar Impuestos',
    'user_management' => 'Administración de Usuarios',
    'add_user' => 'Añadir Usuario',
    'send_invite' => 'Enviar Invitación',
    'sent_invite' => 'Invitación enviada correctamente',
    'updated_user' => 'Usario actualizado correctamente',
    'invitation_message' => ':invitor te ha invitado a unirte a su cuenta en Invoice Ninja.',
    'register_to_add_user' => 'Regístrate para añadir usarios',
    'user_state' => 'Estado',
    'edit_user' => 'Editar Usario',
    'delete_user' => 'Eliminar Usario',
    'active' => 'Activo',
    'pending' => 'Pendiente',
    'deleted_user' => 'Usario eliminado correctamente',
    'confirm_email_invoice' => '¿Estás seguro que quieres enviar esta Factura?',
    'confirm_email_quote' => '¿Estás seguro que quieres enviar este presupuesto?',
    'confirm_recurring_email_invoice' => 'Se ha marcado esta Factura como recurrente, estás seguro que quieres enviar esta Factura?',
    'confirm_recurring_email_invoice_not_sent' => '¿Estás seguro de que quieres comenzar la recurrencia?',
    'cancel_account' => 'Cancelar Cuenta',
    'cancel_account_message' => 'Atención: Esta acción eliminará permanentemente tu cuenta y no se podrá deshacer.',
    'go_back' => 'Atrás',
    'data_visualizations' => 'Visualización de Datos',
    'sample_data' => 'Datos de Ejemplo',
    'hide' => 'Ocultar',
    'new_version_available' => 'Una nueva versión de :releases_link disponible. Estás utilizando la versión :user_version, la última versión es :latest_version',
    'invoice_settings' => 'Configuración de Facturas',
    'invoice_number_prefix' => 'Prefijo del Número de Factura',
    'invoice_number_counter' => 'Contador del Número de Factura',
    'quote_number_prefix' => 'Prefijo del Número de Presupuesto',
    'quote_number_counter' => 'Contador del Número de Presupuesto',
    'share_invoice_counter' => 'Compartir la numeración para presupuesto y factura',
    'invoice_issued_to' => 'Factura emitida a',
    'invalid_counter' => 'Para evitar posibles conflictos, por favor crea un prefijo para el número de factura y para el número de presupuesto.',
    'mark_sent' => 'Marcar como Enviado',
    'gateway_help_1' => ':link para registrarse en Authorize.net.',
    'gateway_help_2' => ':link para registrarse en Authorize.net.',
    'gateway_help_17' => ':link para obtener su firma API de PayPal.',
    'gateway_help_27' => ':link para registrarse en 2Checkout.com. Para asegurar que los Pagos son monitorizados, establezca :complete_link como redireccion de URL en Account > Site Management en el portal de 2Checkout.',
    'gateway_help_60' => ':link para crear una cuenta de WePay',
    'more_designs' => 'Más diseños',
    'more_designs_title' => 'Diseños Adicionales de Facturas',
    'more_designs_cloud_header' => 'Cambia a Pro para añadir más Diseños de Facturas',
    'more_designs_cloud_text' => '',
    'more_designs_self_host_text' => '',
    'buy' => 'Comprar',
    'bought_designs' => 'Los diseños adicionales de facturas se han añadido correctamente',
    'sent' => 'Enviada',
    'vat_number' => 'NIF/CIF',
    'timesheets' => 'Parte de Horas',
    'payment_title' => 'Introduzca su dirección de Facturación y los datos de su Tarjeta de Crédito',
    'payment_cvv' => '*Este es el número de 3-4 dígitos en la parte trasera de tu tarjeta',
    'payment_footer1' => '* La dirección de Facturación debe coincidir con la de la Tarjeta de Crédito.',
    'payment_footer2' => '* Por favor, haga clic en "Pagar ahora" sólo una vez - esta operación puede tardar hasta un minuto en procesarse.',
    'id_number' => 'Nº de identificación',
    'white_label_link' => 'Marca Blanca',
    'white_label_header' => 'Marca Blanca',
    'bought_white_label' => 'Licencia de Marca Blanca habilitada correctamente',
    'white_labeled' => 'Marca Blanca',
    'restore' => 'Restaurar',
    'restore_invoice' => 'Restaurar Factura',
    'restore_quote' => 'Restaurar Presupuesto',
    'restore_client' => 'Restaurar Cliente',
    'restore_credit' => 'Restaurar Pendiente',
    'restore_payment' => 'Restaurar Pago',
    'restored_invoice' => 'Factura restaurada correctamente',
    'restored_quote' => 'Presupuesto restaurada correctamente',
    'restored_client' => 'Cliente restaurada correctamente',
    'restored_payment' => 'Pago restaurado correctamente',
    'restored_credit' => 'Crédito restaurado correctamente',
    'reason_for_canceling' => 'Ayúdanos a mejorar nuestro sitio diciéndonos porque se va.',
    'discount_percent' => 'Porcentaje',
    'discount_amount' => 'Cantidad',
    'invoice_history' => 'Historial de Facturas',
    'quote_history' => 'Historial de Presupuestos',
    'current_version' => 'Versión Actual',
    'select_version' => 'Seleccione la Versión',
    'view_history' => 'Ver Historial',
    'edit_payment' => 'Editar Pago',
    'updated_payment' => 'Pago actualizado correctamente',
    'deleted' => 'Eliminado',
    'restore_user' => 'Restaurar Usuario',
    'restored_user' => 'Usuario restaurado correctamente',
    'show_deleted_users' => 'Mostrar usuarios eliminados',
    'email_templates' => 'Plantillas de Email',
    'invoice_email' => 'Email de Facturas',
    'payment_email' => 'Email de Pagos',
    'quote_email' => 'Email de Presupuestos',
    'reset_all' => 'Restablecer Todos',
    'approve' => 'Aprobar',
    'token_billing_type_id' => 'Token de Facturación',
    'token_billing_help' => 'Almacena los detalles de Pagos con WePay, Stripe, Braintree o GoCardless.',
    'token_billing_1' => 'Deshabilitar',
    'token_billing_2' => 'La casilla <i>Opt-In</i> se muestra pero no está seleccionada',
    'token_billing_3' => 'La casilla <i>Opt-Out</i> se muestra y se selecciona',
    'token_billing_4' => 'Siempre',
    'token_billing_checkbox' => 'Almacenar datos de la Tarjeta de Crédito',
    'view_in_gateway' => 'Ver en :gateway',
    'use_card_on_file' => 'Usar tarjeta en fichero',
    'edit_payment_details' => 'Editar detalles de Pago',
    'token_billing' => 'Guardar datos de la tarjeta',
    'token_billing_secure' => 'Los datos serán almacenados de forma segura por :link',
    'support' => 'Soporte',
    'contact_information' => 'Información de Contacto',
    '256_encryption' => 'Encriptación de 256-Bit',
    'amount_due' => 'Importe a pagar',
    'billing_address' => 'Dirección de Facturación',
    'billing_method' => 'Método de Facturación',
    'order_overview' => 'Resumen de Pedidos',
    'match_address' => '* La Dirección de Facturación debe coincidir con la dirección asociada a la Tarjeta de Crédito.',
    'click_once' => '* Por favor, haga clic en "Pagar ahora" sólo una vez - la operación puede tardar hasta un minuto en ser procesada.',
    'invoice_footer' => 'Pie de Página de la Factura',
    'save_as_default_footer' => 'Guardar como Pie de Página predefinido',
    'token_management' => 'Administración de Tokens',
    'tokens' => 'Tokens',
    'add_token' => 'Agregar Token',
    'show_deleted_tokens' => 'Mostrar tokens eliminados',
    'deleted_token' => 'Token eliminado correctamente',
    'created_token' => 'Token creado correctamente',
    'updated_token' => 'Token actualizado correctamente',
    'edit_token' => 'Editar Token',
    'delete_token' => 'Eliminar Token',
    'token' => 'Token',
    'add_gateway' => 'Agregar Pasarela',
    'delete_gateway' => 'Eliminar Pasarela',
    'edit_gateway' => 'Editar Pasarela',
    'updated_gateway' => 'Pasarela actualizada correctamente',
    'created_gateway' => 'Pasarela creada correctamente',
    'deleted_gateway' => 'Pasarela eliminada correctamente',
    'pay_with_paypal' => 'PayPal',
    'pay_with_card' => 'Tarjeta de Crédito',
    'change_password' => 'Cambiar Contraseña',
    'current_password' => 'Contraseña Actual',
    'new_password' => 'Nueva Contraseña',
    'confirm_password' => 'Confirmar Contraseña',
    'password_error_incorrect' => 'La Contraseña actual es incorrecta.',
    'password_error_invalid' => 'La nueva Contraseña no es válida.',
    'updated_password' => 'Contraseña actualizada correctamente',
    'api_tokens' => 'API Tokens',
    'users_and_tokens' => 'Usuarios & Tokens',
    'account_login' => 'Inicio de Sesión con su Cuenta',
    'recover_password' => 'Recuperar Contraseña',
    'forgot_password' => '¿Olvidó su Contraseña?',
    'email_address' => 'Dirección de Email',
    'lets_go' => 'Acceder',
    'password_recovery' => 'Recuperar Contraseña',
    'send_email' => 'Enviar Email',
    'set_password' => 'Establecer Contraseña',
    'converted' => 'Modificada',
    'email_approved' => 'Avísame por correo cuando un presupuesto sea <b>Aprobado</b>',
    'notification_quote_approved_subject' => 'El presupuesto :invoice fue Aprobado por :client',
    'notification_quote_approved' => 'El cliente :client aprobó el presupuesto :invoice por :amount.',
    'resend_confirmation' => 'Reenviar correo de Confirmacion',
    'confirmation_resent' => 'El correo de confirmación fué reenviado',
    'gateway_help_42' => ':link para registrarse en BitPay.<br/>Nota: Use una Legacy API Key, no un API token.',
    'payment_type_credit_card' => 'Tarjeta de Crédito',
    'payment_type_paypal' => 'PayPal',
    'payment_type_bitcoin' => 'Bitcoin',
    'payment_type_gocardless' => 'GoCardless',
    'knowledge_base' => 'Ayuda',
    'partial' => 'Parcial/Depósito',
    'partial_remaining' => ':partial de :balance',
    'more_fields' => 'Mas Campos',
    'less_fields' => 'Menos Campos',
    'client_name' => 'Nombre del Cliente',
    'pdf_settings' => 'Configuración del PDF',
    'product_settings' => 'Configuración de Producto',
    'auto_wrap' => 'Auto ajuste de línea',
    'duplicate_post' => 'Atencion: la pagina anterior se ha enviado dos veces. El segundo envío será ignorado.',
    'view_documentation' => 'Ver Documentación',
    'app_title' => 'Facturación Open-Source gratuita',
    'app_description' => 'Invoice Ninja es una solución open-source gratuita para manejar la facturación de tus clientes. Con Invoice Ninja, se pueden crear y enviar hermosas facturas desde cualquier dispositivo que tenga acceso a Internet. Tus clientes pueden imprimir tus facturas, descargarlas en formato PDF o inclusive pagarlas en linea desde esta misma plataforma.',
    'rows' => 'filas',
    'www' => 'www',
    'logo' => 'Logo',
    'subdomain' => 'Subdominio',
    'provide_name_or_email' => 'Por favor introduzca su nombre o email',
    'charts_and_reports' => 'Gráficas e Informes',
    'chart' => 'Gráfica',
    'report' => 'Informe',
    'group_by' => 'Agrupar por',
    'paid' => 'Pagado',
    'enable_report' => 'Informe',
    'enable_chart' => 'Gráfico',
    'totals' => 'Totales',
    'run' => 'Ejecutar',
    'export' => 'Exportar',
    'documentation' => 'Documentación',
    'zapier' => 'Zapier',
    'recurring' => 'Facturas Recurrentes',
    'last_invoice_sent' => 'Última factura enviada el :date',
    'processed_updates' => 'Actualización correcta',
    'tasks' => 'Tareas',
    'new_task' => 'Nueva tarea',
    'start_time' => 'Hora de Inicio',
    'created_task' => 'Tarea creada correctamente',
    'updated_task' => 'Tarea actualizada correctamente',
    'edit_task' => 'Editar Tarea',
    'clone_task' => 'Clonar tarea',
    'archive_task' => 'Archivar Tarea',
    'restore_task' => 'Restaurar Tarea',
    'delete_task' => 'Borrar Tarea',
    'stop_task' => 'Parar Tarea',
    'time' => 'Hora',
    'start' => 'Iniciar',
    'stop' => 'Parar',
    'now' => 'Ahora',
    'timer' => 'Temporizador',
    'manual' => 'Manual',
    'date_and_time' => 'Día y hora',
    'second' => 'segundo',
    'seconds' => 'segundos',
    'minute' => 'minuto',
    'minutes' => 'Minutos',
    'hour' => 'hora',
    'hours' => 'horas',
    'task_details' => 'Detalles de Tarea',
    'duration' => 'Duración',
    'time_log' => 'Registro Temporal',
    'end_time' => 'Hora de Fin',
    'end' => 'Fin',
    'invoiced' => 'Facturado',
    'logged' => 'Registrado',
    'running' => 'Ejecutando',
    'task_error_multiple_clients' => 'Las tareas no pueden pertenecer a diferentes clientes',
    'task_error_running' => 'Por favor, primero para las tareas que se estén ejecutandose.',
    'task_error_invoiced' => 'Las tareas ya se han Facturado',
    'restored_task' => 'Tarea restaurada correctamente',
    'archived_task' => 'Tarea archivada correctamente',
    'archived_tasks' => ':count tareas archivadas correctamente',
    'deleted_task' => 'Tarea borrada correctamente',
    'deleted_tasks' => ':count tareas borradas correctamente',
    'create_task' => 'Crear Tarea',
    'stopped_task' => 'Tarea parada correctamente',
    'invoice_task' => 'Facturar tarea',
    'invoice_labels' => 'Etiquetas de Factura',
    'prefix' => 'Prefijo',
    'counter' => 'Contador',
    'payment_type_dwolla' => 'Dwolla',
    'gateway_help_43' => ':link para registrase en Dwolla.',
    'partial_value' => 'Debe ser mayor que 0 y menos que el Total',
    'more_actions' => 'Más Acciones',
    'pro_plan_title' => 'NINJA PRO',
    'pro_plan_call_to_action' => 'Actualízate ahora!',
    'pro_plan_feature1' => 'Crear Clientes Ilimitados',
    'pro_plan_feature2' => 'Acceder a 10 hermosos diseños de Factura',
    'pro_plan_feature3' => 'URLs personalizadas - "TuMarca.InvoiceNinja.com"',
    'pro_plan_feature4' => 'Eliminar "Creado por Invoice Ninja"',
    'pro_plan_feature5' => 'Acceso Multiusuario y seguimiento de Actividad',
    'pro_plan_feature6' => 'Crear Presupuestos y Facturas Pro-forma',
    'pro_plan_feature7' => 'Personaliza los títulos y numeración de los campos de Factura',
    'pro_plan_feature8' => 'Opción para adjuntar PDFs a los correos de los clientes',
    'resume' => 'Reanudar',
    'break_duration' => 'Pausar',
    'edit_details' => 'Editar Detalles',
    'work' => 'Trabajo',
    'timezone_unset' => 'Por favor :link para especificar su Uso Horario',
    'click_here' => 'pulse aqui',
    'email_receipt' => 'Enviar Recibo de Pago al cliente',
    'created_payment_emailed_client' => 'Pago creado y enviado al cliente correctamente',
    'add_company' => 'Añadir Compañía',
    'untitled' => 'Sin Título',
    'new_company' => 'Nueva Compañía',
    'associated_accounts' => 'Cuentas conectadas correctamente',
    'unlinked_account' => 'Cuentas desconectadas correctamente',
    'login' => 'Iniciar Sesión',
    'or' => 'o',
    'email_error' => 'Ocurrió un problema enviando el correo',
    'confirm_recurring_timing' => 'Nota: correos enviados cada hora en punto.',
    'confirm_recurring_timing_not_sent' => 'Nota: las facturas son creadas a las horas en punto.',
    'payment_terms_help' => 'Establezca la <b>fecha límite de pago de factura</b> por defecto',
    'unlink_account' => 'Desconectar Cuenta',
    'unlink' => 'Desconectar',
    'show_address' => 'Mostrar Dirección',
    'show_address_help' => 'Cliente obligatorio para utilizar su dirección de Facturación',
    'update_address' => 'Actualizar Dirección',
    'update_address_help' => 'Actualizar la direccion del cliente con los datos provistos',
    'times' => 'Tiempos',
    'set_now' => 'Establecer ahora',
    'dark_mode' => 'Modo Oscuro',
    'dark_mode_help' => 'Usar fondo oscuro en barras laterales',
    'add_to_invoice' => 'Añadir a la factura :invoice',
    'create_new_invoice' => 'Crear una nueva factura',
    'task_errors' => 'Por favor corrija cualquier tiempo que se solape con otro',
    'from' => 'De',
    'to' => 'Para',
    'font_size' => 'Tamaño de Letra',
    'primary_color' => 'Color Primario',
    'secondary_color' => 'Color Secundario',
    'customize_design' => 'Personalizar diseño',
    'content' => 'Contenido',
    'styles' => 'Estilos',
    'defaults' => 'Ajustes Predefinidos',
    'margins' => 'Margenes',
    'header' => 'Cabecera',
    'footer' => 'Pie',
    'custom' => 'Personalizado',
    'invoice_to' => 'Factura para',
    'invoice_no' => 'Nº Factura',
    'quote_no' => 'Nº de Presupuesto',
    'recent_payments' => 'Pagos recientes',
    'outstanding' => 'Pendiente de Cobro',
    'manage_companies' => 'Administración de Compañías',
    'total_revenue' => 'Ingresos Totales',
    'current_user' => 'Usuario Actual',
    'new_recurring_invoice' => 'Nueva Factura Recurrente',
    'recurring_invoice' => 'Factura Recurrente',
    'new_recurring_quote' => 'Nuevo Presupuesto Recurrente',
    'recurring_quote' => 'Presupuesto Recurrente',
    'recurring_too_soon' => 'Es demasiado pronto para crear la siguiente factura recurrente, esta programada para :date',
    'created_by_invoice' => 'Creado por :invoice',
    'primary_user' => 'Usuario Principal',
    'help' => 'Ayuda',
    'customize_help' => '<p>Usamos :pdfmake_link para definir los diseños de la factura. Pdfmake :playground_link provee de una buena forma de ver la librería en acción.</p>
                        <p>Si necesitas ayuda para modificar algo, escríbenos una pregunta a nuestro :forum_link con el diseño que estés usando.</p>',
    'playground' => 'playground',
    'support_forum' => 'Foro de soporte',
    'invoice_due_date' => 'Fecha Límite de Pago',
    'quote_due_date' => 'Válido hasta',
    'valid_until' => 'Válido hasta',
    'reset_terms' => 'Restaurar términos',
    'reset_footer' => 'Restaurar pie',
    'invoice_sent' => 'Factura :count enviada',
    'invoices_sent' => ':count facturas enviadas',
    'status_draft' => 'Borrador',
    'status_sent' => 'Enviada',
    'status_viewed' => 'Vista',
    'status_partial' => 'Parcial',
    'status_paid' => 'Pagada',
    'status_unpaid' => 'Impagada',
    'status_all' => 'Todo',
    'show_line_item_tax' => 'Mostrar <b>impuesto para cada Línea de Factura</b>',
    'iframe_url' => 'Website',
    'iframe_url_help1' => 'Copia el siguiente código en una página de tu sitio web.',
    'iframe_url_help2' => 'Puedes probar esta funcionalidad pulsando \'Ver como destinatario\' de una Factura.',
    'auto_bill' => 'Facturación Automática',
    'military_time' => '24 Horas',
    'last_sent' => 'Última enviada',
    'reminder_emails' => 'Correos Recordatorio',
    'quote_reminder_emails' => 'Correos de recordatorio de presupuestos',
    'templates_and_reminders' => 'Plantillas & Recordatorios',
    'subject' => 'Asunto',
    'body' => 'Cuerpo',
    'first_reminder' => 'Primer Recordatorio',
    'second_reminder' => 'Segundo Recordatorio',
    'third_reminder' => 'Tercer Recordatorio',
    'num_days_reminder' => 'Días después de la Fecha Límite de Pago',
    'reminder_subject' => 'Recordatorio: Factura :invoice de :account',
    'reset' => 'Restaurar',
    'invoice_not_found' => 'La Factura solicitada no está disponible',
    'referral_program' => 'Programa de Recomendaciones',
    'referral_code' => 'Codigo de Recomendacion',
    'last_sent_on' => 'Enviado la ultima vez en :date',
    'page_expire' => 'Esta página expirará en breve, :click_here para seguir trabajando',
    'upcoming_quotes' => 'Próximos Presupuestos',
    'expired_quotes' => 'Presupuestos Expirados',
    'sign_up_using' => 'Registrarse usando',
    'invalid_credentials' => 'Las credenciales no coinciden con nuestros registros',
    'show_all_options' => 'Mostrar todas las opciones',
    'user_details' => 'Detalles de Usuario',
    'oneclick_login' => 'Cuenta Conectada',
    'disable' => 'Deshabilitado',
    'invoice_quote_number' => 'Números de Factura y Presupuesto',
    'invoice_charges' => 'Recargos de Factura',
    'notification_invoice_bounced' => 'No se pudo entregar la factura :invoice a :contact.',
    'notification_invoice_bounced_subject' => 'No se puede entregar la factura :invoice',
    'notification_quote_bounced' => 'No se pudo entregar el presupuesto :invoice a :contact.',
    'notification_quote_bounced_subject' => 'No se puede entregar el presupuesto :invoice',
    'custom_invoice_link' => 'Enlace a Factura personalizado',
    'total_invoiced' => 'Total Facturado',
    'open_balance' => 'Saldo Pendiente',
    'verify_email' => 'Por favor, visite el enlace en el correo de confirmación de cuenta para verificar su correo.',
    'basic_settings' => 'Configuración Básica',
    'pro' => 'Pro',
    'gateways' => 'Pasarelas de Pago',
    'next_send_on' => 'Próximo envío: :date',
    'no_longer_running' => 'Esta factura no esta programada para su ejecución',
    'general_settings' => 'Configuración General',
    'customize' => 'Personalizar',
    'oneclick_login_help' => 'Conectar una cuenta para entrar sin contraseña',
    'referral_code_help' => 'Gana dinero compartiendo nuestra aplicacion online',
    'enable_with_stripe' => 'Habilitado | Requiere Stripe',
    'tax_settings' => 'Configuración de Impuestos',
    'create_tax_rate' => 'Añadir impuesto',
    'updated_tax_rate' => 'Impuesto actualizado correctamente',
    'created_tax_rate' => 'Impuesto creado correctamente',
    'edit_tax_rate' => 'Editar impuesto',
    'archive_tax_rate' => 'Archivar impuesto',
    'archived_tax_rate' => 'Impuesto archivado correctamente',
    'default_tax_rate_id' => 'Impuesto predeterminado',
    'tax_rate' => 'Impuesto',
    'recurring_hour' => 'Hora periódica',
    'pattern' => 'Patrón',
    'pattern_help_title' => 'Ayuda del patrón',
    'pattern_help_1' => 'Crear Números de Factura y de Presupuesto personalizados mediante un Patron',
    'pattern_help_2' => 'Variables disponibles:',
    'pattern_help_3' => 'Por ejemplo, :example será convertido a :value',
    'see_options' => 'Ver opciones',
    'invoice_counter' => 'Contador de Factura',
    'quote_counter' => 'Contador de Presupuesto',
    'type' => 'Tipo',
    'activity_1' => ':user creó el cliente :client',
    'activity_2' => ':user archivó el cliente :client',
    'activity_3' => ':user borró el cliente :client',
    'activity_4' => ':user archivó la factura :invoice',
    'activity_5' => ':user actualizó la factura :invoice',
    'activity_6' => ':user ha enviado por mail la factura :invoice de :client a :contact',
    'activity_7' => ':contact ha visto la factura :invoice: de :client',
    'activity_8' => ':user archivó la factura :invoice',
    'activity_9' => ':user borró la factura :invoice',
    'activity_10' => ':contact ingresó el pago :payment por importe de :payment_amount en la factura Nº :invoice de :client',
    'activity_11' => ':user actualizó el Pago :payment',
    'activity_12' => ':user archivó el pago :payment',
    'activity_13' => ':user borró el pago :payment',
    'activity_14' => ':user introdujo :credit crédito',
    'activity_15' => ':user actualizó :credit crédito',
    'activity_16' => ':user archivó :credit crédito',
    'activity_17' => ':user deleted :credit crédito',
    'activity_18' => ':user borró el presupuesto :quote',
    'activity_19' => ':user actualizó el presupuesto :quote',
    'activity_20' => ':user envió presupuesto :quote para :client a :contact',
    'activity_21' => ':contact vió el presupuesto :quote',
    'activity_22' => ':user archivó el presupuesto :quote',
    'activity_23' => ':user borró el presupuesto :quote',
    'activity_24' => ':user restauró el presupuesto :quote',
    'activity_25' => ':user restauró la factura :invoice',
    'activity_26' => ':user restauró el cliente :client',
    'activity_27' => ':user restauró el pago :payment',
    'activity_28' => ':user restauró :credit crédito',
    'activity_29' => ':contact ha aprovado el presupuesto :quote para :client',
    'activity_30' => ':user creó al vendedor :vendor',
    'activity_31' => ':user archivó al vendedor :vendor',
    'activity_32' => ':user eliminó al vendedor :vendor',
    'activity_33' => ':user restauró al vendedor :vendor',
    'activity_34' => ':user creó el gasto :expense',
    'activity_35' => ':user archivó el gasto :expense',
    'activity_36' => ':user eliminó el gasto :expense',
    'activity_37' => ':user restauró el gasto :expense',
    'activity_42' => ':user creó la tarea :task',
    'activity_43' => ':user actualizó la tarea :task',
    'activity_44' => ':user archivó la tarea :task',
    'activity_45' => ':user eliminó la tarea :task',
    'activity_46' => ':user restauró la tarea :task',
    'activity_47' => ':user actualizó el gasto :expense',
    'activity_48' => ':user actualizó el ticket :ticket',
    'activity_49' => ':user cerró el ticket :ticket',
    'activity_50' => ':user unió el ticket :ticket',
    'activity_51' => ':user dividió el ticket :ticket',
    'activity_52' => ':contact abrió el ticket :ticket',
    'activity_53' => ':contact reabrió el ticket :ticket',
    'activity_54' => ':user reabrió el ticket :ticket',
    'activity_55' => ':contact respondió el ticket :ticket',
    'activity_56' => ':user vio el ticket :ticket',

    'payment' => 'Pago',
    'system' => 'Sistema',
    'signature' => 'Firma del correo',
    'default_messages' => 'Mensajes Predefinidos',
    'quote_terms' => 'Términos del Presupuesto',
    'default_quote_terms' => 'Términos del Presupuesto predefinidos',
    'default_invoice_terms' => 'Términos de Factura Predeterminado',
    'default_invoice_footer' => 'Pie de Página de Factura Predeterminado',
    'quote_footer' => 'Pie del Presupuesto',
    'free' => 'Gratuito',
    'quote_is_approved' => 'Aprobado correctamente',
    'apply_credit' => 'Aplicar Crédito',
    'system_settings' => 'Configuración del Sistema',
    'archive_token' => 'Archivar Token',
    'archived_token' => 'Token archivado correctamente',
    'archive_user' => 'Archivar Usuario',
    'archived_user' => 'Usuario archivado correctamente',
    'archive_account_gateway' => 'Eliminar Pasarela',
    'archived_account_gateway' => 'Pasarela archivada correctamente',
    'archive_recurring_invoice' => 'Archivar Factura Recurrente',
    'archived_recurring_invoice' => 'Factura recurrente archivada correctamente',
    'delete_recurring_invoice' => 'Borrar Factura Recurrente',
    'deleted_recurring_invoice' => 'Factura recurrente borrada correctamente',
    'restore_recurring_invoice' => 'Restaurar Factura Recurrente ',
    'restored_recurring_invoice' => 'Factura recurrente restaurada correctamente',
    'archive_recurring_quote' => 'Archivar Presupuesto Recurrente',
    'archived_recurring_quote' => 'Presupuesto recurrente archivado correctamente',
    'delete_recurring_quote' => 'Borrar Presupuesto Recurrente',
    'deleted_recurring_quote' => 'Presupuesto recurrente borrado correctamente',
    'restore_recurring_quote' => 'Restaurar Presupuesto Recurrente',
    'restored_recurring_quote' => 'Presupuesto recurrente restaurado correctamente',
    'archived' => 'Archivado',
    'untitled_account' => 'Compañía sin Nombre',
    'before' => 'Antes',
    'after' => 'Después',
    'reset_terms_help' => 'Restaurar los términos por defecto de la cuenta',
    'reset_footer_help' => 'Restaurar el pie de página por defecto de la cuenta',
    'export_data' => 'Exportar',
    'user' => 'Usuario',
    'country' => 'Pais',
    'include' => 'Incluir',
    'logo_too_large' => 'El logo es :size, para un buen rendimiento del PDF, sugerimos cargar una imagen de menos de 200KB',
    'import_freshbooks' => 'Importar desde FreshBooks',
    'import_data' => 'Importar datos',
    'source' => 'Origen',
    'csv' => 'CSV',
    'client_file' => 'Fichero de Clientes',
    'invoice_file' => 'Fichero de Factura',
    'task_file' => 'Fichero de Tareas',
    'no_mapper' => 'Mapeo no válido para el fichero',
    'invalid_csv_header' => 'Cabecera CSV no Válida',
    'client_portal' => 'Portal Cliente',
    'admin' => 'Admin.',
    'disabled' => 'Deshabilitado',
    'show_archived_users' => 'Mostrar usuarios archivados',
    'notes' => 'Notas',
    'invoice_will_create' => 'la factura será creada',
    'invoices_will_create' => 'facturas serán creadas',
    'failed_to_import' => 'Los siguientes registros fallaron al importar',
    'publishable_key' => 'Clave pública',
    'secret_key' => 'Clave Privada',
    'missing_publishable_key' => 'Establece tu clave publica de Stripe para mejorar el proceso de checkout',
    'email_design' => 'Diseño de Correo',
    'due_by' => 'A pagar el :date',
    'enable_email_markup' => 'Habilitar Markup',
    'enable_email_markup_help' => 'Haga que sea fácil para sus clientes que paguen mediante la adición de marcas "schema.org" a sus correos electrónicos.',
    'template_help_title' => 'Ayuda',
    'template_help_1' => 'Variables disponibles:',
    'email_design_id' => 'Estilo de Correo',
    'email_design_help' => 'Haga que sus mensajes de email tengan un aspecto más profesional con diseños HTML',
    'plain' => 'Plano',
    'light' => 'Claro',
    'dark' => 'Oscuro',
    'industry_help' => 'Usado para proporcionar comparaciones de las medias de empresas de sectores y tamaño similares.',
    'subdomain_help' => 'Asigne el subdominio o mostrar la factura en su propio sitio web.',
    'website_help' => 'Mostrar la factura en un iFrame de su sitio web',
    'invoice_number_help' => 'Especifique un prefijo o utilice un patrón a medida para establecer dinámicamente el número de Factura.',
    'quote_number_help' => 'Especifique un prefijo o utilice un patrón a medida para establecer dinámicamente el número de presupuesto.',
    'custom_client_fields_helps' => 'Añadir un campo al crear un Cliente y opcionalmente mostrar la etiqueta y su valor en el PDF.',
    'custom_account_fields_helps' => 'Añadir una etiqueta y su valor a la sección de detalles de la empresa del PDF.',
    'custom_invoice_fields_helps' => 'Añadir un campo al crear una Factura y opcionalmente mostrar la etiqueta y su valor en el PDF.',
    'custom_invoice_charges_helps' => 'Añadir un campo al crear una Factura e incluir el cargo en el subtotal de la Factura.',
    'token_expired' => 'Token de validación ha caducado. Por favor, vuelva a intentarlo.',
    'invoice_link' => 'Enlace a Factura',
    'button_confirmation_message' => 'Pulse aqui para confirmar su dirección de correo.',
    'confirm' => 'Confirmar',
    'email_preferences' => 'Preferencias de Correo',
    'created_invoices' => ':count factura(s) creada(s) correctamente',
    'next_invoice_number' => 'El próximo número de Factura es :number.',
    'next_quote_number' => 'El próximo número de presupuesto es :number.',
    'days_before' => 'días antes de',
    'days_after' => 'días después de',
    'field_due_date' => 'Fecha de Pago',
    'field_invoice_date' => 'Fecha de Factura',
    'schedule' => 'Programar',
    'email_designs' => 'Diseños de correo',
    'assigned_when_sent' => 'Asignado al enviar',
    'white_label_purchase_link' => 'Comprar licencia de marca blanca',
    'expense' => 'Gasto',
    'expenses' => 'Gastos',
    'new_expense' => 'Nuevo Gasto',
    'enter_expense' => 'Introducir Gasto',
    'vendors' => 'Proveedores',
    'new_vendor' => 'Nuevo Proveedor',
    'payment_terms_net' => 'Net',
    'vendor' => 'Proveedor',
    'edit_vendor' => 'Editar Proveedor',
    'archive_vendor' => 'Archivar Proveedor',
    'delete_vendor' => 'Borrar Proveedor',
    'view_vendor' => 'Ver Proveedor',
    'deleted_expense' => 'Gasto borrado correctamente',
    'archived_expense' => 'Gasto archivado correctamente',
    'deleted_expenses' => 'Gastos borrados correctamente',
    'archived_expenses' => 'Gastos archivados correctamente',
    'expense_amount' => 'Importe del Gasto',
    'expense_balance' => 'Saldo del Gasto',
    'expense_date' => 'Fecha',
    'expense_should_be_invoiced' => '¿Este gasto debe ser facturado?',
    'public_notes' => 'Notas',
    'invoice_amount' => 'Importe de Factura',
    'exchange_rate' => 'Tipo de Cambio',
    'yes' => 'Sí',
    'no' => 'No',
    'should_be_invoiced' => 'Debe ser Facturado',
    'view_expense' => 'Ver gasto # :expense',
    'edit_expense' => 'Editar Gasto',
    'archive_expense' => 'Archivar Gasto',
    'delete_expense' => 'Borrar Gasto',
    'view_expense_num' => 'Gasto # :expense',
    'updated_expense' => 'Gasto actualizado correctamente',
    'created_expense' => 'Gasto creado correctamente',
    'enter_expense' => 'Introducir Gasto',
    'view' => 'Ver',
    'restore_expense' => 'Restaurar Gasto',
    'invoice_expense' => 'Facturar Gasto',
    'expense_error_multiple_clients' => 'Los gastos no pertenecen a diferentes clientes',
    'expense_error_invoiced' => 'El gasto ya ha sido facturado',
    'convert_currency' => 'Convertir moneda',
    'num_days' => 'Número de Días',
    'create_payment_term' => 'Crear Términos de Pago',
    'edit_payment_terms' => 'Editar los Términos de Pago',
    'edit_payment_term' => 'Editar el Términos de Pago',
    'archive_payment_term' => 'Archivar Términos de Pago',
    'recurring_due_dates' => 'Fecha de Vencimiento de Factura Recurrente',
    'recurring_due_date_help' => '<p>Establece automáticamente una fecha de vencimiento para la factura.</p>
<p>Las facturas en un ciclo mensual o anual que vencen en o antes del día en que se crearán vencerán el próximo mes. Las facturas que vencen el 29 o 30 en meses que no tienen ese día se vencen el último día del mes.</p>
<p>Las facturas de un ciclo semanal que vence el día de la semana en que se crearán se vencerán la próxima semana.</p>
<p>Por ejemplo:</p>
<ul>
<li>Hoy es el día 15, la fecha de vencimiento es el 1 de cada mes. La fecha de vencimiento probablemente sea el día 1 del próximo mes.</li>
<li>Hoy es el día 15, la fecha de vencimiento es el último día del mes. La fecha de vencimiento será el último día de este mes.</li>
<li>Hoy es el día 15, la fecha de vencimiento es el día 15 del mes. La fecha de vencimiento será el día 15 del mes <strong>próximo.</strong></li>
<li>Hoy es el viernes, la fecha límite es el primer viernes después. La fecha de vencimiento será el próximo viernes, no hoy.</li></ul>',
    'due' => 'Vencimiento',
    'next_due_on' => 'Próximo Vencimiento: :date',
    'use_client_terms' => 'Utilizar términos del cliente',
    'day_of_month' => ':ordinal día del mes',
    'last_day_of_month' => 'Último día del mes',
    'day_of_week_after' => ':ordinal :day despues',
    'sunday' => 'Domingo',
    'monday' => 'Lunes',
    'tuesday' => 'Martes',
    'wednesday' => 'Miércoles',
    'thursday' => 'Jueves',
    'friday' => 'Viernes',
    'saturday' => 'Sábado',
    'header_font_id' => 'Tipo de letra de la cabecera',
    'body_font_id' => 'Tipo de letra del cuerpo',
    'color_font_help' => 'Nota: el color primario y las fuentes también se utilizan en el portal del cliente y los diseños de correo electrónico personalizados.',
    'live_preview' => 'Previsualización en vivo',
    'invalid_mail_config' => 'Imposible enviar el correo, por favor, comprobar que la configuración de correo es correcta.',
    'invoice_message_button' => 'Para ver su Factura con importe  :amount, pulse el siguiente botón.',
    'quote_message_button' => 'Para ver su presupuesto con importe :amount, pulse el siguiente botón.',
    'payment_message_button' => 'Gracias por su Pago de :amount.',
    'payment_type_direct_debit' => 'Débito Automático',
    'bank_accounts' => 'Cuentas Bancarias',
    'add_bank_account' => 'Añadir Cuenta Bancaria',
    'setup_account' => 'Configurar Cuenta',
    'import_expenses' => 'Importar Gastos',
    'bank_id' => 'Banco',
    'integration_type' => 'Tipo de Integración',
    'updated_bank_account' => 'Cuenta bancaria actualizada correctamente',
    'edit_bank_account' => 'Editar Cuenta Bancaria',
    'archive_bank_account' => 'Archivar Cuenta Bancaria',
    'archived_bank_account' => 'Cuenta bancaria archivada correctamente',
    'created_bank_account' => 'Cuenta bancaria creada correctamente',
    'validate_bank_account' => 'Validar Cuenta Bancaria',
    'bank_password_help' => 'Nota: tu password se transmite de manera segura y nunca se almacenará en nuestros servidores.',
    'bank_password_warning' => 'Atención! tu password puede estar transmitida como texto plano, considera habilitar HTTPS.',
    'username' => 'Usuario',
    'account_number' => 'Número de Cuenta',
    'account_name' => 'Nombre de Cuenta',
    'bank_account_error' => 'Fallo al obtener los detalles de la cuenta, por favor comprueba tus credenciales.',
    'status_approved' => 'Aprobado',
    'quote_settings' => 'Configuración de Presupuestos',
    'auto_convert_quote' => 'Auto Convertir',
    'auto_convert_quote_help' => 'Convertir un Presupuesto en Factura automáticamente cuando lo apruebe el cliente.',
    'validate' => 'Validar',
    'info' => 'Info',
    'imported_expenses' => ' :count_vendors proveedor(es) y :count_expenses gasto(s) importados correctamente',
    'iframe_url_help3' => 'Nota: Si piensas aceptar tarjetas de crédito recomendamos tener habilitado HTTPS.',
    'expense_error_multiple_currencies' => 'Los gastos no pueden tener diferentes monedas',
    'expense_error_mismatch_currencies' => 'La moneda del cliente no coincide con la moneda del gasto.',
    'trello_roadmap' => 'Trello Roadmap',
    'header_footer' => 'Cabecera/Pie',
    'first_page' => 'Primera página',
    'all_pages' => 'Todas las páginas',
    'last_page' => 'Última página',
    'all_pages_header' => 'Mostrar Cabecera en',
    'all_pages_footer' => 'Mostrar Pie en',
    'invoice_currency' => 'Moneda de la Factura',
    'enable_https' => 'Recomendamos encarecidamente usar HTTPS para aceptar detalles de tarjetas de crédito online',
    'quote_issued_to' => 'Presupuesto emitido a',
    'show_currency_code' => 'Código de Moneda',
    'free_year_message' => 'Tu cuenta ha sido actualizada al Plan Pro por un año sin ningun coste.',
    'trial_message' => 'Tu cuenta recibirá dos semanas gratuitas de nuestro  plan Pro.',
    'trial_footer' => 'Tu prueba gratuita del Plan Pro termina en :count días, :link para actualizar ahora.',
    'trial_footer_last_day' => 'Hoy es tu último dia de prueba gratuita del Plan Pro, :link para actualizar ahora.',
    'trial_call_to_action' => 'Iniciar periodo de Prueba',
    'trial_success' => 'Habilitado correctamente el periodo de dos semanas de prueba Pro ',
    'overdue' => 'Atraso',


    'white_label_text' => 'Compra UN AÑO de Licencia de Marca Blanca por $:price y elimina la marca Invoice Ninja de la Factura y del Portal de Cliente.',
    'user_email_footer' => 'Para ajustar la configuración de las notificaciones de tu email, visita :link',
    'reset_password_footer' => 'Si no has solicitado un cambio de contraseña, por favor contactate con nosostros: :email',
    'limit_users' => 'Lo sentimos, esta acción excederá el límite de :limit usarios',
    'more_designs_self_host_header' => 'Obtenga 6 diseños más para Facturas por sólo $:price',
    'old_browser' => 'Por favor usa un :link',
    'newer_browser' => 'navegador nuevo',
    'white_label_custom_css' => ':link para $:price para permitir un estilo personalizado y ayudar a respaldar nuestro proyecto.',
    'bank_accounts_help' => 'Conecta una cuenta bancaria para importar automáticamente gastos y crear proveedores. Soporta American Express y :link.',
    'us_banks' => '400+ US banks',

    'pro_plan_remove_logo' => ':link haz click para eliminar el logo de Invoice Ninja',
    'pro_plan_remove_logo_link' => 'Haz click aquí',
    'invitation_status_sent' => 'Enviado',
    'invitation_status_opened' => 'Abierto',
    'invitation_status_viewed' => 'Visto',
    'email_error_inactive_client' => 'No se pueden enviar correos a Clientes inactivos',
    'email_error_inactive_contact' => 'No se pueden enviar correos a Contactos inactivos',
    'email_error_inactive_invoice' => 'No se pueden enviar correos de Facturas inactivas',
    'email_error_inactive_proposal' => 'No se pueden enviar correos a Propuestas inactivas',
    'email_error_user_unregistered' => 'Por favor registra tu cuenta para enviar correos',
    'email_error_user_unconfirmed' => 'Por favor confirma tu cuenta para enviar correos',
    'email_error_invalid_contact_email' => 'Correo de contacto no válido',

    'navigation' => 'Navegación',
    'list_invoices' => 'Lista de Facturas',
    'list_clients' => 'Lista de Clientes',
    'list_quotes' => 'Lista de Presupuestos',
    'list_tasks' => 'Lista de Tareas',
    'list_expenses' => 'Lista de Gastos',
    'list_recurring_invoices' => 'Lista de Facturas Recurrentes',
    'list_payments' => 'Lista de Pagos',
    'list_credits' => 'Lista de Créditos',
    'tax_name' => 'Nombre de Impuesto',
    'report_settings' => 'Configuración de Informes',
    'search_hotkey' => 'Atajo es /',

    'new_user' => 'Nuevo Usuario',
    'new_product' => 'Nuevo Producto',
    'new_tax_rate' => 'Nuevo Impuesto',
    'invoiced_amount' => 'Importe Facturado',
    'invoice_item_fields' => 'Campos de Línea de Factura',
    'custom_invoice_item_fields_help' => 'Añadir un campo al crear un concepto de factura y mostrar la etiqueta y su valor en el PDF.',
    'recurring_invoice_number' => 'Número Recurrente',
    'recurring_invoice_number_prefix_help' => 'Especifique un prefijo que se agregará al número de factura para facturas recurrentes.',

    // Client Passwords
    'enable_portal_password' => 'Proteger Facturas con Contraseña',
    'enable_portal_password_help' => 'Habilite para seleccionar una contraseña para cada contacto. Si una contraseña esta especificada, se le será solicitada al contacto para acceder a sus facturas.',
    'send_portal_password' => 'Generada Automaticamente',
    'send_portal_password_help' => 'Si no se especifica password, se generará una y se enviará junto con la primera Factura.',

    'expired' => 'Expirada',
    'invalid_card_number' => 'El número de tarjeta de crédito no es válido',
    'invalid_expiry' => 'La fecha de vencimiento no es válida.',
    'invalid_cvv' => 'El CVV no es válido.',
    'cost' => 'Coste',
    'create_invoice_for_sample' => 'Nota: cree una factura para previsualizarla aquí.',

    // User Permissions
    'owner' => 'Propietario',
    'administrator' => 'Administrador',
    'administrator_help' => 'Permitir que administre usuarios, cambie configuración y modifique cualquier registro',
    'user_create_all' => 'Crear clientes, facturas, etc.',
    'user_view_all' => 'Ver todos los clientes, facturas, etc.',
    'user_edit_all' => 'Editar todos los clientes, facturas, etc.',
    'gateway_help_20' => ':link para registrarse en Sage Pay.',
    'gateway_help_21' => ':link para registrarse en Sage Pay.',
    'partial_due' => 'Adelanto',
    'restore_vendor' => 'Restablecer Proveedor',
    'restored_vendor' => 'Proveedor restaurado correctamente',
    'restored_expense' => 'Gasto restaurado correctamente',
    'permissions' => 'Permisos',
    'create_all_help' => 'Permitir al usuario crear y modificar registros',
    'view_all_help' => 'Permitir al usuario ver registros. No podrán crearlos',
    'edit_all_help' => 'Permitir al usuario modificar registros. No podrán crearlos',
    'view_payment' => 'Ver Pago',

    'january' => 'Enero',
    'february' => 'Febrero',
    'march' => 'Marzo',
    'april' => 'Abril',
    'may' => 'Mayo',
    'june' => 'Junio',
    'july' => 'Julio',
    'august' => 'Agosto',
    'september' => 'Septiembre',
    'october' => 'Octubre',
    'november' => 'Noviembre',
    'december' => 'Diciembre',

    // Documents
    'documents_header' => 'Documentos:',
    'email_documents_header' => 'Documentos:',
    'email_documents_example_1' => 'Widgets Receipt.pdf',
    'email_documents_example_2' => 'Final Deliverable.zip',
    'quote_documents' => 'Documentos de Presupuesto',
    'invoice_documents' => 'Documentos de Factura',
    'expense_documents' => 'Documentos de Gasto',
    'invoice_embed_documents' => 'Documentos anexados',
    'invoice_embed_documents_help' => 'Incluye imagenes adjuntas en la factura',
    'document_email_attachment' => 'Adjuntar documentos',
    'ubl_email_attachment' => 'Adjuntar URL',
    'download_documents' => 'Descargar documentos (:size)',
    'documents_from_expenses' => 'De los Gastos:',
    'dropzone_default_message' => 'Arrastra ficheros aquí o Haz clic para subir',
    'dropzone_default_message_disabled' => 'Subidas desactivadas',
    'dropzone_fallback_message' => 'Tu navegador no soporta carga de archivos mediante drag\'n\'drop.',
    'dropzone_fallback_text' => 'Utilice el siguiente formulario para cargar sus archivos como en los viejos tiempos.',
    'dropzone_file_too_big' => 'El archivo es demasiado grande ({{filesize}}MiB). Tamaño máximo: {{maxFilesize}}MiB.',
    'dropzone_invalid_file_type' => 'No puede subir archivos de este tipo.',
    'dropzone_response_error' => 'El servidor respondió con el código {{statusCode}}.',
    'dropzone_cancel_upload' => 'Cancelar carga de archivos',
    'dropzone_cancel_upload_confirmation' => '¿Estás seguro de que deseas cancelar esta carga?',
    'dropzone_remove_file' => 'Borrar archivo',
    'documents' => 'Documentos',
    'document_date' => 'Fecha',
    'document_size' => 'Tamaño',

    'enable_client_portal' => 'Panel de Control',
    'enable_client_portal_help' => 'Mostrar u ocultar la página del Panel de Control en el portal del cliente..',
    'enable_client_portal_dashboard' => 'Panel de Control',
    'enable_client_portal_dashboard_help' => 'Mostrar u ocultar la página del Panel de Control en el portal del cliente.',

    // Plans
    'account_management' => 'Administración de la Cuenta',
    'plan_status' => 'Estado del Plan',

    'plan_upgrade' => 'Mejorar',
    'plan_change' => 'Cambiar de Plan',
    'pending_change_to' => 'Cambios para',
    'plan_changes_to' => ':plan en :date',
    'plan_term_changes_to' => ':plan (:term) el :date',
    'cancel_plan_change' => 'Cancelar cambio',
    'plan' => 'Plan',
    'expires' => 'Vence',
    'renews' => 'Se Renueva',
    'plan_expired' => ':plan Plan Vencido',
    'trial_expired' => ':plan Plan Prueba Terminado',
    'never' => 'Nunca',
    'plan_free' => 'Gratuito',
    'plan_pro' => 'Pro',
    'plan_enterprise' => 'Enterprise',
    'plan_white_label' => 'Alojamiento Propio (Marca Blanca)',
    'plan_free_self_hosted' => 'Alojamiento Propio (Gratis)',
    'plan_trial' => 'Prueba',
    'plan_term' => 'Término',
    'plan_term_monthly' => 'Mensual',
    'plan_term_yearly' => 'Anual',
    'plan_term_month' => 'Mes',
    'plan_term_year' => 'Año',
    'plan_price_monthly' => '$:price/Mes',
    'plan_price_yearly' => '$:price/Año',
    'updated_plan' => 'Configuración del plan actualizada',
    'plan_paid' => 'Term Iniciado',
    'plan_started' => 'Plan Iniciado',
    'plan_expires' => 'Plan Vencido',

    'white_label_button' => 'Marca Blanca',

    'pro_plan_year_description' => 'Un año de inscripción en el Plan Invoice Ninja Pro.',
    'pro_plan_month_description' => 'Un mes de inscripción en el Plan Invoice Ninja Pro.',
    'enterprise_plan_product' => 'Plan Enterprise ',
    'enterprise_plan_year_description' => 'Un año de inscripción en el Plan Invoice Ninja Enterprise .',
    'enterprise_plan_month_description' => 'Un mes de inscripción en el Plan Invoice Ninja Enterprise .',
    'plan_credit_product' => 'Crédito',
    'plan_credit_description' => 'Crédito por tiempo no utilizado',
    'plan_pending_monthly' => 'Cambiará a mensualmente el :date',
    'plan_refunded' => 'Se ha emitido un reembolso.',

    'live_preview' => 'Previsualización en vivo',
    'page_size' => 'Tamaño de Pagina',
    'live_preview_disabled' => 'La Vista Previa en vivo se ha deshabilitado para admitir la fuente seleccionada.',
    'invoice_number_padding' => 'Relleno',
    'preview' => 'Vista Previa',
    'list_vendors' => 'Lista de Proveedores',
    'add_users_not_supported' => 'Upgrade to the Enterprise plan to add additional users to your account.',
    'enterprise_plan_features' => 'The Enterprise plan adds support for multiple users and file attachments, :link to see the full list of features.',
    'return_to_app' => 'Regresar a la Applicacion',


    // Payment updates
    'refund_payment' => 'Reembolsar Pago',
    'refund_max' => 'Max:',
    'refund' => 'Reembolo',
    'are_you_sure_refund' => 'Reembolsar los Pagos seleccionados?',
    'status_pending' => 'Pendiente',
    'status_completed' => 'Completado',
    'status_failed' => 'Fallido',
    'status_partially_refunded' => 'Parcialmente Reembolsado',
    'status_partially_refunded_amount' => ':amount Reembolsados',
    'status_refunded' => 'Reembolsado',
    'status_voided' => 'Cancelado',
    'refunded_payment' => 'Pago Reembolsado',
    'activity_39' => ':user cancelo :payment_amount del pago :payment',
    'activity_40' => ':user reembolsó :adjustment de :payment_amount del pago :payment',
    'card_expiration' => 'Exp:&nbsp:expires',

    'card_creditcardother' => 'Desconocido',
    'card_americanexpress' => 'American Express',
    'card_carteblanche' => 'Carte Blanche',
    'card_unionpay' => 'UnionPay',
    'card_diners' => 'Diners Club',
    'card_discover' => 'Discover',
    'card_jcb' => 'JCB',
    'card_laser' => 'Laser',
    'card_maestro' => 'Maestro',
    'card_mastercard' => 'MasterCard',
    'card_solo' => 'Solo',
    'card_switch' => 'Switch',
    'card_visacard' => 'Visa',
    'card_ach' => 'ACH',

    'payment_type_stripe' => 'Stripe',
    'ach' => 'ACH',
    'enable_ach' => 'Habilitar ACH',
    'stripe_ach_help' => 'El soporte de ACH debe ser habilitado en :link.',
    'ach_disabled' => 'Ya existe otra pasarela configurada para débito directo.',

    'plaid' => 'Pagado',
    'client_id' => 'Id del cliente',
    'secret' => 'Secreto',
    'public_key' => 'Llave pública',
    'plaid_optional' => '(opcional)',
    'plaid_environment_help' => 'Cuando se de una clave de prueba de Stripe, se utilizará un entorno de desarrollo de Plaid.',
    'other_providers' => 'Otros proveedores',
    'country_not_supported' => 'Este país no está soportado.',
    'invalid_routing_number' => 'El número de ruta no es válido.',
    'invalid_account_number' => 'El número de cuenta no es valido',
    'account_number_mismatch' => 'Los números de cuenta no coinciden.',
    'missing_account_holder_type' => 'Seleccione una cuenta individual o de empresa.',
    'missing_account_holder_name' => 'Por favor ingrese el nombre del titular de la cuenta.',
    'routing_number' => 'Número de ruta',
    'confirm_account_number' => 'Confirmar número de cuenta',
    'individual_account' => 'Cuenta individual',
    'company_account' => 'Cuenta de la compañia',
    'account_holder_name' => 'Nombre del titular de la cuenta',
    'add_account' => 'Añadir Cuenta ',
    'payment_methods' => 'Métodos de pago',
    'complete_verification' => 'Completar Verificación ',
    'verification_amount1' => 'Cantidad 1',
    'verification_amount2' => 'Cantidad 2',
    'payment_method_verified' => 'Verificación completada correctamente',
    'verification_failed' => 'Fallo en la verificación',
    'remove_payment_method' => 'Borrar Método de pago',
    'confirm_remove_payment_method' => '¿Seguro que quieres eliminar este método de pago?',
    'remove' => 'Borrar',
    'payment_method_removed' => 'Se eliminó el método de pago.',
    'bank_account_verification_help' => 'Hemos realizado dos depósitos en su cuenta con la descripción "VERIFICACIÓN". Estos depósitos demorarán entre 1 y 2 días hábiles en aparecer en su estado de cuenta. Por favor ingrese los montos a continuación.',
    'bank_account_verification_next_steps' => 'Hemos realizado dos depósitos en su cuenta con la descripción "VERIFICACIÓN". Estos depósitos demorarán entre 1 y 2 días hábiles en aparecer en su estado de cuenta.
Una vez que tenga los montos, vuelva a esta página de métodos de pago y haga clic en "Verificación completa" junto a la cuenta.',
    'unknown_bank' => 'Banco Desconocido',
    'ach_verification_delay_help' => 'Podrás usar la cuenta después de completar la verificación. La verificación generalmente demora entre 1 y 2 días hábiles.',
    'add_credit_card' => 'Añadir Tarjeta de crédito',
    'payment_method_added' => 'Se añadio el método de pago.',
    'use_for_auto_bill' => 'Usar para Auto-factura',
    'used_for_auto_bill' => 'Método de pago de Auto-factura',
    'payment_method_set_as_default' => 'Establecer el método de pago de Auto-factura.',
    'activity_41' => 'Fallo el pago de :payment_amount para  (:payment) ',
    'webhook_url' => 'Webhook URL',
    'stripe_webhook_help' => 'Debes :link.',
    'stripe_webhook_help_link_text' => 'agregue esta URL como endpoint en Stripe',
    'gocardless_webhook_help_link_text' => 'añade ésta URL como endpoint en GoCardless',
    'payment_method_error' => 'Se produjo un error al agregar su método de pago. Por favor, inténtelo de nuevo más tarde.',
    'notification_invoice_payment_failed_subject' => 'Pago fallido para la Factura :invoice',
    'notification_invoice_payment_failed' => 'Un pago realizado por el cliente :client  hacia la factura :invoice falló. El pago ha sido marcado como fallido y :amount se ha agregado al saldo del cliente.',
    'link_with_plaid' => 'Enlace de cuenta al instante con Plaid',
    'link_manually' => 'Enlazar Manualmente',
    'secured_by_plaid' => 'Asegurada por Plaid',
    'plaid_linked_status' => 'Su cuenta bancaria en :bank',
    'add_payment_method' => 'Añadir Método de pago',
    'account_holder_type' => 'Tipo de titular de la cuenta',
    'ach_authorization' => 'Autorizo a :company a usar mi cuenta bancaria para pagos futuros y, si es necesario, acreditar electrónicamente mi cuenta para corregir los débitos erróneos. Entiendo que puedo cancelar esta autorización en cualquier momento eliminando el método de pago o contactando :email .',
    'ach_authorization_required' => 'Debe dar su consentimiento a las transacciones de ACH.',
    'off' => 'Apagado',
    'opt_in' => 'Optar en',
    'opt_out' => 'Optar por no',
    'always' => 'Siempre',
    'opted_out' => 'Optado',
    'opted_in' => 'Optado en',
    'manage_auto_bill' => 'Administrar Auto-factura',
    'enabled' => 'Habilitado',
    'paypal' => 'PayPal',
    'braintree_enable_paypal' => 'Habilitar pagos de PayPal a través de BrainTree',
    'braintree_paypal_disabled_help' => 'La pasarela de PayPal está procesando los pagos de PayPal',
    'braintree_paypal_help' => 'Usted también debe :link.',
    'braintree_paypal_help_link_text' => 'enlace PayPal a su cuenta BrainTree',
    'token_billing_braintree_paypal' => 'Guardar detalles de pago',
    'add_paypal_account' => 'Añadir Cuenta de PayPal ',


    'no_payment_method_specified' => 'Metodo de pago no especificado',
    'chart_type' => 'Tipo de Grafica',
    'format' => 'Formato',
    'import_ofx' => 'Importar OFX',
    'ofx_file' => 'Fichero OFX',
    'ofx_parse_failed' => 'Fallo el proceso del Fichero OFX',

    // WePay
    'wepay' => 'WePay',
    'sign_up_with_wepay' => 'Registrarse con WePay',
    'use_another_provider' => 'Usa otro proveedor',
    'company_name' => 'Nombre de la Empresa',
    'wepay_company_name_help' => 'Esto aparecerá en los estados de cuenta de la tarjeta de crédito del cliente.',
    'wepay_description_help' => 'La finalidad de esta cuenta.',
    'wepay_tos_agree' => 'Acepto las :link.',
    'wepay_tos_link_text' => 'Términos de Empleo de WePay',
    'resend_confirmation_email' => 'Reenviar Email de Confirmación',
    'manage_account' => 'Administrar cuenta',
    'action_required' => 'Acción requerida',
    'finish_setup' => 'Completar Configuración',
    'created_wepay_confirmation_required' => 'Por favor revisa tu correo electrónico y confirma tu dirección de correo con WePay.',
    'switch_to_wepay' => 'Cambiar a WePay',
    'switch' => 'Cambiar',
    'restore_account_gateway' => 'Restaurar Pasarela',
    'restored_account_gateway' => 'Pasarela restaurada correctamente',
    'united_states' => 'Estados Unidos',
    'canada' => 'Canada',
    'accept_debit_cards' => 'Aceptar Tarjetas de Débito',
    'debit_cards' => 'Tarjetas de Débito',

    'warn_start_date_changed' => 'La siguiente Factura se enviará en la nueva fecha de inicio.',
    'warn_start_date_changed_not_sent' => 'La siguiente Factura se creará en la nueva fecha de inicio.',
    'original_start_date' => 'Fecha de inicio original',
    'new_start_date' => 'Nueva fecha de inicio',
    'security' => 'Seguridad',
    'see_whats_new' => 'Qué hay de nuevo en v:version',
    'wait_for_upload' => 'Por favor, espere a que se carge el documento.',
    'upgrade_for_permissions' => 'Actualicese a nuestro Plan Enterprise para habilitar permisos',
    'enable_second_tax_rate' => 'Habilitar la posibilidad de especificar un <b>segundo impuesto</b>',
    'payment_file' => 'Fichero de Pagos',
    'expense_file' => 'Fichero de Gastos',
    'product_file' => 'Fichero de Productos',
    'import_products' => 'Importar Productos',
    'products_will_create' => 'productos seran creados',
    'product_key' => 'Producto',
    'created_products' => ':count producto(s) creados/actualizados correctamente.',
    'export_help' => 'Utilice JSON si planea importar los datos en  Invoice Ninja.<br/>El fichero incluye clientes, productos, facturas, presupuestos y pagos.',
    'selfhost_export_help' => '<br/>Recomendamos usar mysqldump para crear una copia de seguridad completa.',
    'JSON_file' => 'Fichero JSON',

    'view_dashboard' => 'Ver Escritorio',
    'client_session_expired' => 'Sesión Caducada',
    'client_session_expired_message' => 'Su sesión a expirado. Por favor, pulse en el enlace de su correo de nuevo.',

    'auto_bill_notification' => 'Esta factura se facturará automáticamente en su :payment_method en el archivo el :due_date.',
    'auto_bill_payment_method_bank_transfer' => 'Cuenta Bancaria',
    'auto_bill_payment_method_credit_card' => 'Tarjeta de Crédito',
    'auto_bill_payment_method_paypal' => 'Cuenta PayPal',
    'auto_bill_notification_placeholder' => 'Esta factura se facturará automáticamente en su tarjeta de crédito en el archivo en la fecha de vencimiento.',
    'payment_settings' => 'Configuración de Pago',

    'on_send_date' => 'En la fecha de envío',
    'on_due_date' => 'En la fecha de vencimiento',
    'auto_bill_ach_date_help' => 'ACH siempre facturará automaticamente a fecha de vencimiento',
    'warn_change_auto_bill' => 'Debido a las reglas de NACHA, los cambios en esta factura pueden evitar la factura automática de ACH.',

    'bank_account' => 'Cuenta Bancaria',
    'payment_processed_through_wepay' => 'Los pagos ACH se procesaran usando WePay',
    'wepay_payment_tos_agree' => 'Estoy de acuerdo con los :terms y :privacy_policy de WePay.',
    'privacy_policy' => 'Política de Privacidad',
    'wepay_payment_tos_agree_required' => 'Debe de estar de acuerdo con los Términos de servicio y la Política de Privacidad de WePay.',
    'ach_email_prompt' => 'Por favor introduzca su dirección de correo:',
    'verification_pending' => 'Verificación Pendiente',

    'update_font_cache' => 'Por favor, refresque de nuevo la pagina para actualizar el cache de tipos de letra.',
    'more_options' => 'Mas opciones',
    'credit_card' => 'Tarjeta de Crédito',
    'bank_transfer' => 'Transferencia bancaria',
    'no_transaction_reference' => 'No hemos recibido la referencia de la transaccion de pago desde la pasarela.',
    'use_bank_on_file' => 'Usar Banco en fichero',
    'auto_bill_email_message' => 'Esta factura se cargará automáticamente en su tarjeta de crédito en el archivo en la fecha de vencimiento.',
    'bitcoin' => 'Bitcoin',
    'gocardless' => 'GoCardless',
    'added_on' => 'Añadido el :date',
    'failed_remove_payment_method' => 'Falló la eliminación del Método de pago',
    'gateway_exists' => 'Esta pasarela ya existe',
    'manual_entry' => 'Entrada manual',
    'start_of_week' => 'Primer día de la semana',

    // Frequencies
    'freq_inactive' => 'Inactivo',
    'freq_daily' => 'Diariamente',
    'freq_weekly' => 'Semanal',
    'freq_biweekly' => 'Quincenal',
    'freq_two_weeks' => 'Dos semanas',
    'freq_four_weeks' => 'Cuatro semanas',
    'freq_monthly' => 'Mensual',
    'freq_three_months' => 'Tres meses',
    'freq_four_months' => 'Cuatro meses',
    'freq_six_months' => 'Seis meses',
    'freq_annually' => 'Anual',
    'freq_two_years' => 'Dos Años',

    // Payment types
    'payment_type_Apply Credit' => 'Aplicar Crédito',
    'payment_type_Bank Transfer' => 'Transferencia bancaria',
    'payment_type_Cash' => 'Efectivo',
    'payment_type_Debit' => 'Débito',
    'payment_type_ACH' => 'ACH',
    'payment_type_Visa Card' => 'Tarjeta VISA',
    'payment_type_MasterCard' => 'MasterCard',
    'payment_type_American Express' => 'American Express',
    'payment_type_Discover Card' => 'Tarjeta Discover',
    'payment_type_Diners Card' => 'Tarjeta Diners',
    'payment_type_EuroCard' => 'EuroCard',
    'payment_type_Nova' => 'Nova',
    'payment_type_Credit Card Other' => 'Otras tarjetas de crédito',
    'payment_type_PayPal' => 'PayPal',
    'payment_type_Google Wallet' => 'Google Wallet',
    'payment_type_Check' => 'Cheque',
    'payment_type_Carte Blanche' => 'Carte Blanche',
    'payment_type_UnionPay' => 'UnionPay',
    'payment_type_JCB' => 'JCB',
    'payment_type_Laser' => 'Laser',
    'payment_type_Maestro' => 'Maestro',
    'payment_type_Solo' => 'Solo',
    'payment_type_Switch' => 'Switch',
    'payment_type_iZettle' => 'iZettle',
    'payment_type_Swish' => 'Swish',
    'payment_type_Alipay' => 'Alipay',
    'payment_type_Sofort' => 'Sofort',
    'payment_type_SEPA' => 'SEPA Direct Debit',
    'payment_type_Bitcoin' => 'Bitcoin',
    'payment_type_GoCardless' => 'GoCardless',
    'payment_type_Zelle' => 'Zelle',

    // Industries
    'industry_Accounting & Legal' => 'Contabilidad y legal',
    'industry_Advertising' => 'Publicidad',
    'industry_Aerospace' => 'Aerospacial',
    'industry_Agriculture' => 'Agricultura',
    'industry_Automotive' => 'Automoción',
    'industry_Banking & Finance' => 'Banca y finanzas',
    'industry_Biotechnology' => 'Biotecnología',
    'industry_Broadcasting' => 'Ciencias de la información',
    'industry_Business Services' => 'Servicios empresariales',
    'industry_Commodities & Chemicals' => 'Química y productos',
    'industry_Communications' => 'Comunicaciones',
    'industry_Computers & Hightech' => 'Informática y alta tecnología',
    'industry_Defense' => 'Defensa',
    'industry_Energy' => 'Energía',
    'industry_Entertainment' => 'Entretenimiento',
    'industry_Government' => 'Gubernamental',
    'industry_Healthcare & Life Sciences' => 'Sanidad y biología',
    'industry_Insurance' => 'Seguros',
    'industry_Manufacturing' => 'Producción',
    'industry_Marketing' => 'Marketing',
    'industry_Media' => 'Medios',
    'industry_Nonprofit & Higher Ed' => 'ONGs y educación superior',
    'industry_Pharmaceuticals' => 'Farmacéutico',
    'industry_Professional Services & Consulting' => 'Servicios profesionales y de consultoría',
    'industry_Real Estate' => 'Inmobiliario',
    'industry_Restaurant & Catering' => 'Restaurante & Catering',
    'industry_Retail & Wholesale' => 'Minorista y mayorista',
    'industry_Sports' => 'Deportes',
    'industry_Transportation' => 'Transporte',
    'industry_Travel & Luxury' => 'Viaje y ocio',
    'industry_Other' => 'Otro',
    'industry_Photography' => 'Fotografía',

    // Countries
    'country_Afghanistan' => 'Afganistán',
    'country_Albania' => 'Albania',
    'country_Antarctica' => 'Antarctica',
    'country_Algeria' => 'Algeria',
    'country_American Samoa' => 'American Samoa',
    'country_Andorra' => 'Andorra',
    'country_Angola' => 'Angola',
    'country_Antigua and Barbuda' => 'Antigua y Barbuda',
    'country_Azerbaijan' => 'Azerbaijan',
    'country_Argentina' => 'Argentina',
    'country_Australia' => 'Australia',
    'country_Austria' => 'Austria',
    'country_Bahamas' => 'Bahamas',
    'country_Bahrain' => 'Bahrain',
    'country_Bangladesh' => 'Bangladesh',
    'country_Armenia' => 'Armenia',
    'country_Barbados' => 'Barbados',
    'country_Belgium' => 'Belgica',
    'country_Bermuda' => 'Bermuda',
    'country_Bhutan' => 'Bhutan',
    'country_Bolivia, Plurinational State of' => 'Bolivia',
    'country_Bosnia and Herzegovina' => 'Bosnia Herzegovina',
    'country_Botswana' => 'Botswana',
    'country_Bouvet Island' => 'Bouvet Island',
    'country_Brazil' => 'Brasil',
    'country_Belize' => 'Belize',
    'country_British Indian Ocean Territory' => 'British Indian Ocean Territory',
    'country_Solomon Islands' => 'Solomon Islands',
    'country_Virgin Islands, British' => 'Virgin Islands, British',
    'country_Brunei Darussalam' => 'Brunei Darussalam',
    'country_Bulgaria' => 'Bulgaria',
    'country_Myanmar' => 'Myanmar',
    'country_Burundi' => 'Burundi',
    'country_Belarus' => 'Belarus',
    'country_Cambodia' => 'Cambodia',
    'country_Cameroon' => 'Cameroon',
    'country_Canada' => 'Canada',
    'country_Cape Verde' => 'Cabo Verde',
    'country_Cayman Islands' => 'Islas Cayman',
    'country_Central African Republic' => 'Republica Centro Africana',
    'country_Sri Lanka' => 'Sri Lanka',
    'country_Chad' => 'Chad',
    'country_Chile' => 'Chile',
    'country_China' => 'China',
    'country_Taiwan, Province of China' => 'Taiwan',
    'country_Christmas Island' => 'Christmas Island',
    'country_Cocos (Keeling) Islands' => 'Cocos (Keeling) Islands',
    'country_Colombia' => 'Colombia',
    'country_Comoros' => 'Comoros',
    'country_Mayotte' => 'Mayotte',
    'country_Congo' => 'Congo',
    'country_Congo, the Democratic Republic of the' => 'Republica Democratica del Congo',
    'country_Cook Islands' => 'Islas Cook ',
    'country_Costa Rica' => 'Costa Rica',
    'country_Croatia' => 'Croacia',
    'country_Cuba' => 'Cuba',
    'country_Cyprus' => 'Chipre',
    'country_Czech Republic' => 'Republica Checa',
    'country_Benin' => 'Benin',
    'country_Denmark' => 'Dinamarca',
    'country_Dominica' => 'Dominica',
    'country_Dominican Republic' => 'Republica Dominicana',
    'country_Ecuador' => 'Ecuador',
    'country_El Salvador' => 'El Salvador',
    'country_Equatorial Guinea' => 'Equatorial Guinea',
    'country_Ethiopia' => 'Etiopia',
    'country_Eritrea' => 'Eritrea',
    'country_Estonia' => 'Estonia',
    'country_Faroe Islands' => 'Islas Faroe',
    'country_Falkland Islands (Malvinas)' => 'Islas Falkland (Malvinas)',
    'country_South Georgia and the South Sandwich Islands' => 'Georgia del Sur e Islas Sandwich Sur',
    'country_Fiji' => 'Fiji',
    'country_Finland' => 'Finlandia',
    'country_Åland Islands' => 'Åland Islands',
    'country_France' => 'Francia',
    'country_French Guiana' => 'Guyana Francesa',
    'country_French Polynesia' => 'Polynesia Francesa',
    'country_French Southern Territories' => 'French Southern Territories',
    'country_Djibouti' => 'Djibouti',
    'country_Gabon' => 'Gabon',
    'country_Georgia' => 'Georgia',
    'country_Gambia' => 'Gambia',
    'country_Palestinian Territory, Occupied' => 'Territorios Ocupados de Palestina',
    'country_Germany' => 'Alemania',
    'country_Ghana' => 'Ghana',
    'country_Gibraltar' => 'Gibraltar',
    'country_Kiribati' => 'Kiribati',
    'country_Greece' => 'Grecia',
    'country_Greenland' => 'Groenlandia',
    'country_Grenada' => 'Granada',
    'country_Guadeloupe' => 'Guadalupe',
    'country_Guam' => 'Guam',
    'country_Guatemala' => 'Guatemala',
    'country_Guinea' => 'Guinea',
    'country_Guyana' => 'Guyana',
    'country_Haiti' => 'Haiti',
    'country_Heard Island and McDonald Islands' => 'Heard Island and McDonald Islands',
    'country_Holy See (Vatican City State)' => 'El Vaticano',
    'country_Honduras' => 'Honduras',
    'country_Hong Kong' => 'Hong Kong',
    'country_Hungary' => 'Hungary',
    'country_Iceland' => 'Isladia',
    'country_India' => 'India',
    'country_Indonesia' => 'Indonesia',
    'country_Iran, Islamic Republic of' => 'Republica Islamica de Iran',
    'country_Iraq' => 'Iraq',
    'country_Ireland' => 'Irlanda',
    'country_Israel' => 'Israel',
    'country_Italy' => 'Italia',
    'country_Côte d\'Ivoire' => 'Côte d\'Ivoire',
    'country_Jamaica' => 'Jamaica',
    'country_Japan' => 'Japon',
    'country_Kazakhstan' => 'Kazakhstan',
    'country_Jordan' => 'Jordan',
    'country_Kenya' => 'Kenya',
    'country_Korea, Democratic People\'s Republic of' => 'Republica Democratica de Korea del Norte',
    'country_Korea, Republic of' => 'Republica de Korea',
    'country_Kuwait' => 'Kuwait',
    'country_Kyrgyzstan' => 'Kyrgyzstan',
    'country_Lao People\'s Democratic Republic' => 'Republica Democratica de Lao',
    'country_Lebanon' => 'Libano',
    'country_Lesotho' => 'Lesotho',
    'country_Latvia' => 'Latvia',
    'country_Liberia' => 'Liberia',
    'country_Libya' => 'Libia',
    'country_Liechtenstein' => 'Liechtenstein',
    'country_Lithuania' => 'Lituania',
    'country_Luxembourg' => 'Luxemburgo',
    'country_Macao' => 'Macao',
    'country_Madagascar' => 'Madagascar',
    'country_Malawi' => 'Malawi',
    'country_Malaysia' => 'Malasia',
    'country_Maldives' => 'Maldivas',
    'country_Mali' => 'Mali',
    'country_Malta' => 'Malta',
    'country_Martinique' => 'Martinica',
    'country_Mauritania' => 'Mauritania',
    'country_Mauritius' => 'Mauritius',
    'country_Mexico' => 'Mexico',
    'country_Monaco' => 'Monaco',
    'country_Mongolia' => 'Mongolia',
    'country_Moldova, Republic of' => 'Republica de Moldavia',
    'country_Montenegro' => 'Montenegro',
    'country_Montserrat' => 'Montserrat',
    'country_Morocco' => 'Marruecos',
    'country_Mozambique' => 'Mozambique',
    'country_Oman' => 'Oman',
    'country_Namibia' => 'Namibia',
    'country_Nauru' => 'Nauru',
    'country_Nepal' => 'Nepal',
    'country_Netherlands' => 'Holanda',
    'country_Curaçao' => 'Curaçao',
    'country_Aruba' => 'Aruba',
    'country_Sint Maarten (Dutch part)' => 'San Martin (Parte holandesa)',
    'country_Bonaire, Sint Eustatius and Saba' => 'Bonaire, Sint Eustatius and Saba',
    'country_New Caledonia' => 'New Caledonia',
    'country_Vanuatu' => 'Vanuatu',
    'country_New Zealand' => 'Nueva Zelanda',
    'country_Nicaragua' => 'Nicaragua',
    'country_Niger' => 'Niger',
    'country_Nigeria' => 'Nigeria',
    'country_Niue' => 'Niue',
    'country_Norfolk Island' => 'Norfolk Island',
    'country_Norway' => 'Norway',
    'country_Northern Mariana Islands' => 'Northern Mariana Islands',
    'country_United States Minor Outlying Islands' => 'United States Minor Outlying Islands',
    'country_Micronesia, Federated States of' => 'Micronesia, Federated States of',
    'country_Marshall Islands' => 'Marshall Islands',
    'country_Palau' => 'Palau',
    'country_Pakistan' => 'Pakistan',
    'country_Panama' => 'Panama',
    'country_Papua New Guinea' => 'Papua New Guinea',
    'country_Paraguay' => 'Paraguay',
    'country_Peru' => 'Peru',
    'country_Philippines' => 'Filipinas',
    'country_Pitcairn' => 'Pitcairn',
    'country_Poland' => 'Polonia',
    'country_Portugal' => 'Portugal',
    'country_Guinea-Bissau' => 'Guinea-Bissau',
    'country_Timor-Leste' => 'Timor-Leste',
    'country_Puerto Rico' => 'Puerto Rico',
    'country_Qatar' => 'Qatar',
    'country_Réunion' => 'Réunion',
    'country_Romania' => 'Rumania',
    'country_Russian Federation' => 'Rusia',
    'country_Rwanda' => 'Rwanda',
    'country_Saint Barthélemy' => 'Saint Barthélemy',
    'country_Saint Helena, Ascension and Tristan da Cunha' => 'Saint Helena, Ascension and Tristan da Cunha',
    'country_Saint Kitts and Nevis' => 'Saint Kitts and Nevis',
    'country_Anguilla' => 'Anguilla',
    'country_Saint Lucia' => 'Saint Lucia',
    'country_Saint Martin (French part)' => 'Saint Martin (French part)',
    'country_Saint Pierre and Miquelon' => 'Saint Pierre and Miquelon',
    'country_Saint Vincent and the Grenadines' => 'Saint Vincent and the Grenadines',
    'country_San Marino' => 'San Marino',
    'country_Sao Tome and Principe' => 'Sao Tome and Principe',
    'country_Saudi Arabia' => 'Arabia Saudi ',
    'country_Senegal' => 'Senegal',
    'country_Serbia' => 'Serbia',
    'country_Seychelles' => 'Seychelles',
    'country_Sierra Leone' => 'Sierra Leona',
    'country_Singapore' => 'Singapore',
    'country_Slovakia' => 'Slovakia',
    'country_Viet Nam' => 'Viet Nam',
    'country_Slovenia' => 'Slovenia',
    'country_Somalia' => 'Somalia',
    'country_South Africa' => 'Sudáfrica',
    'country_Zimbabwe' => 'Zimbabwe',
    'country_Spain' => 'España',
    'country_South Sudan' => 'South Sudan',
    'country_Sudan' => 'Sudan',
    'country_Western Sahara' => 'Sahara Occidental',
    'country_Suriname' => 'Surinam',
    'country_Svalbard and Jan Mayen' => 'Svalbard and Jan Mayen',
    'country_Swaziland' => 'Swaziland',
    'country_Sweden' => 'Suecia',
    'country_Switzerland' => 'Suiza',
    'country_Syrian Arab Republic' => 'Syria',
    'country_Tajikistan' => 'Tajikistan',
    'country_Thailand' => 'Tailandia',
    'country_Togo' => 'Togo',
    'country_Tokelau' => 'Tokelau',
    'country_Tonga' => 'Tonga',
    'country_Trinidad and Tobago' => 'Trinidad y Tobago',
    'country_United Arab Emirates' => 'Emiratos Arabes Unidos',
    'country_Tunisia' => 'Tunez',
    'country_Turkey' => 'Turquia',
    'country_Turkmenistan' => 'Turkmenistan',
    'country_Turks and Caicos Islands' => 'Turks and Caicos Islands',
    'country_Tuvalu' => 'Tuvalu',
    'country_Uganda' => 'Uganda',
    'country_Ukraine' => 'Ucrania',
    'country_Macedonia, the former Yugoslav Republic of' => 'Republica de Macedonia',
    'country_Egypt' => 'Egipto',
    'country_United Kingdom' => 'Reino unido',
    'country_Guernsey' => 'Guernsey',
    'country_Jersey' => 'Jersey',
    'country_Isle of Man' => 'Isle of Man',
    'country_Tanzania, United Republic of' => 'Tanzania, United Republic of',
    'country_United States' => 'Estados unidos',
    'country_Virgin Islands, U.S.' => 'Virgin Islands, U.S.',
    'country_Burkina Faso' => 'Burkina Faso',
    'country_Uruguay' => 'Uruguay',
    'country_Uzbekistan' => 'Uzbekistan',
    'country_Venezuela, Bolivarian Republic of' => 'Venezuela',
    'country_Wallis and Futuna' => 'Wallis and Futuna',
    'country_Samoa' => 'Samoa',
    'country_Yemen' => 'Yemen',
    'country_Zambia' => 'Zambia',

    // Languages
    'lang_Brazilian Portuguese' => 'Portugués brasileño',
    'lang_Croatian' => 'Croata',
    'lang_Czech' => 'Checo',
    'lang_Danish' => 'Danés',
    'lang_Dutch' => 'Holandés',
    'lang_English' => 'Inglés',
    'lang_French' => 'Francés',
    'lang_French - Canada' => 'Francés canadiense',
    'lang_German' => 'Alemán',
    'lang_Italian' => 'Italiano',
    'lang_Japanese' => 'Japonés',
    'lang_Lithuanian' => 'Lituano',
    'lang_Norwegian' => 'Noruego',
    'lang_Polish' => 'Polaco',
    'lang_Spanish' => 'Español',
    'lang_Spanish - Spain' => 'Español - España',
    'lang_Swedish' => 'Sueco',
    'lang_Albanian' => 'Albanés',
    'lang_Greek' => 'Griego',
    'lang_English - United Kingdom' => 'Ingles - Reino Unido',
    'lang_English - Australia' => 'Inglés - Australia',
    'lang_Slovenian' => 'Eslovenia',
    'lang_Finnish' => 'Finlandia',
    'lang_Romanian' => 'Rumania',
    'lang_Turkish - Turkey' => 'Turco - Turquia',
    'lang_Portuguese - Brazilian' => 'Portugues - Brasil',
    'lang_Portuguese - Portugal' => 'Portugues - Portugal',
    'lang_Thai' => 'Tailandes',
    'lang_Macedonian' => 'Macedonio',
    'lang_Chinese - Taiwan' => 'Chino - Taiwan',
    'lang_Serbian' => 'Serbio',
    'lang_Bulgarian' => 'Búlgaro',
    'lang_Russian' => 'Russian',

    // Industries
    'industry_Accounting & Legal' => 'Contabilidad y legal',
    'industry_Advertising' => 'Publicidad',
    'industry_Aerospace' => 'Aerospacial',
    'industry_Agriculture' => 'Agricultura',
    'industry_Automotive' => 'Automoción',
    'industry_Banking & Finance' => 'Banca y finanzas',
    'industry_Biotechnology' => 'Biotecnología',
    'industry_Broadcasting' => 'Ciencias de la información',
    'industry_Business Services' => 'Servicios empresariales',
    'industry_Commodities & Chemicals' => 'Química y productos',
    'industry_Communications' => 'Comunicaciones',
    'industry_Computers & Hightech' => 'Informática y alta tecnología',
    'industry_Defense' => 'Defensa',
    'industry_Energy' => 'Energía',
    'industry_Entertainment' => 'Entretenimiento',
    'industry_Government' => 'Gubernamental',
    'industry_Healthcare & Life Sciences' => 'Sanidad y biología',
    'industry_Insurance' => 'Seguros',
    'industry_Manufacturing' => 'Producción',
    'industry_Marketing' => 'Marketing',
    'industry_Media' => 'Medios',
    'industry_Nonprofit & Higher Ed' => 'ONGs y educación superior',
    'industry_Pharmaceuticals' => 'Farmacéutico',
    'industry_Professional Services & Consulting' => 'Servicios profesionales y de consultoría',
    'industry_Real Estate' => 'Inmobiliario',
    'industry_Retail & Wholesale' => 'Minorista y mayorista',
    'industry_Sports' => 'Deportes',
    'industry_Transportation' => 'Transporte',
    'industry_Travel & Luxury' => 'Viaje y ocio',
    'industry_Other' => 'Otro',
    'industry_Photography' => 'Fotografía',

    'view_client_portal' => 'Ver portal de cliente',
    'view_portal' => 'Ver portal',
    'vendor_contacts' => 'Contactos de Proveedores',
    'all' => 'Todo',
    'selected' => 'Seleccionado',
    'category' => 'Categoría',
    'categories' => 'Categorias',
    'new_expense_category' => 'Nueva Categoría de Gasto',
    'edit_category' => 'Editar Categoría',
    'archive_expense_category' => 'Archivar Categoría',
    'expense_categories' => 'Categorías de Gasto',
    'list_expense_categories' => 'Listado de Categorias de Gasto',
    'updated_expense_category' => 'Categoría de gasto actualizada correctamente',
    'created_expense_category' => 'Categoría de gasto creada correctamente',
    'archived_expense_category' => 'Categoría de gasto archivada correctamente',
    'archived_expense_categories' => ':count categorías de gasto actualizados correctamente',
    'restore_expense_category' => 'Restaurar Categoría de Gasto',
    'restored_expense_category' => 'Categoría de Gasto restaurada correctamente',
    'apply_taxes' => 'Aplicar Impuestos',
    'min_to_max_users' => ':min a :max usuarios',
    'max_users_reached' => 'Se ha alcanzado el número máximo de usuarios',
    'buy_now_buttons' => 'Botones de Comprar Ahora',
    'landing_page' => 'Página Inicial',
    'payment_type' => 'Tipo de Pago',
    'form' => 'Formulario',
    'link' => 'Enlace',
    'fields' => 'Campos',
    'dwolla' => 'Dwolla',
    'buy_now_buttons_warning' => 'Nota: El cliente y la Factura se han creado aunque la operación no se ha completado',
    'buy_now_buttons_disabled' => 'Esta caracteristica requiere que el producto este creado y la pasarela de pago esté configurada',
    'enable_buy_now_buttons_help' => 'Habilitar el soporte para los botones de Comprar ahora',
    'changes_take_effect_immediately' => 'Nota: Los cambio tienen lugar inmediatamente',
    'wepay_account_description' => 'Pasarela de Pago para Invoice Ninja',
    'payment_error_code' => 'Hubo un error procesando el pago [:code]. Por favor, inténtelo de nuevo mas adelante.',
    'standard_fees_apply' => 'Cargos: 2.9%/1.2% [Tarjeta de Crédito/Transferencia Bancaria] + $0.30 por cargo correcto.',
    'limit_import_rows' => 'Los datos necesitan ser importados en bloques de :count filas o menos',
    'error_title' => 'Algo a ido mal.',
    'error_contact_text' => 'Si desea ayuda, envíenos un correo electrónico a :mailaddress',
    'no_undo' => 'Atención: esto no se puede deshacer.',
    'no_contact_selected' => 'Por favor seleccione un contacto',
    'no_client_selected' => 'Por favor seleccione un cliente',

    'gateway_config_error' => 'Puede ser útil establecer nuevas contraseñas o generar nuevas claves de API.',
    'payment_type_on_file' => ':type en fichero',
    'invoice_for_client' => 'Factura :invoice para :client',
    'intent_not_found' => 'Lo siento, no estoy seguro de lo que estás preguntando.',
    'intent_not_supported' => 'Lo siento, no puedo hacer eso.',
    'client_not_found' => 'No pude encontrar el cliente',
    'not_allowed' => 'Lo sentimos, no tienes los permisos necesarios',
    'bot_emailed_invoice' => 'Su factura ha sido enviada.',
    'bot_emailed_notify_viewed' => 'Te enviaré un correo electrónico cuando se vea.',
    'bot_emailed_notify_paid' => 'Te enviaré un correo electrónico cuando se pague.',
    'add_product_to_invoice' => 'Añadir 1 :product',
    'not_authorized' => 'No está autorizado',
    'bot_get_email' => '¡Hola! (wave) <br/>Gracias por probar el Bot Invoice Ninja. <br/>Necesitas crear una cuenta gratuita para usar este bot.<br/>Envíanme la dirección de correo electrónico de tu cuenta para comenzar.',
    'bot_get_code' => '¡Gracias! Le envié un correo electrónico con su código de seguridad.',
    'bot_welcome' => 'Eso es todo, tu cuenta está verificada.<br/>',
    'email_not_found' => 'No pude encontrar una cuenta disponible para :email',
    'invalid_code' => 'El código no es correcto',
    'security_code_email_subject' => 'Código de seguridad para Invoice Ninja Bot',
    'security_code_email_line1' => 'Este es su código de seguridad Invoice Ninja Bot.',
    'security_code_email_line2' => 'Nota: caducará en 10 minutos.',
    'bot_help_message' => 'Actualmente sopota: <br/>• Crear \ actualizar \ enviar por correo electrónico una factura <br/>• Lista de productos<br/>Por ejemplo:<br/> <i>bobina de factura para 2 boletos, establecer la fecha de vencimiento para el próximo jueves y el descuento para 10 por ciento</i>',
    'list_products' => 'Lista de Productos',

    'include_item_taxes_inline' => 'Incluir total del <b>impuesto para cada concepto de Factura</b>',
    'created_quotes' => 'Se ha(n) creado correctamente :count presupuesto(s)',
    'limited_gateways' => 'Nota: soportamos una pasarela de tarjeta de crédito por empresa.',

    'warning' => 'Advertencia',
    'self-update' => 'Actualizar',
    'update_invoiceninja_title' => 'Actualizar Invoice Ninja',
    'update_invoiceninja_warning' => '¡Antes de comenzar a actualizar Invoice Ninja cree una copia de seguridad de su base de datos y archivos!',
    'update_invoiceninja_available' => 'Está disponible una nueva versión de Invoice Ninja.',
    'update_invoiceninja_unavailable' => 'No hay ninguna versión nueva de Invoice Ninja.',
    'update_invoiceninja_instructions' => 'Instale la nueva versión <strong>:version</strong> haciendo clic en el botón <em>Actualizar ahora</em> a continuación. Luego, serás redirigido al Cuadro de Mandos.',
    'update_invoiceninja_update_start' => 'Actualizar ahora',
    'update_invoiceninja_download_start' => 'Descargar :version',
    'create_new' => 'Crear Nuevo',

    'toggle_navigation' => 'Alternar Navegación',
    'toggle_history' => 'Alternar Historial',
    'unassigned' => 'Sin asignar',
    'task' => 'Tarea',
    'contact_name' => 'Nombre del Contacto',
    'city_state_postal' => 'Ciudad / Provincia / C.Postal',
    'custom_field' => 'Campo personalizado',
    'account_fields' => 'Campos de la Empresa',
    'facebook_and_twitter' => 'Facebook y Twitter',
    'facebook_and_twitter_help' => 'Siga nuestros feeds para ayudar a respaldar nuestro proyecto',
    'reseller_text' => 'Nota: La Licencia de Marca Blanca está diseñada para uso personal. Envíenos un correo electrónico a :email si desea revender la aplicación.',
    'unnamed_client' => 'Cliente sin nombre',

    'day' => 'Día',
    'week' => 'Semana',
    'month' => 'Mes',
    'inactive_logout' => 'Has sido desconectado por inactividad',
    'reports' => 'Informes',
    'total_profit' => 'Beneficio Total',
    'total_expenses' => 'Gastos Totales',
    'quote_to' => 'Presupuesto para',

    // Limits
    'limit' => 'Límite',
    'min_limit' => 'Min: :min',
    'max_limit' => 'Max: :max',
    'no_limit' => 'Sin Límites',
    'set_limits' => 'Establecer los Límites de :gateway_type',
    'enable_min' => 'Activar Mínimo',
    'enable_max' => 'Activar Máximo',
    'min' => 'Mínimo',
    'max' => 'Máximo',
    'limits_not_met' => 'Esta factura no cumple con los límites para ese tipo de pago.',

    'date_range' => 'Rango de fechas',
    'raw' => 'Bruto',
    'raw_html' => 'HTML sin procesar',
    'update' => 'Actualizar',
    'invoice_fields_help' => 'Arrastre los campos para cambiarlos el orden y ubicación',
    'new_category' => 'Nueva Categoría',
    'restore_product' => 'Restaurar Presupuesto',
    'blank' => 'Vacio',
    'invoice_save_error' => 'Ha habido un error guardando la factura',
    'enable_recurring' => 'Habilitar facturas recurrentes',
    'disable_recurring' => 'Deshabilitar facturas recurrentes',
    'text' => 'Texto',
    'expense_will_create' => 'gasto se creará ',
    'expenses_will_create' => 'gastos se crearán ',
    'created_expenses' => ':count gastos creados correctamente',

    'translate_app' => 'Ayúdanos a mejorar nuestras traducciones con :link',
    'expense_category' => 'Categoría del Gasto',

    'go_ninja_pro' => '¡Hazte Pro!',
    'go_enterprise' => 'Hazte el Plan Enterprise!',
    'upgrade_for_features' => 'Actualizate para más características',
    'pay_annually_discount' => '¡Pague anualmente por 10 meses + 2 gratis!',
    'pro_upgrade_title' => 'Ninja Pro',
    'pro_upgrade_feature1' => 'TuMarca.InvoiceNinja.com',
    'pro_upgrade_feature2' => '¡Personaliza cada detalle de tu factura!',
    'enterprise_upgrade_feature1' => 'Establecer permisos para múltiples usuarios',
    'enterprise_upgrade_feature2' => 'Adjunte archivos de terceros a facturas y gastos',
    'much_more' => '¡Mucho mas!',
    'all_pro_fetaures' => 'Mas todas las caracteristicas Pro!',

    'currency_symbol' => 'Símbolo',
    'currency_code' => 'Código',

    'buy_license' => 'Comprar la licencia',
    'apply_license' => 'Renovar licencia',
    'submit' => 'Enviar',
    'white_label_license_key' => 'Número de licencia',
    'invalid_white_label_license' => 'La Licencia de Marca Blanca no es válida',
    'created_by' => 'Creado por :name',
    'modules' => 'Módulos',
    'financial_year_start' => 'Primer mes del año',
    'authentication' => 'Autenticación',
    'checkbox' => 'Casilla de verificación',
    'invoice_signature' => 'Firma',
    'show_accept_invoice_terms' => 'Mostrar aceptación de términos de la factura',
    'show_accept_invoice_terms_help' => 'Requerir que el cliente confirme que acepta los términos de la factura.',
    'show_accept_quote_terms' => 'Mostrar aceptación de términos del presupuesto',
    'show_accept_quote_terms_help' => 'Requerir que el cliente confirme que acepta los términos del presupuesto.',
    'require_invoice_signature' => 'Firma de la factura',
    'require_invoice_signature_help' => 'Requerir que el cliente proporcione su firma.',
    'require_quote_signature' => 'Firma del presupuesto.',
    'require_quote_signature_help' => 'Requerir que el cliente proporcione su firma.',
    'i_agree' => 'Estoy de acuerdo con los Términos',
    'sign_here' => 'Por favor firme aquí:',
    'authorization' => 'Autorización',
    'signed' => 'Frimado',

    // BlueVine
    'bluevine_promo' => 'Obtenga líneas de crédito comerciales flexibles y factoraje de facturas usando BlueVine.',
    'bluevine_modal_label' => 'Registrarse con BlueVine',
    'bluevine_modal_text' => '<h3>Financiamiento rápido para su negocio. Sin papeleo</h3>
<ul><li>Líneas de crédito flexibles y factoraje de facturas.</li></ul>',
    'bluevine_create_account' => 'Crea una cuenta',
    'quote_types' => 'Obtenga un presupuesto para',
    'invoice_factoring' => 'Factorización de facturas',
    'line_of_credit' => 'Línea de crédito',
    'fico_score' => 'Su puntuación FICO',
    'business_inception' => 'Fecha de inicio del negocio',
    'average_bank_balance' => 'Saldo promedio de la cuenta bancaria',
    'annual_revenue' => 'Ingresos anuales',
    'desired_credit_limit_factoring' => 'Límite deseado de factorización de factura',
    'desired_credit_limit_loc' => 'Límite deseado de línea de crédito ',
    'desired_credit_limit' => 'Límite deseado de crédito ',
    'bluevine_credit_line_type_required' => 'Debe elegir al menos uno',
    'bluevine_field_required' => 'Este campo es obligatorio',
    'bluevine_unexpected_error' => 'Ocurrió un error inesperado.',
    'bluevine_no_conditional_offer' => 'Se requiere más información antes de obtener un presupuesto . Haga clic en continuar',
    'bluevine_invoice_factoring' => 'Factorización de Facturas',
    'bluevine_conditional_offer' => 'Oferta Condicional',
    'bluevine_credit_line_amount' => 'Línea de Crédito',
    'bluevine_advance_rate' => 'Tasa de avance',
    'bluevine_weekly_discount_rate' => 'Tasa de descuento semanal',
    'bluevine_minimum_fee_rate' => 'Tarifa mínima',
    'bluevine_line_of_credit' => 'Línea de crédito',
    'bluevine_interest_rate' => 'Tasa de interés',
    'bluevine_weekly_draw_rate' => 'Tasa de Sorteo semanal',
    'bluevine_continue' => 'Ir a BlueVine',
    'bluevine_completed' => 'Registro en BlueVine completado',

    'vendor_name' => 'Proveedor',
    'entity_state' => 'Estado',
    'client_created_at' => 'Fecha de Creación',
    'postmark_error' => 'Hubo un problema al enviar el correo electrónico a través de Postmark: :link',
    'project' => 'Proyecto',
    'projects' => 'Proyectos',
    'new_project' => 'Nuevo Proyecto',
    'edit_project' => 'Editar Proyecto',
    'archive_project' => 'Archivar Proyecto',
    'list_projects' => 'Lista de Proyecto',
    'updated_project' => 'Proyecto actualizado correctamente',
    'created_project' => 'Proyecto creado correctamente',
    'archived_project' => 'Proyecto archivado correctamente',
    'archived_projects' => ':count proyectos archivados correctamente',
    'restore_project' => 'Restaurar Proyecto',
    'restored_project' => 'Proyecto restaurado correctamente',
    'delete_project' => 'Borrar Proyecto',
    'deleted_project' => 'Proyecto eliminado correctamente',
    'deleted_projects' => ':count proyecto eliminados correctamente',
    'delete_expense_category' => 'Borrar categoría',
    'deleted_expense_category' => 'Categoría eliminada correctamente',
    'delete_product' => 'Borrar Producto',
    'deleted_product' => 'Producto eliminado correctamente',
    'deleted_products' => ':count productos eliminados correctamente',
    'restored_product' => 'Producto restaurado correctamente',
    'update_credit' => 'Actualizar crédito',
    'updated_credit' => 'Crédito actualizado correctamente',
    'edit_credit' => 'Editar Crédito',
    'realtime_preview' => 'Previsualizar en tiempo real',
    'realtime_preview_help' => 'Actualización de la vista previa en PDF en tiempo real en la página de la factura al editarla.<br/>Desactive esta opción para mejorar el rendimiento al editar las facturas.',
    'live_preview_help' => 'Muestra una vista previa en PDF en vivo en la página de la factura.',
    'force_pdfjs_help' => 'Reemplace el visor de PDF incorporado en :chrome_link y :firefox_link. <br/>Habilítelo si su navegador descarga automáticamente el PDF.',
    'force_pdfjs' => 'Evitar la descarga',
    'redirect_url' => 'Redireccionar URL',
    'redirect_url_help' => 'Opcionalmente, especifique una URL para redirigir después de ingresar un pago.',
    'save_draft' => 'Guardar borrador',
    'refunded_credit_payment' => 'Pago de crédito reembolsado',
    'keyboard_shortcuts' => 'Atajos de teclado',
    'toggle_menu' => 'Alternar Menú',
    'new_...' => 'Nuevo...',
    'list_...' => 'Lista...',
    'created_at' => 'Fecha de Creación',
    'contact_us' => 'Contácte con Nosotros',
    'user_guide' => 'Guía del usuario',
    'promo_message' => 'Actualice antes de :expires y obtenga :amount OFF el primer año de nuestros paquetes Pro o Enterprise.',
    'discount_message' => ':amount caduca el :expires',
    'mark_paid' => 'Marcar como pagado',
    'marked_sent_invoice' => 'Factura marcada como enviada correctamente',
    'marked_sent_invoices' => 'Facturas marcadas como enviadas correctamente',
    'invoice_name' => 'Factura',
    'product_will_create' => 'producto sera creado',
    'contact_us_response' => '¡Gracias por tu mensaje! Intentaremos responder lo antes posible.',
    'last_7_days' => 'Los últimos 7 días',
    'last_30_days' => 'Los últimos 30 días',
    'this_month' => 'Este Mes',
    'last_month' => 'Último Mes',
    'current_quarter' => 'Cuatrimestre Actual',
    'last_quarter' => 'Trimestre Anterior',
    'last_year' => 'Último Año',
    'custom_range' => 'Rango personalizado',
    'url' => 'URL',
    'debug' => 'Debug',
    'https' => 'HTTPS',
    'require' => 'Requerido',
    'license_expiring' => 'Nota: su licencia expirará en :count días, :link para renovarla.',
    'security_confirmation' => 'Su dirección de correo electrónico ha sido confirmada.',
    'white_label_expired' => 'Su licencia de marca blanca ha expirado, considere renovarla para dar soporte a nuestro proyecto.',
    'renew_license' => 'Renovar licencia',
    'iphone_app_message' => 'Considera descargar nuestro :link',
    'iphone_app' => 'iPhone app',
    'android_app' => 'Android app',
    'logged_in' => 'Conectado',
    'switch_to_primary' => 'Cambie a su empresa principal (:name) para administrar su plan.',
    'inclusive' => 'Inclusivo',
    'exclusive' => 'Exclusivo',
    'postal_city_state' => 'C.Postal / Ciudad / Provincia',
    'phantomjs_help' => 'En ciertos casos, la aplicación usa :link_phantom para generar el PDF, instala :link_docs para generarlo localmente.',
    'phantomjs_local' => 'Usando PhantomJS en local',
    'client_number' => 'Código de Cliente',
    'client_number_help' => 'Especifique un prefijo o utilice un patrón a medida para establecer dinámicamente el número de cliente.',
    'next_client_number' => 'El siguiente Código de Cliente es :number.',
    'generated_numbers' => 'Números Generados',
    'notes_reminder1' => 'Primer Recordatorio',
    'notes_reminder2' => 'Segundo Recordatorio',
    'notes_reminder3' => 'Tercer Recordatorio',
    'notes_reminder4' => 'Recordatorio',
    'bcc_email' => 'BCC Email',
    'tax_quote' => 'Impuesto de Presupuesto',
    'tax_invoice' => 'Impuesto de Factura',
    'emailed_invoices' => 'Facturas enviadas correctamente',
    'emailed_quotes' => 'Presupuestos enviados correctamente',
    'website_url' => 'Website URL',
    'domain' => 'Dominio',
    'domain_help' => 'Se usa en el portal del cliente y al enviar correos electrónicos.',
    'domain_help_website' => 'Se usa al enviar correos electrónicos.',
    'import_invoices' => 'Importar Facturas',
    'new_report' => 'Nuevo Informe',
    'edit_report' => 'Editar Informe',
    'columns' => 'Columnas',
    'filters' => 'Filtros',
    'sort_by' => 'Ordenar por',
    'draft' => 'Borrador',
    'unpaid' => 'Impagado',
    'aging' => 'Envejecimiento',
    'age' => 'Edad',
    'days' => 'Días',
    'age_group_0' => '0 - 30 Días',
    'age_group_30' => '30 - 60 Días',
    'age_group_60' => '60 - 90 Días',
    'age_group_90' => '90 - 120 Días',
    'age_group_120' => '120+ Días',
    'invoice_details' => 'Detalles de Factura',
    'qty' => 'Cantidad',
    'profit_and_loss' => 'Ganancias y Pérdidas',
    'revenue' => 'Ingresos',
    'profit' => 'Beneficio',
    'group_when_sorted' => 'Orden por Grupo',
    'group_dates_by' => 'Agrupar fechas por',
    'year' => 'Año',
    'view_statement' => 'Ver Estado de cuenta',
    'statement' => 'Estado de cuenta',
    'statement_date' => 'Fecha de Estado de cuenta',
    'mark_active' => 'Marcar como Activo',
    'send_automatically' => 'Enviar Automáticamente',
    'initial_email' => 'Email Inicial',
    'invoice_not_emailed' => 'Esta factura no ha sido enviada.',
    'quote_not_emailed' => 'Este presupuesto no ha sido enviado.',
    'sent_by' => 'Enviado por :user',
    'recipients' => 'Destinatarios',
    'save_as_default' => 'Guardar como Por Defecto',
    'start_of_week_help' => 'Utilizado por selectores de <b>fecha</b>',
    'financial_year_start_help' => 'Utilizado por selectores de <b>rango de fecha</b>',
    'reports_help' => 'May + Click para ordenar por múltiples columnas, Ctrl + click para quitar agrupamiento.',
    'this_year' => 'Este Año',

    // Updated login screen
    'ninja_tagline' => 'Crea. Envia. Recibe tus Pagos.',
    'login_or_existing' => 'O inicie sesión con una cuenta existente.',
    'sign_up_now' => 'Registrarse Ahora',
    'not_a_member_yet' => '¿No eres miembro todavía?',
    'login_create_an_account' => 'Crea una Cuenta!',

    // New Client Portal styling
    'invoice_from' => 'Facturas desde:',
    'email_alias_message' => 'Requerimos que cada compañía tenga una dirección de correo electrónico única. <br/>Considere el uso de un alias. es decir, email+label@example.com',
    'full_name' => 'Nombre completo',
    'month_year' => 'MES/AÑO',
    'valid_thru' => 'Válido\nhasta',

    'product_fields' => 'Campos de Producto',
    'custom_product_fields_help' => 'Agregue un campo al crear un producto o factura y muestre la etiqueta y el valor en el PDF.',
    'freq_two_months' => 'Dos meses',
    'freq_yearly' => 'Anual',
    'profile' => 'Perfil',
    'payment_type_help' => 'Establece el <b>tipo de pago manual</b> predeterminado.',
    'industry_Construction' => 'Construcción',
    'your_statement' => 'Tu Estado de Cuenta',
    'statement_issued_to' => 'Estado de Cuenta emitido a',
    'statement_to' => 'Estado de Cuenta para',
    'customize_options' => 'Personalizar opciones',
    'created_payment_term' => 'Términos de pago creados correctamente',
    'updated_payment_term' => 'Términos de pago actualizados correctamente',
    'archived_payment_term' => 'Términos de pago archivados correctamente',
    'resend_invite' => 'Reenviar Invitación',
    'credit_created_by' => 'Crédito creado por el pago :transaction_reference',
    'created_payment_and_credit' => 'Pago y Crédito creado correctamente',
    'created_payment_and_credit_emailed_client' => 'Pago y Crédito creado y enviado al cliente correctamente',
    'create_project' => 'Crear Proyecto',
    'create_vendor' => 'Crear Proveedor',
    'create_expense_category' => 'Crear categoría',
    'pro_plan_reports' => ':link para habilitar informes uniéndose al Plan Pro',
    'mark_ready' => 'Marcar como listo',

    'limits' => 'Limites',
    'fees' => 'Cargos',
    'fee' => 'Cargo',
    'set_limits_fees' => 'Establecer los Límites/Cargos de :gateway_type',
    'fees_tax_help' => 'Habilite los impuestos de línea para establecer las tasas de impuestos de tarifa.',
    'fees_sample' => 'La tarifa por una factura de cantidad :amount sería :total.',
    'discount_sample' => 'El descuento por una factura de cantidad :amount sería :total.',
    'no_fees' => 'Sin cargos',
    'gateway_fees_disclaimer' => 'Advertencia: no todos los estados / pasarelas de pago permiten agregar tarifas, revise las leyes locales / términos de servicio.',
    'percent' => 'Porcentaje',
    'location' => 'Ubicación',
    'line_item' => 'Linea de Concepto',
    'surcharge' => 'Recargo',
    'location_first_surcharge' => 'Habilitado - Primer recargo',
    'location_second_surcharge' => 'Habilitado - Segundo recargo',
    'location_line_item' => 'Habilitado - Linea de Concepto',
    'online_payment_surcharge' => 'Recargo por Pago Online ',
    'gateway_fees' => 'Tasas de pasarela',
    'fees_disabled' => 'Las tarifas están deshabilitadas',
    'gateway_fees_help' => 'Agregue automáticamente un recargo/descuento de pago en línea.',
    'gateway' => 'Pasarela',
    'gateway_fee_change_warning' => 'Si hay facturas sin pagar con tarifas, deben actualizarse manualmente.',
    'fees_surcharge_help' => 'Personalizar recargo :link.',
    'label_and_taxes' => 'etiquetas e impuestos',
    'billable' => 'Facturable',
    'logo_warning_too_large' => 'El archivo de imagen es demasiado grande.',
    'logo_warning_fileinfo' => 'Advertencia: para admitir gifs, la extensión PHP fileinfo necesita estar habilitada.',
    'logo_warning_invalid' => 'Hubo un problema al leer el archivo de imagen, intente con un formato diferente.',

    'error_refresh_page' => 'Se produjo un error, actualice la página y vuelva a intentarlo.',
    'data' => 'Datos',
    'imported_settings' => 'Configuración importada correctamente',
    'reset_counter' => 'Reiniciar Contador',
    'next_reset' => 'Proximo Reinicio',
    'reset_counter_help' => 'Restablece automáticamente los contadores de facturas y  presupuestos.',
    'auto_bill_failed' => 'Fallo la Facturación automática de la factura :invoice_number',
    'online_payment_discount' => 'Descuento por Pago Online',
    'created_new_company' => 'Compañia creada correctamente',
    'fees_disabled_for_gateway' => 'Las tarifas están deshabilitadas para esta pasarela.',
    'logout_and_delete' => 'Cerrar sesión / Eliminar cuenta',
    'tax_rate_type_help' => 'Las tasas impositivas incluyentes ajustan el costo de la línea de pedido cuando se seleccionan. <br/>Solo se pueden usar tasas de impuestos exclusivas como predeterminadas.',
    'invoice_footer_help' => 'Use $pageNumber y $pageCount para mostrar la información de la página.',
    'credit_note' => 'Nota de Crédito',
    'credit_issued_to' => 'Crédito emitido a',
    'credit_to' => 'Crédito para',
    'your_credit' => 'Su Crédito',
    'credit_number' => 'Código de Crédito',
    'create_credit_note' => 'Crear Nota de Crédito',
    'menu' => 'Menu',
    'error_incorrect_gateway_ids' => 'Error: la tabla de pasarelas tiene identificadores incorrectos.',
    'purge_data' => 'Purgar Datos',
    'delete_data' => 'Borrar Datos',
    'purge_data_help' => 'Eliminar permanentemente todos los datos pero mantener la cuenta y la configuración.',
    'cancel_account_help' => 'Eliminar permanentemente la cuenta junto con todos los datos y la configuración.',
    'purge_successful' => 'Datos de la empresa purgados correctamente',
    'forbidden' => 'Prohibido',
    'purge_data_message' => 'Advertencia: Esto borrará definitivamente sus datos, no hay deshacer.',
    'contact_phone' => 'Teléfono del Contacto',
    'contact_email' => 'Email del Contacto',
    'reply_to_email' => 'Direccion Email de Respuesta',
    'reply_to_email_help' => 'Especifique la dirección de respuesta para los correos electrónicos de los clientes.',
    'bcc_email_help' => 'En privado, incluya esta dirección con los correos electrónicos de los clientes.',
    'import_complete' => 'Su importación se ha completado correctamente.',
    'confirm_account_to_import' => 'Por favor, confirme su cuenta para importar datos.',
    'import_started' => 'Su importación ha comenzado, le enviaremos un correo electrónico una vez que se complete.',
    'listening' => 'Escuchando...',
    'microphone_help' => 'Diga "nueva factura para [cliente]" o "muéstreme los pagos archivados de [cliente]"',
    'voice_commands' => 'Comandos de voz',
    'sample_commands' => 'Comandos de ejemplo',
    'voice_commands_feedback' => 'Estamos trabajando activamente para mejorar esta función, si hay un comando que le gustaría que admitamos, envíenos un correo electrónico a :email.',
    'payment_type_Venmo' => 'Venmo',
    'payment_type_Money Order' => 'Giro postal',
    'archived_products' => ':count productos archivados correctamente',
    'recommend_on' => 'Recomendamos <b>habilitar</b> esta configuración.',
    'recommend_off' => 'Recomendamos <b>deshabilitar</b> esta configuración.',
    'notes_auto_billed' => 'Auto-facturado',
    'surcharge_label' => 'Etiqueta de Recargo',
    'contact_fields' => 'Campos del contacto',
    'custom_contact_fields_help' => 'Añadir un campo al crear un Contacto y opcionalmente mostrar la etiqueta y su valor en el PDF.',
    'datatable_info' => 'Mostrando de :start a :end de :total entradas',
    'credit_total' => 'Crédito Total',
    'mark_billable' => 'Marcar como  Facturable',
    'billed' => 'Facturado',
    'company_variables' => 'Variables de la compañía',
    'client_variables' => 'Variables del cliente',
    'invoice_variables' => 'Variables de la factura',
    'navigation_variables' => 'Variables de navegación',
    'custom_variables' => 'Variables personalizadas',
    'invalid_file' => 'Tipo de archivo inválido',
    'add_documents_to_invoice' => 'Agregar documentos a la factura',
    'mark_expense_paid' => 'Marcar como pagado',
    'white_label_license_error' => 'Error al validar la licencia, verifique "/storage/logs/laravel-error.log" para más detalles.',
    'plan_price' => 'Precio del plan',
    'wrong_confirmation' => 'Código de confirmación incorrecto',
    'oauth_taken' => 'La cuenta ya está registrada',
    'emailed_payment' => 'Pago enviado correctamente por correo electrónico',
    'email_payment' => 'Pago por correo electrónico',
    'invoiceplane_import' => 'Use :link para migrar sus datos desde InvoicePlane.',
    'duplicate_expense_warning' => 'ADVERTENCIA: Este :link puede ser un duplicado',
    'expense_link' => 'Gasto',
    'resume_task' => 'Reanudar tarea',
    'resumed_task' => 'La tarea se reanudó correctamente',
    'quote_design' => 'Diseños del presupuesto',
    'default_design' => 'Diseño estándar',
    'custom_design1' => 'Diseño personalizado 1',
    'custom_design2' => 'Diseño personalizado 2',
    'custom_design3' => 'Diseño personalizado 3',
    'empty' => 'Vacío',
    'load_design' => 'Cargar diseño',
    'accepted_card_logos' => 'Logotipos de tarjetas aceptadas',
    'phantomjs_local_and_cloud' => 'Usando PhantomJS local, volviendo a phantomjscloud.com',
    'google_analytics' => 'Google Analytics',
    'analytics_key' => 'Analytics Key',
    'analytics_key_help' => 'Seguimiento de pagos usando :link',
    'start_date_required' => 'La fecha de inicio es obligatoria',
    'application_settings' => 'Configuración de la Aplicación',
    'database_connection' => 'Conexión de la base de datos',
    'driver' => 'Driver',
    'host' => 'Host',
    'database' => 'Base de datos',
    'test_connection' => 'Probar Conexión',
    'from_name' => 'Nombre De',
    'from_address' => 'Email De',
    'port' => 'Puerto',
    'encryption' => 'Encriptación',
    'mailgun_domain' => 'Dominio Mailgun',
    'mailgun_private_key' => 'Mailgun Private Key',
    'send_test_email' => 'Enviar email de prueba',
    'select_label' => 'Seleccionar etiqueta',
    'label' => 'Etiqueta',
    'service' => 'Servicio',
    'update_payment_details' => 'Actualizar detalles de pago',
    'updated_payment_details' => 'Se actualizaron correctamente los detalles de pago',
    'update_credit_card' => 'Actualizar Tarjeta de crédito',
    'recurring_expenses' => 'Gastos Periódicos',
    'recurring_expense' => 'Gasto Periódico',
    'new_recurring_expense' => 'Nuevo Gasto Periódico',
    'edit_recurring_expense' => 'Editar Gasto Periódico',
    'archive_recurring_expense' => 'Archivar Gasto Periódico',
    'list_recurring_expense' => 'Lista de Gastos Periódicos',
    'updated_recurring_expense' => 'Gasto Periódico actualizado correctamente',
    'created_recurring_expense' => 'Gasto Periódico creado correctamente',
    'archived_recurring_expense' => 'Gasto Periódico archivado correctamente',
    'restore_recurring_expense' => 'Restaurar Gasto Periódico',
    'restored_recurring_expense' => 'Gasto Periódico restaurado correctamente',
    'delete_recurring_expense' => 'Borrar Gasto Periódico',
    'deleted_recurring_expense' => 'Gasto Periódico borrado correctamente',
    'view_recurring_expense' => 'Ver Gasto Periódico',
    'taxes_and_fees' => 'Impuestos y cargos',
    'import_failed' => 'Error de Importación',
    'recurring_prefix' => 'Prefijo Recurrente',
    'options' => 'Opciones',
    'credit_number_help' => 'Especifique un prefijo o use un patrón personalizado para establecer dinámicamente el número de crédito para las facturas negativas.',
    'next_credit_number' => 'El siguiente identificador de crédito es :number.',
    'padding_help' => 'El número de ceros para rellenar el número.',
    'import_warning_invalid_date' => 'Advertencia: el formato de fecha parece ser inválido.',
    'product_notes' => 'Notas de Producto',
    'app_version' => 'Version de aplicacion',
    'ofx_version' => 'Version de OFX ',
    'gateway_help_23' => ':link para obtener tus claves de Stripe API.',
    'error_app_key_set_to_default' => 'Error: APP_KEY se establece en un valor predeterminado, para actualizarlo haga una copia de seguridad de su base de datos y luego ejecute <code>php artisan ninja:update-key</code>',
    'charge_late_fee' => 'Cargo por tardanza',
    'late_fee_amount' => 'Cargo por pago atrasado',
    'late_fee_percent' => 'Porcentaje por pago atrasado',
    'late_fee_added' => 'Cargo por retraso agregado en :date',
    'download_invoice' => 'Descargar Factura',
    'download_quote' => 'Descargar Presupuesto',
    'invoices_are_attached' => 'Sus archivos PDF de facturas se adjuntaron.',
    'downloaded_invoice' => 'Se enviará un correo electrónico con la factura en PDF',
    'downloaded_quote' => 'Se enviará un correo electrónico con el presupuesto en PDF',
    'downloaded_invoices' => 'Se enviará un correo electrónico con la factura en PDF',
    'downloaded_quotes' => 'Se enviará un correo electrónico con el presupuesto en PDF',
    'clone_expense' => 'Clonar Gasto',
    'default_documents' => 'Documents por defecto',
    'send_email_to_client' => 'Enviar email al cliente',
    'refund_subject' => 'Reembolso procesado',
    'refund_body' => 'Se ha procesado un reembolso de :amount por la factura :invoice_number.',

    'currency_us_dollar' => 'Dólar estadounidense',
    'currency_british_pound' => 'Libra británica',
    'currency_euro' => 'Euro',
    'currency_south_african_rand' => 'South African Rand',
    'currency_danish_krone' => 'Danish Krone',
    'currency_israeli_shekel' => 'Israeli Shekel',
    'currency_swedish_krona' => 'Swedish Krona',
    'currency_kenyan_shilling' => 'Kenyan Shilling',
    'currency_canadian_dollar' => 'Canadian Dollar',
    'currency_philippine_peso' => 'Philippine Peso',
    'currency_indian_rupee' => 'Indian Rupee',
    'currency_australian_dollar' => 'Australian Dollar',
    'currency_singapore_dollar' => 'Singapore Dollar',
    'currency_norske_kroner' => 'Norske Kroner',
    'currency_new_zealand_dollar' => 'New Zealand Dollar',
    'currency_vietnamese_dong' => 'Vietnamese Dong',
    'currency_swiss_franc' => 'Swiss Franc',
    'currency_guatemalan_quetzal' => 'Guatemalan Quetzal',
    'currency_malaysian_ringgit' => 'Malaysian Ringgit',
    'currency_brazilian_real' => 'Brazilian Real',
    'currency_thai_baht' => 'Thai Baht',
    'currency_nigerian_naira' => 'Nigerian Naira',
    'currency_argentine_peso' => 'Argentine Peso',
    'currency_bangladeshi_taka' => 'Bangladeshi Taka',
    'currency_united_arab_emirates_dirham' => 'United Arab Emirates Dirham',
    'currency_hong_kong_dollar' => 'Hong Kong Dollar',
    'currency_indonesian_rupiah' => 'Indonesian Rupiah',
    'currency_mexican_peso' => 'Mexican Peso',
    'currency_egyptian_pound' => 'Egyptian Pound',
    'currency_colombian_peso' => 'Colombian Peso',
    'currency_west_african_franc' => 'West African Franc',
    'currency_chinese_renminbi' => 'Renminbi Chino',
    'currency_rwandan_franc' => 'Rwandan Franc',
    'currency_tanzanian_shilling' => 'Tanzanian Shilling',
    'currency_netherlands_antillean_guilder' => 'Netherlands Antillean Guilder',
    'currency_trinidad_and_tobago_dollar' => 'Trinidad and Tobago Dollar',
    'currency_east_caribbean_dollar' => 'East Caribbean Dollar',
    'currency_ghanaian_cedi' => 'Ghanaian Cedi',
    'currency_bulgarian_lev' => 'Bulgarian Lev',
    'currency_aruban_florin' => 'Aruban Florin',
    'currency_turkish_lira' => 'Turkish Lira',
    'currency_romanian_new_leu' => 'Romanian New Leu',
    'currency_croatian_kuna' => 'Croatian Kuna',
    'currency_saudi_riyal' => 'Saudi Riyal',
    'currency_japanese_yen' => 'Japanese Yen',
    'currency_maldivian_rufiyaa' => 'Maldivian Rufiyaa',
    'currency_costa_rican_colon' => 'Costa Rican Colón',
    'currency_pakistani_rupee' => 'Pakistani Rupee',
    'currency_polish_zloty' => 'Polish Zloty',
    'currency_sri_lankan_rupee' => 'Sri Lankan Rupee',
    'currency_czech_koruna' => 'Czech Koruna',
    'currency_uruguayan_peso' => 'Uruguayan Peso',
    'currency_namibian_dollar' => 'Namibian Dollar',
    'currency_tunisian_dinar' => 'Tunisian Dinar',
    'currency_russian_ruble' => 'Russian Ruble',
    'currency_mozambican_metical' => 'Mozambican Metical',
    'currency_omani_rial' => 'Omani Rial',
    'currency_ukrainian_hryvnia' => 'Ukrainian Hryvnia',
    'currency_macanese_pataca' => 'Macanese Pataca',
    'currency_taiwan_new_dollar' => 'Taiwan New Dollar',
    'currency_dominican_peso' => 'Dominican Peso',
    'currency_chilean_peso' => 'Chilean Peso',
    'currency_icelandic_krona' => 'Icelandic Króna',
    'currency_papua_new_guinean_kina' => 'Papua New Guinean Kina',
    'currency_jordanian_dinar' => 'Jordanian Dinar',
    'currency_myanmar_kyat' => 'Myanmar Kyat',
    'currency_peruvian_sol' => 'Peruvian Sol',
    'currency_botswana_pula' => 'Botswana Pula',
    'currency_hungarian_forint' => 'Hungarian Forint',
    'currency_ugandan_shilling' => 'Ugandan Shilling',
    'currency_barbadian_dollar' => 'Barbadian Dollar',
    'currency_brunei_dollar' => 'Brunei Dollar',
    'currency_georgian_lari' => 'Georgian Lari',
    'currency_qatari_riyal' => 'Qatari Riyal',
    'currency_honduran_lempira' => 'Lempira Hondureña',
    'currency_surinamese_dollar' => 'Dólar Surinamés',
    'currency_bahraini_dinar' => 'Dinar Bareiní',
    'currency_venezuelan_bolivars' => 'Bolívares Venezolanos',
    'currency_south_korean_won' => 'Won Surcoreano',
    'currency_moroccan_dirham' => 'Dírham Marroquí',
    'currency_jamaican_dollar' => 'Dólar Jamaicano',
    'currency_angolan_kwanza' => 'Kwanza Angoleño',
    'currency_haitian_gourde' => 'Gourde Haitiano',
    'currency_zambian_kwacha' => 'Kwacha Zambiano',
    'currency_nepalese_rupee' => 'Rupia Nepalí',
    'currency_cfp_franc' => 'Franco CFP',
    'currency_mauritian_rupee' => 'Rupia de Mauricio',
    'currency_cape_verdean_escudo' => 'Escudo Caboverdiano',
    'currency_kuwaiti_dinar' => 'Dinar Kuwaití',
    'currency_algerian_dinar' => 'Dinar Argelino',
    'currency_macedonian_denar' => 'Dinar Macedonio',
    'currency_fijian_dollar' => 'Dólar Fiyiano',
    'currency_bolivian_boliviano' => 'Boliviano',
    'currency_albanian_lek' => 'Lek albanés',
    'currency_serbian_dinar' => 'Dinar serbio',
    'currency_lebanese_pound' => 'Libra libanesa',
    'currency_armenian_dram' => 'Dram armenio',
    'currency_azerbaijan_manat' => 'Manat azerbaiyano',
    'currency_bosnia_and_herzegovina_convertible_mark' => 'Marco convertible de Bosnia y Herzegovina',
    'currency_belarusian_ruble' => 'Rublo bielorruso',
    'currency_moldovan_leu' => 'Leu moldavo',
    'currency_kazakhstani_tenge' => 'Tenge kazajo',
    'currency_gibraltar_pound' => 'Libra de Gibraltar',

    'review_app_help' => 'Esperamos que estés disfrutando con la app. <br/>Si consideras :link ¡te lo agraderemos enormemente!',
    'writing_a_review' => 'escribir una reseña',

    'use_english_version' => 'Asegúrese de usar la versión en inglés de los archivos. <br/>Usamos los encabezados de las columnas para que coincidan con los campos.',
    'tax1' => 'Primer impuesto',
    'tax2' => 'Segundo impuesto',
    'fee_help' => 'Las tarifas de Gateway son los costos que se cobran por el acceso a las redes financieras que manejan el procesamiento de pagos en línea.',
    'format_export' => 'Formato de exportación',
    'custom1' => 'Primera personalización',
    'custom2' => 'Segunda personalización',
    'contact_first_name' => 'Nombre del Contacto',
    'contact_last_name' => 'Apellido del contacto',
    'contact_custom1' => 'Contacto Primer personalizado',
    'contact_custom2' => 'Contacto Segundo personalizado',
    'currency' => 'Divisa',
    'ofx_help' => 'Para resolver problemas consulta los comentarios en :ofxhome_link y para testear en :ofxget_link.',
    'comments' => 'Comentarios',

    'item_product' => 'Producto del artículo',
    'item_notes' => 'Notas del artículo',
    'item_cost' => 'Coste del artículo',
    'item_quantity' => 'Cantidad del artículo',
    'item_tax_rate' => 'Tasa de impuesto al artículo',
    'item_tax_name' => 'Nombre del impuesto del artículo',
    'item_tax1' => 'Impuesto de artículo 1',
    'item_tax2' => 'Impuesto de artículo 2',

    'delete_company' => 'Borrar Compañía',
    'delete_company_help' => 'Eliminar permanentemente la empresa junto con todos los datos y ajustes.',
    'delete_company_message' => 'Advertencia: esto eliminará definitivamente su empresa, no hay deshacer.',

    'applied_discount' => 'El cupón se ha aplicado, el precio del plan se ha reducido en :discount%.',
    'applied_free_year' => 'El cupón se aplicó, su cuenta se actualizó a profesional por un año.',

    'contact_us_help' => 'Si informa un error, incluya todos los registros relevantes de "/storage/logs/laravel-error.log"',
    'include_errors' => 'Incluir errores',
    'include_errors_help' => 'Incluir :link de "/storage/logs/laravel-error.log"',
    'recent_errors' => 'errores recientes',
    'customer' => 'Cliente',
    'customers' => 'Clientes',
    'created_customer' => 'Cliente creado correctamente',
    'created_customers' => ':count clientes creados correctamente',

    'purge_details' => 'Los datos en su empresa (:account) se han purgado satisfactoriamente.',
    'deleted_company' => 'Empresa borrada satisfactoriamente',
    'deleted_account' => 'Cuenta cancelada satisfactoriamente',
    'deleted_company_details' => 'Su empresa (:account) se ha eliminado correctamente.',
    'deleted_account_details' => 'Su cuenta (:account) se ha eliminado correctamente.',

    'alipay' => 'Alipay',
    'sofort' => 'Sofort',
    'sepa' => 'SEPA Direct Debit',
    'enable_alipay' => 'Aceptar Alipay',
    'enable_sofort' => 'Aceptar transferencias bancarias de la UE',
    'stripe_alipay_help' => 'Estas pasarelas también deben activarse en :link.',
    'calendar' => 'Calendario',
    'pro_plan_calendar' => ':link para habilitar calendario uniéndose al Plan Pro',

    'what_are_you_working_on' => '¿En que estas trabajando?',
    'time_tracker' => 'Time Tracker',
    'refresh' => 'Refrescar',
    'filter_sort' => 'Filtrar/Ordenar',
    'no_description' => 'Sin Descripción',
    'time_tracker_login' => 'Time Tracker Login',
    'save_or_discard' => 'Guarde o descarte sus cambios',
    'discard_changes' => 'Descartar los cambios',
    'tasks_not_enabled' => 'Las tareas no están habilitadas.',
    'started_task' => 'Tarea empezada correctamente',
    'create_client' => 'Crear cliente',

    'download_desktop_app' => 'Descargue la aplicación de escritorio',
    'download_iphone_app' => 'Descargue la aplicación de iPhone ',
    'download_android_app' => 'Descargue la aplicación de Android ',
    'time_tracker_mobile_help' => 'Toca dos veces una tarea para seleccionarla',
    'stopped' => 'Parado',
    'ascending' => 'Ascendente',
    'descending' => 'Descendente',
    'sort_field' => 'Ordenar por',
    'sort_direction' => 'Dirección',
    'discard' => 'Descartar',
    'time_am' => 'AM',
    'time_pm' => 'PM',
    'time_mins' => 'mins',
    'time_hr' => 'hr',
    'time_hrs' => 'hrs',
    'clear' => 'Limpiar',
    'warn_payment_gateway' => 'Nota: la aceptación de pagos en línea requiere una puerta de enlace de pago, enlace para agregar uno.',
    'task_rate' => 'Tasa de tareas',
    'task_rate_help' => 'Indique el ratio por defecto para las tareas facturadas.',
    'past_due' => 'Vencido',
    'document' => 'Documento',
    'invoice_or_expense' => 'Factura/Gasto',
    'invoice_pdfs' => 'PDFs de facturas',
    'enable_sepa' => 'Aceptar SEPA',
    'enable_bitcoin' => 'Aceptar Bitcoin',
    'iban' => 'IBAN',
    'sepa_authorization' => 'Al proporcionar su IBAN y confirmar este pago, usted está autorizando a :company y Stripe, nuestro proveedor de servicios de pago, a enviar instrucciones a su banco para cargar su cuenta y su banco para debitar su cuenta de acuerdo con esas instrucciones. Tiene derecho a un reembolso de su banco en los términos y condiciones de su acuerdo con su banco. Se debe reclamar un reembolso dentro de las 8 semanas a partir de la fecha en que se debitó su cuenta.',
    'recover_license' => 'Recuperar licencia',
    'purchase' => 'Compra',
    'recover' => 'Recuperar',
    'apply' => 'Aplicar',
    'recover_white_label_header' => 'Recuperar licencia de Marca Blanca',
    'apply_white_label_header' => 'Aplicar licencia de Marca Blanca',
    'videos' => 'Videos',
    'video' => 'Video',
    'return_to_invoice' => 'Regresar a la factura',
    'gateway_help_13' => 'Para usar ITN, deje el campo Clave de PDT en blanco.',
    'partial_due_date' => 'Fecha de vencimiento parcial',
    'task_fields' => 'Campos de las Tareas',
    'product_fields_help' => 'Arrastre los campos para cambiar su orden',
    'custom_value1' => 'Valor Personalizado',
    'custom_value2' => 'Valor Personalizado',
    'enable_two_factor' => 'Autenticacion en dos pasos',
    'enable_two_factor_help' => 'Utiliza tu telefono para confirmar tu identidad cuando te conectes',
    'two_factor_setup' => 'Configuracion de Autenticacion en dos pasos',
    'two_factor_setup_help' => 'Escanea el codigo de barras con una :link aplicacion compatible',
    'one_time_password' => 'Password de un solo uso',
    'set_phone_for_two_factor' => 'Indica tu teléfono movil como backup para activar.',
    'enabled_two_factor' => 'Autenticacion en dos pasos habilitada correctamente',
    'add_product' => 'Añadir Producto',
    'email_will_be_sent_on' => 'Nota: el correo se enviará el :date.',
    'invoice_product' => 'Producto de Factura',
    'self_host_login' => 'Self-Host Login',
    'set_self_hoat_url' => 'Self-Host URL',
    'local_storage_required' => 'Error: almacenaje local no disponible.',
    'your_password_reset_link' => 'Enlace para reiniciar su password',
    'subdomain_taken' => 'El subdominio ya está en uso',
    'client_login' => 'Acceso de Clientes',
    'converted_amount' => 'Cuenta convertida',
    'default' => 'Por defecto',
    'shipping_address' => 'Direccion de Envio',
    'bllling_address' => 'Dirección de Facturación',
    'billing_address1' => 'Calle de Facturacion',
    'billing_address2' => 'Piso de Facturacion',
    'billing_city' => 'Ciudad de Facturacion',
    'billing_state' => 'Provincia de Facturacion',
    'billing_postal_code' => 'Cod. Postal de Facturacion',
    'billing_country' => 'Pais de Facturacion',
    'shipping_address1' => 'Calle de Envio',
    'shipping_address2' => 'Piso de Envio',
    'shipping_city' => 'Ciudad de Envio',
    'shipping_state' => 'Provincia de Envio',
    'shipping_postal_code' => 'Cod. Postal de Envio',
    'shipping_country' => 'Pais de Envio',
    'classify' => 'Clasificar',
    'show_shipping_address_help' => 'Requerir al cliente que indique su dirección de envio',
    'ship_to_billing_address' => 'Enviar a la Dirección de Facturación',
    'delivery_note' => 'Nota para el envio',
    'show_tasks_in_portal' => 'Mostrar tareas en el Portal del Cliente',
    'cancel_schedule' => 'Cancelar Programacion',
    'scheduled_report' => 'Informe Programado',
    'scheduled_report_help' => 'Enviar por correo el informe :report como :format a :email',
    'created_scheduled_report' => 'Informe Programado correctamente',
    'deleted_scheduled_report' => 'Informe Programado cancelado correctamente',
    'scheduled_report_attached' => 'Tu informe :type programado está adjunto.',
    'scheduled_report_error' => 'Fallo al crear informe programado',
    'invalid_one_time_password' => 'Contraseña de uso único inválida',
    'apple_pay' => 'Apple/Google Pay',
    'enable_apple_pay' => 'Aceptar Apple Pay y Google Pay',
    'requires_subdomain' => 'Este tipo de pago requiere que :link.',
    'subdomain_is_set' => 'el subdominio se ha fijado',
    'verification_file' => 'archivo de verificacion',
    'verification_file_missing' => 'El archivo de verificación es necesario para aceptar pagos',
    'apple_pay_domain' => 'Usa <code>:domain</code> como dominio en :link.',
    'apple_pay_not_supported' => 'Lo sentimos, Apple/Google Pay no está soportado por su navegador',
    'optional_payment_methods' => 'Métodos de pago opcionales',
    'add_subscription' => 'Añadir suscripción',
    'target_url' => 'objetivo',
    'target_url_help' => 'Cuando el evento seleccionado suceda, la app enviará la entidad a la URL de destino.',
    'event' => 'Evento',
    'subscription_event_1' => 'Cliente creado ',
    'subscription_event_2' => 'Factura creada',
    'subscription_event_3' => 'Presupuesto creado',
    'subscription_event_4' => 'Pago creado',
    'subscription_event_5' => 'Crear Proveedor',
    'subscription_event_6' => 'Presupuesto Actualizado',
    'subscription_event_7' => 'Presupuesto Borrado',
    'subscription_event_8' => 'Factura Actualizada',
    'subscription_event_9' => 'Factura Eliminada',
    'subscription_event_10' => 'Cliente Actualizado',
    'subscription_event_11' => 'Cliente Eliminado',
    'subscription_event_12' => 'Pago Eliminado',
    'subscription_event_13' => 'Proveedor Actualizado',
    'subscription_event_14' => 'Proveedor Eliminado',
    'subscription_event_15' => 'Gasto Creado',
    'subscription_event_16' => 'Gasto Actualizado',
    'subscription_event_17' => 'Gasto Eliminado',
    'subscription_event_18' => 'Tarea Creada',
    'subscription_event_19' => 'Tarea Actualizada',
    'subscription_event_20' => 'Tarea Eliminada',
    'subscription_event_21' => 'Presupuesto Aprobado',
    'subscriptions' => 'Suscripciones',
    'updated_subscription' => 'Suscripción actualizada correctamente',
    'created_subscription' => 'Suscripción creada correctamente',
    'edit_subscription' => 'Editar Suscripción',
    'archive_subscription' => 'Archivar Suscripción',
    'archived_subscription' => 'Suscripción archivada correctamente',
    'project_error_multiple_clients' => 'Los proyectos no pueden pertenecer a diferentes clientes',
    'invoice_project' => 'Facturar Proyecto',
    'module_recurring_invoice' => 'Facturas Recurrentes',
    'module_credit' => 'Créditos',
    'module_quote' => 'Presupuestos y Propuestas',
    'module_task' => 'Tareas y Proyectos',
    'module_expense' => 'Gastos y Proveedores',
    'module_ticket' => 'Tickets',
    'reminders' => 'Recordatorios',
    'send_client_reminders' => 'Enviar email recordatorio',
    'can_view_tasks' => 'Las tareas son visibles en el portal',
    'is_not_sent_reminders' => 'Los recordatorios no se enviarán',
    'promotion_footer' => 'La promoción expirará pronto, :link para actualizar ahora.',
    'unable_to_delete_primary' => 'Nota: para eliminar esta empresa, primero borra todas las empresas enlazadas.',
    'please_register' => 'Por favor registra tu cuenta',
    'processing_request' => 'Procesando Petición',
    'mcrypt_warning' => 'Atención: Mcrypt está obsoleto, ejecuta :command para actualizar tu cifrado.',
    'edit_times' => 'Editar tiempos',
    'inclusive_taxes_help' => 'Incluye <b>impuestos en el coste</b>',
    'inclusive_taxes_notice' => 'Esta opción no puede ser cambiada una vez que se emita una factura.',
    'inclusive_taxes_warning' => 'Atención: las facturas existentes necesitarán ser guardadas de nuevo',
    'copy_shipping' => 'Copiar Envío',
    'copy_billing' => 'Copia Facturación',
    'quote_has_expired' => 'El presupuesto ha expirado, por favor contacta con el vendedor.',
    'empty_table_footer' => 'Mostrando de 0 a 0 de 0 entradas',
    'do_not_trust' => 'No recordar este dispositivo',
    'trust_for_30_days' => 'Mantener durante 30 días',
    'trust_forever' => 'Mantener para siempre',
    'kanban' => 'Kanban',
    'backlog' => 'Disponibles',
    'ready_to_do' => 'Preparadas',
    'in_progress' => 'En proceso',
    'add_status' => 'Añadir Estado',
    'archive_status' => 'Archivar Estado',
    'new_status' => 'Nuevo Estado',
    'convert_products' => 'Convertir Productos',
    'convert_products_help' => 'Convertir automáticamente los precios de los productos a la divisa del cliente',
    'improve_client_portal_link' => 'Use un subdominio para acortar el enlace al portal de cliente',
    'budgeted_hours' => 'Horas Presupuestadas',
    'progress' => 'Progreso',
    'view_project' => 'Ver Proyecto',
    'summary' => 'Resumen',
    'endless_reminder' => 'Recordatorio Sin Fín',
    'signature_on_invoice_help' => 'Añade el código mostrado a continuación para mostrar la firma de tu cliente en el PDF',
    'signature_on_pdf' => 'Mostrar en PDF',
    'signature_on_pdf_help' => 'Mostrar la firma del cliente en el PDF de la factura/presupuesto',
    'expired_white_label' => 'La licencia de marca blanca ha expirado',
    'return_to_login' => 'Volver a Inicio de Sesión',
    'convert_products_tip' => 'Nota: añade un :link llamado ":name" para ver la tasa de cambio.',
    'amount_greater_than_balance' => 'La cantidad es mayor que el balance de la factura, un crédito será creado con la cantidad restante.',
    'custom_fields_tip' => 'Usa <code>Etiqueta|Opción1,Opción2</code> para mostrar un cuadro de selección.',
    'client_information' => 'Información del cliente',
    'updated_client_details' => 'Se actualizaron correctamente los detalles del cliente',
    'auto' => 'Automática/o',
    'tax_amount' => 'Total Impuestos',
    'tax_paid' => 'Impuestos Pagados',
    'none' => 'Ninguno',
    'proposal_message_button' => 'Para ver su propuesta con importe :amount, pulse el siguiente botón.',
    'proposal' => 'Propuesta',
    'proposals' => 'Propuestas',
    'list_proposals' => 'Listar Propuestas',
    'new_proposal' => 'Nueva propuesta',
    'edit_proposal' => 'Editar propuesta',
    'archive_proposal' => 'Archivar propuesta',
    'delete_proposal' => 'Borrar propuesta',
    'created_proposal' => 'Propuesta creada correctamente',
    'updated_proposal' => 'Propuesta actualizada correctamente',
    'archived_proposal' => 'Propuesta archivada correctamente',
    'deleted_proposal' => 'Propuesta archivada correctamente',
    'archived_proposals' => ':count propuestas archivadas correctamente',
    'deleted_proposals' => ':count propuestas archivadas correctamente',
    'restored_proposal' => 'Propuesta restaurada satisfactoriamente',
    'restore_proposal' => 'Restaurar Propuesta',
    'snippet' => 'Snippet',
    'snippets' => 'Snippets',
    'proposal_snippet' => 'Snippet',
    'proposal_snippets' => 'Snippets',
    'new_proposal_snippet' => 'Nuevo Snippet',
    'edit_proposal_snippet' => 'Editar Snippet',
    'archive_proposal_snippet' => 'Archivar Snippet',
    'delete_proposal_snippet' => 'Borrar Snippet',
    'created_proposal_snippet' => 'Snippet creado correctamente',
    'updated_proposal_snippet' => 'Snippet actualizado correctamente',
    'archived_proposal_snippet' => 'Snippet archivado correctamente',
    'deleted_proposal_snippet' => 'Snippet archivado correctamente',
    'archived_proposal_snippets' => ':count snippets archivados correctamente',
    'deleted_proposal_snippets' => ':count snippets archivados correctamente',
    'restored_proposal_snippet' => 'Snippet restaurado correctamente',
    'restore_proposal_snippet' => 'Restaurar Snippet',
    'template' => 'Plantilla',
    'templates' => 'Plantillas',
    'proposal_template' => 'Plantilla',
    'proposal_templates' => 'Plantillas',
    'new_proposal_template' => 'Nueva Plantilla',
    'edit_proposal_template' => 'Editar Plantilla',
    'archive_proposal_template' => 'Archivar plantilla',
    'delete_proposal_template' => 'Borrar plantilla',
    'created_proposal_template' => 'Plantilla creada correctamente',
    'updated_proposal_template' => 'Plantilla actualizada correctamente',
    'archived_proposal_template' => 'Plantilla archivada correctamente',
    'deleted_proposal_template' => 'Plantilla archivada correctamente',
    'archived_proposal_templates' => ':count plantillas archivadas correctamente',
    'deleted_proposal_templates' => ':count plantillas archivadas correctamente',
    'restored_proposal_template' => 'Plantilla restaurada correctamente',
    'restore_proposal_template' => 'Restaurar Plantilla',
    'proposal_category' => 'Categoría',
    'proposal_categories' => 'Categorías',
    'new_proposal_category' => 'Nueva Categoría',
    'edit_proposal_category' => 'Editar Categoría',
    'archive_proposal_category' => 'Archivar Categoría',
    'delete_proposal_category' => 'Borrar Categoría',
    'created_proposal_category' => 'Categoría creada correctamente',
    'updated_proposal_category' => 'Categoría actualizada correctamente',
    'archived_proposal_category' => 'Categoría archivada correctamente',
    'deleted_proposal_category' => 'Categoría archivada correctamente',
    'archived_proposal_categories' => ':count categorías archivadas correctamente',
    'deleted_proposal_categories' => ':count categorías archivadas correctamente',
    'restored_proposal_category' => 'Categoría restaurada correctamente',
    'restore_proposal_category' => 'Restaurar Categoría',
    'delete_status' => 'Borrar Estado',
    'standard' => 'Estándar',
    'icon' => 'Icono',
    'proposal_not_found' => 'La propuesta solicitada no está disponible',
    'create_proposal_category' => 'Crear categoría',
    'clone_proposal_template' => 'Clonar Plantilla',
    'proposal_email' => 'Enviar Propuesta',
    'proposal_subject' => 'Nueva propuesta :number de :account',
    'proposal_message' => 'Para ver su propuesta con importe :amount, pulse el siguiente botón.',
    'emailed_proposal' => 'Propuesta enviada correctamente',
    'load_template' => 'Cargar Plantilla',
    'no_assets' => 'Sin imágenes, arrastra aquí para subir',
    'add_image' => 'Añadir Imagen',
    'select_image' => 'Seleccionar Imagen',
    'upgrade_to_upload_images' => 'Actualiza al Plan Enterprise para subir imágenes',
    'delete_image' => 'Borrar Imagen',
    'delete_image_help' => 'Atención: borrar la imagen la eliminará de todas las propuestas.',
    'amount_variable_help' => 'Nota: el campo de la factura $amount usará el campo parcial/depósito si se indica, de otra forma se usará el balance de la factura.',
    'taxes_are_included_help' => 'Nota: los impuestos incluidos están activados.',
    'taxes_are_not_included_help' => 'Nota: los impuestos incluidos no están activados.',
    'change_requires_purge' => 'Cambiar esta opción necesita :link los datos de la cuenta',
    'purging' => 'purgado',
    'warning_local_refund' => 'El reembolso será registrado en la app, pero NO será procesado por la pasarela de pago.',
    'email_address_changed' => 'La dirección de correo electrónico se ha cambiado',
    'email_address_changed_message' => 'La dirección de correo de tu cuenta ha sido cambiada de :old_email a :new_email.',
    'test' => 'Test',
    'beta' => 'Beta',
    'gmp_required' => 'Exporting to ZIP requires the GMP extension',
    'email_history' => 'Histórico de Emails',
    'loading' => 'Cargando',
    'no_messages_found' => 'No se encontraron mensajes',
    'processing' => 'Procesando',
    'reactivate' => 'Reactivar',
    'reactivated_email' => 'La dirección de correo electrónico ha sido reactivada',
    'emails' => 'Emails',
    'opened' => 'Abiertos',
    'bounced' => 'Rebotados',
    'total_sent' => 'Total Enviados',
    'total_opened' => 'Total Abiertos',
    'total_bounced' => 'Total Rebotados',
    'total_spam' => 'Total Spam',
    'platforms' => 'Plataformas',
    'email_clients' => 'Email Clients',
    'mobile' => 'Móvil',
    'desktop' => 'Escritorio',
    'webmail' => 'Webmail',
    'group' => 'Grupo',
    'subgroup' => 'Subgrupo',
    'unset' => 'Unset',
    'received_new_payment' => '¡Has recibido un nuevo pago!',
    'slack_webhook_help' => 'Recibe notificaciones de pago usando :link.',
    'slack_incoming_webhooks' => 'Slack incoming webhooks',
    'accept' => 'Aceptar',
    'accepted_terms' => 'Se aceptaron correctamente los últimos términos de servicio',
    'invalid_url' => 'URL inválida',
    'workflow_settings' => 'Configuración de Flujos',
    'auto_email_invoice' => 'Auto Email',
    'auto_email_invoice_help' => 'Automáticamente enviar por email facturas recurrentes cuando sean creadas.',
    'auto_archive_invoice' => 'Auto Archivar',
    'auto_archive_invoice_help' => 'Automáticamente archivar facturas cuando sean pagadas.',
    'auto_archive_quote' => 'Auto Archivar',
    'auto_archive_quote_help' => 'Automáticamente archivar presupuestos cuando sean convertidos.',
    'require_approve_quote' => 'Requerir aprobación de presupuesto.',
    'require_approve_quote_help' => 'Requerir que el cliente apruebe el presupuesto.',
    'allow_approve_expired_quote' => 'Permitir aprobación de presupuesto vencido',
    'allow_approve_expired_quote_help' => 'Permitir a los clientes aprobar presupuestos expirados.',
    'invoice_workflow' => 'Flujo de Factura',
    'quote_workflow' => 'Flujo de Presupuesto',
    'client_must_be_active' => 'Error: el cliente debe estar activo',
    'purge_client' => 'Purgar Cliente',
    'purged_client' => 'Cliente purgado correctamente',
    'purge_client_warning' => 'Todos los registros relacionados (facturas, tareas, gastos, documentos, etc) serán también eliminados.',
    'clone_product' => 'Clonar Producto',
    'item_details' => 'Detalles Artículo',
    'send_item_details_help' => 'Enviar los detalles de los artículos a la pasarela de pago',
    'view_proposal' => 'Ver Propuesta',
    'view_in_portal' => 'Ver en Portal',
    'cookie_message' => 'Esta página web usa cookies para asegurar que tengas la mejor experiencia de uso de este sitio.',
    'got_it' => '¡Lo tengo!',
    'vendor_will_create' => 'el proveedor será creado',
    'vendors_will_create' => 'los proveedores serán creados',
    'created_vendors' => 'Se crearon :count proveedor(es) correctamente',
    'import_vendors' => 'Importar Proveedores',
    'company' => 'Empresa',
    'client_field' => 'Campo de Cliente',
    'contact_field' => 'Campo de Contacto',
    'product_field' => 'Campo de Producto',
    'task_field' => 'Campo de Tarea',
    'project_field' => 'Campo de Proyecto',
    'expense_field' => 'Campo de Gasto',
    'vendor_field' => 'Campo de Proveedor',
    'company_field' => 'Campo de Empresa',
    'invoice_field' => 'Campo de Factura',
    'invoice_surcharge' => 'Recargo de Factura',
    'custom_task_fields_help' => 'Añadir un campo al crear una tarea.',
    'custom_project_fields_help' => 'Añadir un campo al crear un proyecto.',
    'custom_expense_fields_help' => 'Añadir un campo al crear un gasto.',
    'custom_vendor_fields_help' => 'Añadir un campo al crear un proveedor.',
    'messages' => 'Mensajes',
    'unpaid_invoice' => 'Factura Impagada',
    'paid_invoice' => 'Factura Pagada',
    'unapproved_quote' => 'Presupuesto No Aprobado',
    'unapproved_proposal' => 'Propuesta No Aprobada',
    'autofills_city_state' => 'Auto rellenar ciudad/provincia',
    'no_match_found' => 'Sin resultados',
    'password_strength' => 'Seguridad de la Contraseña',
    'strength_weak' => 'Débil',
    'strength_good' => 'Buena',
    'strength_strong' => 'Fuerte',
    'mark' => 'Marca',
    'updated_task_status' => 'Se actualizó correctamente el estado de la tarea',
    'background_image' => 'Imagen de Fondo',
    'background_image_help' => 'Usa el :link para gestionar tus imágenes, te recomendamos usar un archivo pequeño.',
    'proposal_editor' => 'editor de propuesta',
    'background' => 'Fondo',
    'guide' => 'Guía',
    'gateway_fee_item' => 'Concepto de Comisión de Pasarela de Pago',
    'gateway_fee_description' => 'Sobrecoste de Comisión de Pasarela de Pago',
    'gateway_fee_discount_description' => 'Descuento de tarifa de pasarela',
    'show_payments' => 'Mostrar Pagos',
    'show_aging' => 'Mostrar Envejecimiento',
    'reference' => 'Referencia',
    'amount_paid' => 'Cantidad Pagada',
    'send_notifications_for' => 'Mandar Notificaciones Por',
    'all_invoices' => 'Todas las Facturas',
    'my_invoices' => 'Mis Facturas',
    'payment_reference' => 'Referencia de Pago',
    'maximum' => 'Máximo',
    'sort' => 'Orden',
    'refresh_complete' => 'Actualización Completa',
    'please_enter_your_email' => 'Por favor introduce tu email',
    'please_enter_your_password' => 'Por favor introduce tu contraseña',
    'please_enter_your_url' => 'Por favor introduce tu URL',
    'please_enter_a_product_key' => 'Por favor introduce un código de producto',
    'an_error_occurred' => 'Ha ocurrido un error',
    'overview' => 'Resumen',
    'copied_to_clipboard' => ':value copiado al portapapeles',
    'error' => 'Error',
    'could_not_launch' => 'No se puede abrir',
    'additional' => 'Adicional',
    'ok' => 'Ok',
    'email_is_invalid' => 'El email es inválido',
    'items' => 'Artículos',
    'partial_deposit' => 'Parcial/Depósito',
    'add_item' => 'Añadir Artículo',
    'total_amount' => 'Cantidad Total',
    'pdf' => 'PDF',
    'invoice_status_id' => 'Estado de Factura',
    'click_plus_to_add_item' => 'Pulsa + para añadir un artículo',
    'count_selected' => ':count seleccionado',
    'dismiss' => 'Descartar',
    'please_select_a_date' => 'Por favor selecciona una fecha',
    'please_select_a_client' => 'Por favor selecciona un cliente',
    'language' => 'Idioma',
    'updated_at' => 'Actualizado',
    'please_enter_an_invoice_number' => 'Por favor introduce un número de factura',
    'please_enter_a_quote_number' => 'Por favor introduce un número de presupuesto',
    'clients_invoices' => 'Facturas de :client',
    'viewed' => 'Vistas',
    'approved' => 'Aprobados',
    'invoice_status_1' => 'Borrador',
    'invoice_status_2' => 'Enviadas',
    'invoice_status_3' => 'Vistas',
    'invoice_status_4' => 'Aprobados',
    'invoice_status_5' => 'Parcial',
    'invoice_status_6' => 'Pagadas',
    'marked_invoice_as_sent' => 'Factura marcada como enviada correctamente',
    'please_enter_a_client_or_contact_name' => 'Por favor introduce un cliente o nombre de contacto',
    'restart_app_to_apply_change' => 'Reinicia la app para aplicar el cambio',
    'refresh_data' => 'Actualizar Datos',
    'blank_contact' => 'Contacto Nuevo',
    'no_records_found' => 'No se han encontrado registros',
    'industry' => 'Sector',
    'size' => 'Tamaño',
    'net' => 'Neto',
    'show_tasks' => 'Mostrar tareas',
    'email_reminders' => 'Emails Recordatorios',
    'reminder1' => 'Primer Recordatorio',
    'reminder2' => 'Segundo Recordatorio',
    'reminder3' => 'Tercer Recordatorio',
    'send' => 'Enviar',
    'auto_billing' => 'Auto facturación',
    'button' => 'Botón',
    'more' => 'Más',
    'edit_recurring_invoice' => 'Editar Factura Recurrente',
    'edit_recurring_quote' => 'Editar Presupuesto Recurrente',
    'quote_status' => 'Estado de Presupuesto',
    'please_select_an_invoice' => 'Por favor, seleccione una factura',
    'filtered_by' => 'Filtrado por',
    'payment_status' => 'Estado de Pago',
    'payment_status_1' => 'Pendiente',
    'payment_status_2' => 'Anulado',
    'payment_status_3' => 'Fallido',
    'payment_status_4' => 'Completado',
    'payment_status_5' => 'Parcialmente Reembolsado',
    'payment_status_6' => 'Reembolsado',
    'send_receipt_to_client' => 'Mandar recibo al cliente',
    'refunded' => 'Reembolsado',
    'marked_quote_as_sent' => 'Presupuesto marcado como enviado correctamente',
    'custom_module_settings' => 'Opciones del Módulo Personalizado',
    'ticket' => 'Ticket',
    'tickets' => 'Tickets',
    'ticket_number' => 'N. Ticket',
    'new_ticket' => 'Nuevo Ticket',
    'edit_ticket' => 'Editar Ticket',
    'view_ticket' => 'Ver Ticket',
    'archive_ticket' => 'Archivar Ticket',
    'restore_ticket' => 'Restaurar Ticket',
    'delete_ticket' => 'Eliminar Ticket',
    'archived_ticket' => 'Ticket archivado correctamente',
    'archived_tickets' => 'Tickets archivados correctamente',
    'restored_ticket' => 'Ticket restaurado correctamente',
    'deleted_ticket' => 'Ticket eliminado correctamente',
    'open' => 'Abrir',
    'new' => 'Nuevo',
    'closed' => 'Cerrado',
    'reopened' => 'Reabierto',
    'priority' => 'Prioridad',
    'last_updated' => 'Última Actualización',
    'comment' => 'Comentarios',
    'tags' => 'Etiquetas',
    'linked_objects' => 'Objetos Linkados',
    'low' => 'Baja',
    'medium' => 'Media',
    'high' => 'Alta',
    'no_due_date' => 'Sin fecha de vencimiento',
    'assigned_to' => 'Asignado a',
    'reply' => 'Responder',
    'awaiting_reply' => 'Esperando respuesta',
    'ticket_close' => 'Cerrar Ticket',
    'ticket_reopen' => 'Reabrir Ticket',
    'ticket_open' => 'Abrir Ticket',
    'ticket_split' => 'Dividir Ticket',
    'ticket_merge' => 'Unir Ticket',
    'ticket_update' => 'Actualizar Ticket',
    'ticket_settings' => 'Opciones de Ticket',
    'updated_ticket' => 'Ticket Actualizado',
    'mark_spam' => 'Marcar como Spam',
    'local_part' => 'Parte Local',
    'local_part_unavailable' => 'Nombre asignado',
    'local_part_available' => 'Nombre disponible',
    'local_part_invalid' => 'Nombre inválido (caracteres alfanuméricos sólo, sin espacios',
    'local_part_help' => 'Personaliza la parte local de tu email de soporte de entrada, p.ej, TU_NOMBRE@support.invoiceninja.com',
    'from_name_help' => 'El nombre de remitente es el nombre que se muestra en vez de la dirección de email, p. ej. Centro de Soporte',
    'local_part_placeholder' => 'TU_NOMBRE',
    'from_name_placeholder' => 'Centro de Soporte',
    'attachments' => 'Archivos Adjuntos',
    'client_upload' => 'Subidas de cliente',
    'enable_client_upload_help' => 'Permitir a los clientes subir documentos/archivos adjuntos',
    'max_file_size_help' => 'El tamaño de fichero máximo (KB) está limitado por las variables post_max_size y upload_max_filesize configuradas en tu PHP.INI',
    'max_file_size' => 'Tamaño de fichero máximo',
    'mime_types' => 'Tipos de ficheros',
    'mime_types_placeholder' => '.pdf , .docx, .jpg',
    'mime_types_help' => 'Lista separada por comas de los tipos mime de fichero aceptados, déjalo en blanco para todos',
    'ticket_number_start_help' => 'El número de ticket debe ser mayor que el número de ticket actual',
    'new_ticket_template_id' => 'Nuevo ticket',
    'new_ticket_autoresponder_help' => 'Seleccionando una plantilla enviará una auto respuesta a un cliente/contacto cuando cree un nuevo ticket',
    'update_ticket_template_id' => 'Ticket actualizado',
    'update_ticket_autoresponder_help' => 'Seleccionando una plantilla enviará una auto respuesta a un cliente/contacto cuando actualice un ticket',
    'close_ticket_template_id' => 'Ticket cerrado',
    'close_ticket_autoresponder_help' => 'Seleccionando una plantilla enviará una auto respuesta a un cliente/contacto cuando cierre un ticket',
    'default_priority' => 'Prioridad por defecto',
    'alert_new_comment_id' => 'Nuevo comentario',
    'alert_comment_ticket_help' => 'Seleccionando una plantilla enviará una notificación (a un agente) cuando se haga un comentario.',
    'alert_comment_ticket_email_help' => 'Lista de emails separados por coma en el campo BCC en un nuevo comentario.',
    'new_ticket_notification_list' => 'Notificaciones de nuevo ticket adicionales',
    'update_ticket_notification_list' => 'Notificaciones de nuevo comentario adicionales',
    'comma_separated_values' => 'admin@example.com, supervisor@example.com',
    'alert_ticket_assign_agent_id' => 'Asignación de ticket',
    'alert_ticket_assign_agent_id_hel' => 'Seleccionando una plantilla enviará una notificación (a un agente) cuando un ticket sea asignado.',
    'alert_ticket_assign_agent_id_notifications' => 'Notificaciones de ticket asignado adicionales',
    'alert_ticket_assign_agent_id_help' => 'Lista de emails separados por coma en el campo BCC en la asignación de ticket.',
    'alert_ticket_transfer_email_help' => 'Lista de emails separados por coma en el campo BCC en la transferencia de ticket.',
    'alert_ticket_overdue_agent_id' => 'Ticket vencido',
    'alert_ticket_overdue_email' => 'Notificaciones de ticket vencido adicionales',
    'alert_ticket_overdue_email_help' => 'Lista de emails separados por coma en el campo BCC en el vencimiento de ticket.',
    'alert_ticket_overdue_agent_id_help' => 'Seleccionando una plantilla enviará una notificación (a un agente) cuando un ticket llegue a la fecha de vencimiento.',
    'ticket_master' => 'Jefe de Tickets',
    'ticket_master_help' => 'Tiene la facultad de asignar y transferir tickets. Asignado como agente por defecto para todos los tickets.',
    'default_agent' => 'Agente por Defecto',
    'default_agent_help' => 'Si se selecciona, será asignado automáticamente en todos los tickets de entrada',
    'show_agent_details' => 'Mostrar los detalles del agente en las respuestas',
    'avatar' => 'Avatar',
    'remove_avatar' => 'Eliminar avatar',
    'ticket_not_found' => 'Ticket no encontrado',
    'add_template' => 'Añadir Plantila',
    'ticket_template' => 'Plantilla de Ticket',
    'ticket_templates' => 'Plantillas de Ticket',
    'updated_ticket_template' => 'Plantilla de Ticket Actualizada',
    'created_ticket_template' => 'Plantilla de Ticket Creada',
    'archive_ticket_template' => 'Archivar Plantilla',
    'restore_ticket_template' => 'Restaurar Plantilla',
    'archived_ticket_template' => 'Plantilla archivada correctamente',
    'restored_ticket_template' => 'Plantilla restaurada correctamente',
    'close_reason' => 'Háznos saber por qué estás cerrando este ticket',
    'reopen_reason' => 'Indícanos por qué estás reabriendo este ticket',
    'enter_ticket_message' => 'Por favor, introduce un mensaje para actualizar el ticket',
    'show_hide_all' => 'Mostrar / Ocultar todo',
    'subject_required' => 'Asunto requerido',
    'mobile_refresh_warning' => 'Si estás usando la app móvil necesitarás hacer un refresco completo.',
    'enable_proposals_for_background' => 'Para subir una imagen de fondo :link para activar el módulo de propuestas.',
    'ticket_assignment' => 'El ticket :ticket_number ha sido asignado a :agent',
    'ticket_contact_reply' => 'El ticket :ticket_number ha sido actualizado por el cliente :contact',
    'ticket_new_template_subject' => 'El ticket :ticket_number ha sido creado.',
    'ticket_updated_template_subject' => 'El ticket :ticket_number ha sido actualizado.',
    'ticket_closed_template_subject' => 'El ticket :ticket_number ha sido cerrado.',
    'ticket_overdue_template_subject' => 'El ticket :ticket_number ha vencido.',
    'merge' => 'Unir',
    'merged' => 'Unidos',
    'agent' => 'Agente',
    'parent_ticket' => 'Ticket Padre',
    'linked_tickets' => 'Tickets Enlazados',
    'merge_prompt' => 'Introduce número de ticket con el que unir',
    'merge_from_to' => 'Ticket #:old_ticket se ha unido con el ticket #:new_ticket',
    'merge_closed_ticket_text' => 'Ticket #:old_ticket se ha cerrado y unido con el Ticket#:new_ticket - :subject',
    'merge_updated_ticket_text' => 'Ticket #:old_ticket se ha cerrado y unido con este ticket',
    'merge_placeholder' => 'Unir ticket #:ticket con el siguiente ticket',
    'select_ticket' => 'Seleccionar Ticket',
    'new_internal_ticket' => 'Nuevo ticket interno',
    'internal_ticket' => 'Ticket Interno',
    'create_ticket' => 'Crear ticket',
    'allow_inbound_email_tickets_external' => 'Nuevos Tickets por email (Cliente)',
    'allow_inbound_email_tickets_external_help' => 'Permitir a los clientes crear nuevos tickets por email',
    'include_in_filter' => 'Incluir en el filtro',
    'custom_client1' => ':VALUE',
    'custom_client2' => ':VALUE',
    'compare' => 'Comparar',
    'hosted_login' => 'Acceso alojado',
    'selfhost_login' => 'Acceso auto alojado',
    'google_login' => 'Acceso con Google',
    'thanks_for_patience' => 'Gracias por tu paciencia mientras trabajamos en implementar esas características.\n\nEsperamos tenerlas completadas en los próximos meses.\n\nHasta entonces continuaremos soportando el',
    'legacy_mobile_app' => 'app móvil heredada',
    'today' => 'Hoy',
    'current' => 'Actual',
    'previous' => 'Previo',
    'current_period' => 'Periodo Actual',
    'comparison_period' => 'Periodo de Comparación',
    'previous_period' => 'Periodo Anterior',
    'previous_year' => 'Año Anterior',
    'compare_to' => 'Comparar con',
    'last_week' => 'Última Semana',
    'clone_to_invoice' => 'Clonar a Factura',
    'clone_to_quote' => 'Clonar a Presupuesto',
    'convert' => 'Convertir',
    'last7_days' => 'Últimos 7 días',
    'last30_days' => 'Últimos 30 días',
    'custom_js' => 'JS personalizado',
    'adjust_fee_percent_help' => 'Ajustar el porcentaje para dar cuenta de la tarifa',
    'show_product_notes' => 'Mostrar detalles de producto',
    'show_product_notes_help' => 'Incluye la<b>descripción y coste</b> en el desplegable de producto',
    'important' => 'Importante',
    'thank_you_for_using_our_app' => '¡Gracias por utilizar nuestra app!',
    'if_you_like_it' => 'Si te gusta por favor',
    'to_rate_it' => 'para valorar.',
    'average' => 'Promedio',
    'unapproved' => 'No aprobado',
    'authenticate_to_change_setting' => 'Por favor, autenticarse para cambiar esta configuración',
    'locked' => 'Bloqueado',
    'authenticate' => 'Autenticación',
    'please_authenticate' => 'Por favor, autenticarse',
    'biometric_authentication' => 'Autenticación biométrica',
    'auto_start_tasks' => 'Tareas programadas',
    'budgeted' => 'Presupuestado',
    'please_enter_a_name' => 'Por favor introduce un nombre',
    'click_plus_to_add_time' => 'Pulsa + para añadir tiempo',
    'design' => 'Diseño',
    'password_is_too_short' => 'La contraseña es demasiado corta',
    'failed_to_find_record' => 'Fallo al buscar registro',
    'valid_until_days' => 'Válido hasta',
    'valid_until_days_help' => 'Establece automáticamente el valor <b>Válido hasta</b> en los presupuestos, con este número de días en el futuro. Déjelo en blanco para deshabilitarlo.',
    'usually_pays_in_days' => 'Días',
    'requires_an_enterprise_plan' => 'Requiere plan \'enterprise\'',
    'take_picture' => 'Tomar foto',
    'upload_file' => 'Subir archivo',
    'new_document' => 'Nuevo documento',
    'edit_document' => 'Editar documento',
    'uploaded_document' => 'Documento subido satisfactoriamente',
    'updated_document' => 'Documento actualizado satisfactoriamente',
    'archived_document' => 'Documento archivado satisfactoriamente',
    'deleted_document' => 'Documento borrado satisfactoriamente',
    'restored_document' => 'Documento restaurado satisfactoriamente',
    'no_history' => 'Sin historial',
    'expense_status_1' => 'Registrado',
    'expense_status_2' => 'Pendiente',
    'expense_status_3' => 'Facturado',
    'no_record_selected' => 'No se han seleccionado registros',
    'error_unsaved_changes' => 'Guarda o cancela tus cambios',
    'thank_you_for_your_purchase' => '¡Gracias por su compra!',
    'redeem' => 'Redimir',
    'back' => 'Atrás',
    'past_purchases' => 'Compras Pasadas',
    'annual_subscription' => 'Suscripción anual',
    'pro_plan' => 'Plan Pro',
    'enterprise_plan' => 'Plan Enterprise',
    'count_users' => ':count usuarios',
    'upgrade' => 'Mejorar',
    'please_enter_a_first_name' => 'Introduce tu nombre',
    'please_enter_a_last_name' => 'Introduce tu apellido',
    'please_agree_to_terms_and_privacy' => 'Por favor, acepta los términos de servicio y la política de privacidad para crear una cuenta',
    'i_agree_to_the' => 'Estoy de acuerdo con',
    'terms_of_service_link' => 'términos de servicio',
    'privacy_policy_link' => 'política de privacidad',
    'view_website' => 'Ver Sitio Web',
    'create_account' => 'Crear Cuenta',
    'email_login' => 'Iniciar sesión con correo electrónico',
    'late_fees' => 'Cargos por pagos atrasados',
    'payment_number' => 'Nº de Pago',
    'before_due_date' => 'Antes de la fecha de vencimiento',
    'after_due_date' => 'Después de la fecha de vencimiento',
    'after_invoice_date' => 'Después de la fecha de la factura',
    'filtered_by_user' => 'Filtrado por usuario',
    'created_user' => 'Usuario creado con éxito',
    'primary_font' => 'Fuente primaria',
    'secondary_font' => 'Fuente secundaria',
    'number_padding' => 'Relleno numérico',
    'general' => 'General',
    'surcharge_field' => 'Campo de recargo',
    'company_value' => 'Valor de compañía',
    'credit_field' => 'Campo de crédito',
    'payment_field' => 'Campo de pago',
    'group_field' => 'Campo de grupo',
    'number_counter' => 'Contador de números',
    'number_pattern' => 'Patrón numérico',
    'custom_javascript' => 'JavaScript Personalizado',
    'portal_mode' => 'Modo portal',
    'attach_pdf' => 'Adjuntar PDF',
    'attach_documents' => 'Adjuntar Documentos',
    'attach_ubl' => 'Adjuntar UBL',
    'email_style' => 'Estilo de correo electrónico',
    'processed' => 'Procesado',
    'fee_amount' => 'Importe de la cuota',
    'fee_percent' => 'Porcentaje de tarifa',
    'fee_cap' => 'Límite de tarifa',
    'limits_and_fees' => 'Límites/Tarifas',
    'credentials' => 'Credenciales',
    'require_billing_address_help' => 'Requerir al cliente indicar su dirección de facturación',
    'require_shipping_address_help' => 'Requerir al cliente indicar su dirección de envío',
    'deleted_tax_rate' => 'Impuesto borrado correctamente',
    'restored_tax_rate' => 'Impuesto restaurado correctamente',
    'provider' => 'Proveedor',
    'company_gateway' => 'Pasarela de pago',
    'company_gateways' => 'Pasarelas de pago',
    'new_company_gateway' => 'Nueva pasarela',
    'edit_company_gateway' => 'Editar pasarela',
    'created_company_gateway' => 'Pasarela creada correctamente',
    'updated_company_gateway' => 'Pasarela actualizada correctamente',
    'archived_company_gateway' => 'Pasarela archivada correctamente',
    'deleted_company_gateway' => 'Pasarela borrada correctamente',
    'restored_company_gateway' => 'Pasarela restaurada correctamente',
    'continue_editing' => 'Seguir editando',
    'default_value' => 'Valor por defecto',
    'currency_format' => 'Formato de moneda',
    'first_day_of_the_week' => 'Primer día de la semana',
    'first_month_of_the_year' => 'Primer mes del año',
    'symbol' => 'Símbolo',
    'ocde' => 'Código',
    'date_format' => 'Formato de fecha',
    'datetime_format' => 'Formato de fecha y hora',
    'send_reminders' => 'Enviar recordatorios',
    'timezone' => 'Zona horaria',
    'filtered_by_group' => 'Filtrado por Grupo',
    'filtered_by_invoice' => 'Filtrado por Factura',
    'filtered_by_client' => 'Filtrado por Cliente',
    'filtered_by_vendor' => 'Filtrado por proveedor',
    'group_settings' => 'Opciones de Grupo',
    'groups' => 'Grupos',
    'new_group' => 'Nuevo grupo',
    'edit_group' => 'Editar grupo',
    'created_group' => 'Grupo creado correctamente',
    'updated_group' => 'Grupo actualizado correctamente',
    'archived_group' => 'Grupo archivado correctamente',
    'deleted_group' => 'Grupo borrado correctamente',
    'restored_group' => 'Grupo restaurado correctamente',
    'upload_logo' => 'Subir Logo',
    'uploaded_logo' => 'Logo subido',
    'saved_settings' => 'Ajustes guardados',
    'device_settings' => 'Opciones de dispositivo',
    'credit_cards_and_banks' => 'Tarjetas de Crédito y Bancos',
    'price' => 'Precio',
    'email_sign_up' => 'Registrarse con Email',
    'google_sign_up' => 'Registrarse con Google',
    'sign_up_with_google' => 'Registrarse con Google',
    'long_press_multiselect' => 'Multiselección en pulsación prolongada',
    'migrate_to_next_version' => 'Migrar a la siguiente versión de Invoice Ninja',
    'migrate_intro_text' => 'Hemos estado trabajando en la siguiente versión de Invoice Ninja. Pulsa en el botón de abajo para comenzar la migración.',
    'start_the_migration' => 'Empezar la migración',
    'migration' => 'Migración',
    'welcome_to_the_new_version' => 'Bienvenido a la nueva versión de Invoice Ninja',
    'next_step_data_download' => 'En el siguiente paso, te dejaremos descargar tus datos para la migración.',
    'download_data' => 'Pulsa en el botón de abajo para descargar los datos.',
    'migration_import' => '¡Increíble! Ahora estás listo para importar tu migración. Ve a tu nueva instalación para importar tus datos.',
    'continue' => 'Continuar',
    'company1' => 'Compañía Personalizada 1',
    'company2' => 'Compañía Personalizada 2',
    'company3' => 'Compañía Personalizada 3',
    'company4' => 'Compañía Personalizada 4',
    'product1' => 'Producto Personalizado 1',
    'product2' => 'Producto Personalizado 2',
    'product3' => 'Producto Personalizado 3',
    'product4' => 'Producto Personalizado 4',
    'client1' => 'Cliente Personalizado 1',
    'client2' => 'Cliente Personalizado 2',
    'client3' => 'Cliente Personalizado 3',
    'client4' => 'Cliente Personalizado 4',
    'contact1' => 'Contacto Personalizado 1',
    'contact2' => 'Contacto Personalizado 2',
    'contact3' => 'Contacto Personalizado 3',
    'contact4' => 'Contacto Personalizado 4',
    'task1' => 'Tarea Personalizada 1',
    'task2' => 'Tarea Personalizada 2',
    'task3' => 'Tarea Personalizada 3',
    'task4' => 'Tarea Personalizada 4',
    'project1' => 'Proyecto Personalizado 1',
    'project2' => 'Proyecto Personalizado 2',
    'project3' => 'Proyecto Personalizado 3',
    'project4' => 'Proyecto Personalizado 4',
    'expense1' => 'Gasto Personalizado 1',
    'expense2' => 'Gasto Personalizado 2',
    'expense3' => 'Gasto Personalizado 3',
    'expense4' => 'Gasto Personalizado 4',
    'vendor1' => 'Proveedor Personalizado 1',
    'vendor2' => 'Proveedor Personalizado 2',
    'vendor3' => 'Proveedor Personalizado 3',
    'vendor4' => 'Proveedor Personalizado 4',
    'invoice1' => 'Factura Personalizada 1',
    'invoice2' => 'Factura Personalizada 2',
    'invoice3' => 'Factura Personalizada 3',
    'invoice4' => 'Factura Personalizada 4',
    'payment1' => 'Pago Personalizado 1',
    'payment2' => 'Pago Personalizado 2',
    'payment3' => 'Pago Personalizado 3',
    'payment4' => 'Pago Personalizado 4',
    'surcharge1' => 'Recargo Personalizado 1',
    'surcharge2' => 'Recargo Personalizado 2',
    'surcharge3' => 'Recargo Personalizado 3',
    'surcharge4' => 'Recargo Personalizado 4',
    'group1' => 'Grupo Personalizado 1',
    'group2' => 'Grupo Personalizado 2',
    'group3' => 'Grupo Personalizado 3',
    'group4' => 'Grupo Personalizado 4',
    'number' => 'Número',
    'count' => 'Recuento',
    'is_active' => 'Activo',
    'contact_last_login' => 'Último Acceso de Contacto',
    'contact_full_name' => 'Nombre Completo de Contacto',
    'contact_custom_value1' => 'Contacto Personalizado 1',
    'contact_custom_value2' => 'Contacto Personalizado 2',
    'contact_custom_value3' => 'Contacto Personalizado 3',
    'contact_custom_value4' => 'Contacto Personalizado 4',
    'assigned_to_id' => 'Asignado a Id',
    'created_by_id' => 'Creado por Id',
    'add_column' => 'Añadir Columna',
    'edit_columns' => 'Editar Columnas',
    'to_learn_about_gogle_fonts' => 'aprender sobre las Fuentes de Google',
    'refund_date' => 'Fecha de Reembolso',
    'multiselect' => 'Multiselección',
    'verify_password' => 'Verificar Contraseña',
    'applied' => 'Aplicado',
    'include_recent_errors' => 'Incluir errores recientes de los registros',
    'your_message_has_been_received' => 'Hemos recibido tu mensaje e intentaremos responderte cuanto antes.',
    'show_product_details' => 'Mostrar Detalles de Producto',
    'show_product_details_help' => 'Incluir la descripción y el coste en el desplegable del producto',
    'pdf_min_requirements' => 'El renderizador de PDF requiere :version',
    'adjust_fee_percent' => 'Ajustar Porcentaje de Tarifa',
    'configure_settings' => 'Configurar Opciones',
    'about' => 'Acerca de',
    'credit_email' => 'Correo electrónico de crédito',
    'domain_url' => 'URL del Dominio',
    'password_is_too_easy' => 'La contraseña debe contener una letra mayúscula y un número',
    'client_portal_tasks' => 'Tareas del Portal Cliente',
    'client_portal_dashboard' => 'Escritorio del Portal Cliente',
    'please_enter_a_value' => 'Por favor, introduzca un valor',
    'deleted_logo' => 'Logo borrado correctamente',
    'generate_number' => 'Generar Número',
    'when_saved' => 'Al Guardar',
    'when_sent' => 'Al Enviar',
    'select_company' => 'Seleccionar Compañía',
    'float' => 'Flotante',
    'collapse' => 'Ocultar',
    'show_or_hide' => 'Mostrar/Ocultar',
    'menu_sidebar' => 'Menú en Barra Lateral',
    'history_sidebar' => 'Histórico en Barra Lateral',
    'tablet' => 'Tableta',
    'layout' => 'Diseño',
    'module' => 'Modulo',
    'first_custom' => 'Primera Personalización',
    'second_custom' => 'Segunda Personalización',
    'third_custom' => 'Tercera Personalización',
    'show_cost' => 'Mostrar Coste',
    'show_cost_help' => 'Mostrar un campo de coste de producto para seguir el margen/beneficio',
    'show_product_quantity' => 'Mostrar Cantidad de Productos',
    'show_product_quantity_help' => 'Mostrar un campo de cantidad de productos, de lo contrario predeterminar a uno',
    'show_invoice_quantity' => 'Mostrar Cantidad de Factura',
    'show_invoice_quantity_help' => 'Mostrar un campo de cantidad de artículo de línea; de lo contrario, el valor predeterminado es uno',
    'default_quantity' => 'Cantidad por Defecto',
    'default_quantity_help' => 'Poner la cantidad de artículos automáticamente a uno',
    'one_tax_rate' => 'Un Tipo de Impuesto',
    'two_tax_rates' => 'Dos Tipos de Impuesto',
    'three_tax_rates' => 'Tres Tipos de Impuesto',
    'default_tax_rate' => 'Impuesto por Defecto',
    'invoice_tax' => 'Impuesto de Factura',
    'line_item_tax' => 'Impuesto de Artículo',
    'inclusive_taxes' => 'Impuestos Inclusivos',
    'invoice_tax_rates' => 'Tipos de Impuesto de Factura',
    'item_tax_rates' => 'Tipos de Impuesto de Artículo',
    'configure_rates' => 'Configurar tipos',
    'tax_settings_rates' => 'Tipos de Impuesto',
    'accent_color' => 'Color de Acento',
    'comma_sparated_list' => 'Lista separada por comas',
    'single_line_text' => 'Texto de una sola línea',
    'multi_line_text' => 'Texto de líneas múltiples',
    'dropdown' => 'Desplegable',
    'field_type' => 'Tipo de Campo',
    'recover_password_email_sent' => 'Se ha enviado un email de recuperación de contraseña',
    'removed_user' => 'Usuario eliminado correctamente',
    'freq_three_years' => 'Tres Años',
    'military_time_help' => 'Formato de 24 Horas',
    'click_here_capital' => 'Pulsa aquí',
    'marked_invoice_as_paid' => 'Factura marcada como enviada correctamente',
    'marked_invoices_as_sent' => 'Facturas marcadas como enviadas correctamente',
    'marked_invoices_as_paid' => 'Facturas marcadas como enviadas correctamente',
    'activity_57' => 'El sistema falló al enviar la factura :invoice',
    'custom_value3' => 'Valor Personalizado 3',
    'custom_value4' => 'Valor Personalizado 4',
    'email_style_custom' => 'Estilo de Email Personalizado',
    'custom_message_dashboard' => 'Mensaje de Escritorio Personalizado',
    'custom_message_unpaid_invoice' => 'Mensaje de Factura Impagada Personalizada',
    'custom_message_paid_invoice' => 'Mensaje de Factura Pagada Personalizada',
    'custom_message_unapproved_quote' => 'Mensaje de Presupuesto no Aprobado Personalizado',
    'lock_sent_invoices' => 'Bloquear Facturas Enviadas',
    'translations' => 'Traducciones',
    'task_number_pattern' => 'Patrón del Número de Tarea',
    'task_number_counter' => 'Contador del Número de Tarea',
    'expense_number_pattern' => 'Patrón del Número de Gasto',
    'expense_number_counter' => 'Contador del Número de Gasto',
    'vendor_number_pattern' => 'Patrón del Número de Proveedor',
    'vendor_number_counter' => 'Contador del Número de Proveedor',
    'ticket_number_pattern' => 'Patrón del Número de Ticket',
    'ticket_number_counter' => 'Contador del Número de Ticket',
    'payment_number_pattern' => 'Patrón del Número de Pago',
    'payment_number_counter' => 'Contador del Número de Pago',
    'invoice_number_pattern' => 'Patrón del Número de Factura',
    'quote_number_pattern' => 'Patrón del Número de Presupuesto',
    'client_number_pattern' => 'Patrón del Número de Crédito',
    'client_number_counter' => 'Contador del Número de Crédito',
    'credit_number_pattern' => 'Patrón del Número de Crédito',
    'credit_number_counter' => 'Contador del Número de Crédito',
    'reset_counter_date' => 'Resetear Fecha del Contador',
    'counter_padding' => 'Relleno del Contador',
    'shared_invoice_quote_counter' => 'Compartir la numeración para presupuesto y factura',
    'default_tax_name_1' => 'Nombre de Impuesto por Defecto 1',
    'default_tax_rate_1' => 'Tasa de Impuesto por Defecto 1',
    'default_tax_name_2' => 'Nombre de Impuesto por Defecto 2',
    'default_tax_rate_2' => 'Tasa de Impuesto por Defecto 2',
    'default_tax_name_3' => 'Nombre de Impuesto por Defecto 3',
    'default_tax_rate_3' => 'Tasa de Impuesto por Defecto 3',
    'email_subject_invoice' => 'Asunto de Email de Factura',
    'email_subject_quote' => 'Asunto de Email de Presupuesto',
    'email_subject_payment' => 'Asunto de Email de Pago',
    'switch_list_table' => 'Cabiar a lista de tabla',
    'client_city' => 'Ciudad del Cliente',
    'client_state' => 'Provincia del Cliente',
    'client_country' => 'País del Cliente',
    'client_is_active' => 'El Cliente está Activo',
    'client_balance' => 'Balance del Cliente',
    'client_address1' => 'Calle del Cliente',
    'client_address2' => 'Bloq/Pta del Cliente',
    'client_shipping_address1' => 'Calle de Envío del Cliente',
    'client_shipping_address2' => 'Bloq/Pta de Envío del Cliente',
    'tax_rate1' => 'Impuesto 1',
    'tax_rate2' => 'Impuesto 2',
    'tax_rate3' => 'Impuesto 3',
    'archived_at' => 'Archivado el',
    'has_expenses' => 'Tiene Gastos',
    'custom_taxes1' => 'Impuestos Personalizados 1',
    'custom_taxes2' => 'Impuestos Personalizados 2',
    'custom_taxes3' => 'Impuestos Personalizados 3',
    'custom_taxes4' => 'Impuestos Personalizados 4',
    'custom_surcharge1' => 'Recargo Personalizado 1',
    'custom_surcharge2' => 'Recargo Personalizado 2',
    'custom_surcharge3' => 'Recargo Personalizado 3',
    'custom_surcharge4' => 'Recargo Personalizado 4',
    'is_deleted' => 'Borrado',
    'vendor_city' => 'Ciudad del Proveedor',
    'vendor_state' => 'Provincia del Proveedor',
    'vendor_country' => 'País del Proveedor',
    'credit_footer' => 'Pie de Página de Crédito',
    'credit_terms' => 'Términos de Crédito',
    'untitled_company' => 'Compañia Sin Nombre',
    'added_company' => 'Compañía añadida correctamente',
    'supported_events' => 'Eventos Soportados',
    'custom3' => 'Tercera Personalización',
    'custom4' => 'Cuarta Personalización',
    'optional' => 'Opcional',
    'license' => 'Licencia',
    'invoice_balance' => 'Balance de Factura',
    'saved_design' => 'Diseño guardado correctamente',
    'client_details' => 'Detalles de Cliente',
    'company_address' => 'Dirección de Compañía',
    'quote_details' => 'Detalles del Presupuesto',
    'credit_details' => 'Detalles de Crédito',
    'product_columns' => 'Columnas de Producto',
    'task_columns' => 'Columnas de Tarea',
    'add_field' => 'Añadir Campo',
    'all_events' => 'Todos los Eventos',
    'owned' => 'Propietario',
    'payment_success' => 'Pago realizado con éxito',
    'payment_failure' => 'Fallo de Pago',
    'quote_sent' => 'Prespuesto Enviado',
    'credit_sent' => 'Crédito Enviado',
    'invoice_viewed' => 'Factura Vista',
    'quote_viewed' => 'Presupuesto Visto',
    'credit_viewed' => 'Crédito Visto',
    'quote_approved' => 'Presupuesto Aprobado',
    'receive_all_notifications' => 'Recibir Todas las Notificaciones',
    'purchase_license' => 'Comprar Licencia',
    'enable_modules' => 'Activar Módulos',
    'converted_quote' => 'Presupuesto convertido correctamente',
    'credit_design' => 'Diseño de Crédito',
    'includes' => 'Incluye',
    'css_framework' => 'CSS Framework',
    'custom_designs' => 'Diseños Personalizados',
    'designs' => 'Diseños',
    'new_design' => 'Nuevo Diseño',
    'edit_design' => 'Editar Diseño',
    'created_design' => 'Diseño creado correctamente',
    'updated_design' => 'Diseño actualizado correctamente',
    'archived_design' => 'Diseño archivado correctamente',
    'deleted_design' => 'Diseño borrado correctamente',
    'removed_design' => 'Diseño eliminado correctamente',
    'restored_design' => 'Diseño restaurado correctamente',
    'recurring_tasks' => 'Tareas Recurrentes',
    'removed_credit' => 'Crédito eliminado correctamente',
    'latest_version' => 'Última Versión',
    'update_now' => 'Actualizar Ahora',
    'a_new_version_is_available' => 'Una nueva versión de la aplicación web está disponible',
    'update_available' => 'Actualización Disponible',
    'app_updated' => 'Actualización completada correctamente',
    'integrations' => 'Integraciones',
    'tracking_id' => 'Id seguimiento',
    'slack_webhook_url' => 'Slack Webhook URL',
    'partial_payment' => 'Pago Parcial',
    'partial_payment_email' => 'Correo electrónico de pago parcial',
    'clone_to_credit' => 'Clonar a Crédito',
    'emailed_credit' => 'Crédito enviado correctamente',
    'marked_credit_as_sent' => 'Marcar crédito como enviado',
    'email_subject_payment_partial' => 'Asunto de Email de Pago Parcial',
    'is_approved' => 'Aprobada',
    'migration_went_wrong' => 'Uppps, ¡algo fue mal! Por favor, asegúrate de que has configurado una instancia Invoice Ninja v5 antes de empezar la migración.',
    'cross_migration_message' => 'No se permite la migración de cuentas cruzadas. Lea más sobre esto aquí: <a href="https://invoiceninja.github.io/docs/migration/#troubleshooting">https://invoiceninja.github.io/docs/migration/#troubleshooting</a>',
    'email_credit' => 'Enviar Crédito',
    'client_email_not_set' => 'El cliente no tiene establecida una dirección de email',
    'ledger' => 'Libro Mayor',
    'view_pdf' => 'Ver PDF',
    'all_records' => 'Todos los registros',
    'owned_by_user' => 'Propiedad del usuario',
    'credit_remaining' => 'Crédito Restante',
    'use_default' => 'Usar por defecto',
    'reminder_endless' => 'Recordatorios Sin Fín',
    'number_of_days' => 'Número de días',
    'configure_payment_terms' => 'Configurar Términos de Pago',
    'payment_term' => 'Término de Pago',
    'new_payment_term' => 'Nuevo Término de Pago',
    'deleted_payment_term' => 'Término de pago borrado correctamente',
    'removed_payment_term' => 'Término de pago eliminado correctamente',
    'restored_payment_term' => 'Término de pago restaurado correctamente',
    'full_width_editor' => 'Editor de Ancho Completo',
    'full_height_filter' => 'Filtro de Alto Completo',
    'email_sign_in' => 'Ingresar con email',
    'change' => 'Cambiar',
    'change_to_mobile_layout' => '¿Cambiar al formato de móvil?',
    'change_to_desktop_layout' => '¿Cambiar al formato de escritorio?',
    'send_from_gmail' => 'Enviar desde Gmail',
    'reversed' => 'Revertida',
    'cancelled' => 'Cancelada',
    'quote_amount' => 'Total de Presupuesto',
    'hosted' => 'Hospedado',
    'selfhosted' => 'Hospedaje Propio',
    'hide_menu' => 'Ocultar Menú',
    'show_menu' => 'Mostrar Menú',
    'partially_refunded' => 'Parcialmente Reintegrada',
    'search_documents' => 'Buscar Documentos',
    'search_designs' => 'Buscar Diseños',
    'search_invoices' => 'Buscar Facturas',
    'search_clients' => 'Buscar Clientes',
    'search_products' => 'Buscar Productos',
    'search_quotes' => 'Buscar Presupuestos',
    'search_credits' => 'Buscar Créditos',
    'search_vendors' => 'Buscar Proveedores',
    'search_users' => 'Buscar Usuarios',
    'search_tax_rates' => 'Buscar Tipos de Impuesto',
    'search_tasks' => 'Buscar Tareas',
    'search_settings' => 'Buscar Opciones',
    'search_projects' => 'Buscar Proyectos',
    'search_expenses' => 'Buscar Gastos',
    'search_payments' => 'Buscar Pagos',
    'search_groups' => 'Buscar Grupos',
    'search_company' => 'Buscar Compañía',
    'cancelled_invoice' => 'Factura cancelada correctamente',
    'cancelled_invoices' => 'Facturas canceladas correctamente',
    'reversed_invoice' => 'Factura revertida correctamente',
    'reversed_invoices' => 'Facturas revertidas correctamente',
    'reverse' => 'Revertir',
    'filtered_by_project' => 'Fitlrado por Proyecto',
    'google_sign_in' => 'Ingresar con Google',
    'activity_58' => ':user revirtió la factura :invoice',
    'activity_59' => ':user canceló la factura :invoice',
    'payment_reconciliation_failure' => 'Fallo de Conciliación',
    'payment_reconciliation_success' => 'Concilicación correcta',
    'gateway_success' => 'Éxito de pasarela',
    'gateway_failure' => 'Fallo de Pasarela',
    'gateway_error' => 'Error de Pasarela',
    'email_send' => 'Email Enviado',
    'email_retry_queue' => 'Cola de Reenvío de Email',
    'failure' => 'Fallo',
    'quota_exceeded' => 'Cuota Excedida',
    'upstream_failure' => 'Upstream Failure',
    'system_logs' => 'Registros del Sistema',
    'copy_link' => 'Copiar Enlace',
    'welcome_to_invoice_ninja' => 'Bienvenid@ a Invoice Ninja',
    'optin' => 'Opt-In',
    'optout' => 'Opt-Out',
    'auto_convert' => 'Auto Convertir',
    'reminder1_sent' => 'Recordatorio 1, enviado',
    'reminder2_sent' => 'Recordatorio 2, enviado',
    'reminder3_sent' => 'Recordatorio 3, enviado',
    'reminder_last_sent' => 'Último recordatorio enviado',
    'pdf_page_info' => 'Página :current de :total',
    'emailed_credits' => 'Créditos enviados correctamente',
    'view_in_stripe' => 'Ver en Stripe',
    'rows_per_page' => 'Filas por Página',
    'apply_payment' => 'Aplicar Pago',
    'unapplied' => 'Sin Aplicar',
    'custom_labels' => 'Etiquetas Personalizadas',
    'record_type' => 'Tipo de Registro',
    'record_name' => 'Nombre de Registro',
    'file_type' => 'Tipo de Archivo',
    'height' => 'Altura',
    'width' => 'Anchura',
    'health_check' => 'Consultar Estado de Sistema',
    'last_login_at' => 'Último Acceso el',
    'company_key' => 'Clave de empresa',
    'storefront' => 'Escaparate',
    'storefront_help' => 'Activar apps de terceros para crear facturas',
    'count_records_selected' => ':count registros seleccionados',
    'count_record_selected' => ':count registro seleccionado',
    'client_created' => 'Cliente Creado',
    'online_payment_email' => 'Email de Pago Online',
    'manual_payment_email' => 'Email de Pago Manual',
    'completed' => 'Completado',
    'gross' => 'Bruto',
    'net_amount' => 'Importe Neto',
    'net_balance' => 'Balance Neto',
    'client_settings' => 'Configuración de Cliente',
    'selected_invoices' => 'Facturas Seleccionadas',
    'selected_payments' => 'Pagos Seleccionados',
    'selected_quotes' => 'Presupuestos Seleccionados',
    'selected_tasks' => 'Tareas Seleccionadas',
    'selected_expenses' => 'Gastos Seleccionados',
    'past_due_invoices' => 'Facturas Fuera de Plazo',
    'create_payment' => 'Crear Pago',
    'update_quote' => 'Actualizar Presupuesto',
    'update_invoice' => 'Actualizar Factura',
    'update_client' => 'Actualizar Cliente',
    'update_vendor' => 'Actualizar Proveedor',
    'create_expense' => 'Crear Gasto',
    'update_expense' => 'Actualizar Gasto',
    'update_task' => 'Actualizar Tarea',
    'approve_quote' => 'Aprobar Presupuesto',
    'when_paid' => 'Al Pagar',
    'expires_on' => 'Expira el',
    'show_sidebar' => 'Mostrar Barra Lateral',
    'hide_sidebar' => 'Ocultar Barra Lateral',
    'event_type' => 'Tipo de Evento',
    'copy' => 'Copiar',
    'must_be_online' => 'Por favor reinicia la app cuando te conectes a internet',
    'crons_not_enabled' => 'La tarea cron debe ser activada',
    'api_webhooks' => 'API Webhooks',
    'search_webhooks' => 'Buscar :count Webhooks',
    'search_webhook' => 'Buscar 1 Webhook',
    'webhook' => 'Webhook',
    'webhooks' => 'Webhooks',
    'new_webhook' => 'Nuevo Webhook',
    'edit_webhook' => 'Editar Webhook',
    'created_webhook' => 'Webhook creado correctamente',
    'updated_webhook' => 'Webhook actualizado correctamente',
    'archived_webhook' => 'Webhook archivado correctamente',
    'deleted_webhook' => 'Webhook borrado correctamente',
    'removed_webhook' => 'Webhook eliminado correctamente',
    'restored_webhook' => 'Webhook restaurado correctamente',
    'search_tokens' => 'Buscar :count Tokens',
    'search_token' => 'Buscar 1 Token',
    'new_token' => 'Nuevo Token',
    'removed_token' => 'Token eliminado correctamente',
    'restored_token' => 'Token restaurado correctamente',
    'client_registration' => 'Registro de Cliente',
    'client_registration_help' => 'Permitir a los clientes auto-registrarse en el portal',
    'customize_and_preview' => 'Personalizar y Previsualizar',
    'search_document' => 'Buscar 1 Documento',
    'search_design' => 'Buscar 1 Diseño',
    'search_invoice' => 'Buscar 1 Factura',
    'search_client' => 'Buscar 1 Cliente',
    'search_product' => 'Buscar 1 Producto',
    'search_quote' => 'Buscar 1 Presupuesto',
    'search_credit' => 'Buscar 1 Crédito',
    'search_vendor' => 'Buscar 1 Proveedor',
    'search_user' => 'Buscar 1 Usuario',
    'search_tax_rate' => 'Buscar 1 Tipo de Impuesto',
    'search_task' => 'Buscar 1 Tarea',
    'search_project' => 'Buscar 1 Proyecto',
    'search_expense' => 'Buscar 1 Gasto',
    'search_payment' => 'Buscar 1 Pago',
    'search_group' => 'Buscar 1 Grupo',
    'created_on' => 'Creado el',
    'payment_status_-1' => 'Sin Aplicar',
    'lock_invoices' => 'Bloquear Facturas',
    'show_table' => 'Mostrar Tabla',
    'show_list' => 'Mostrar Lista',
    'view_changes' => 'Ver Cambios',
    'force_update' => 'Forzar Actualización',
    'force_update_help' => 'Estás usando la última versión, pero puede haber corrección de errores pendientes.',
    'mark_paid_help' => 'Seguir que la factura haya sido pagada',
    'mark_invoiceable_help' => 'Activar que el gasto sea facturable',
    'add_documents_to_invoice_help' => 'Hacer los documentos visibles',
    'convert_currency_help' => 'Establecer un tipo de cambio',
    'expense_settings' => 'Configuración de Gastos',
    'clone_to_recurring' => 'Clonar a Recurrente',
    'crypto' => 'Crypto',
    'user_field' => 'Campo de Usuario',
    'variables' => 'Variables',
    'show_password' => 'Mostrar Contraseña',
    'hide_password' => 'Ocultar Contraseña',
    'copy_error' => 'Copiar Error',
    'capture_card' => 'Capturar Tarjeta',
    'auto_bill_enabled' => 'Activar Auto Facturación',
    'total_taxes' => 'Impuestos Totales',
    'line_taxes' => 'Impuestos de Línea',
    'total_fields' => 'Campos Totales',
    'stopped_recurring_invoice' => 'Se ha parado la factura recurrente correctamente',
    'started_recurring_invoice' => 'Se ha iniciado la factura recurrente correctamente',
    'resumed_recurring_invoice' => 'Se ha reiniciado la factura recurrente correctamente',
    'gateway_refund' => 'Pasarela de Devolución',
    'gateway_refund_help' => 'Procesar la devolución con la pasarela de pago',
    'due_date_days' => 'Fecha de Vencimiento',
    'paused' => 'Pausado',
    'day_count' => 'Día :count',
    'first_day_of_the_month' => 'Primer Día del Mes',
    'last_day_of_the_month' => 'Último Día del Mes',
    'use_payment_terms' => 'Usar Términos de Pago',
    'endless' => 'Sin Fín',
    'next_send_date' => 'Próxima Fecha de Envío',
    'remaining_cycles' => 'Ciclos Pendientes',
    'created_recurring_invoice' => 'Factura recurrente creada correctamente',
    'updated_recurring_invoice' => 'Factura recurrente actualizada correctamente',
    'removed_recurring_invoice' => 'Factura recurrente eliminada correctamente',
    'search_recurring_invoice' => 'Buscar 1 Factura Recurrente',
    'search_recurring_invoices' => 'Buscar :count Facturas Recurrentes',
    'send_date' => 'Fecha de Envío',
    'auto_bill_on' => 'Facturación Automática Activa',
    'minimum_under_payment_amount' => 'Cantidad Mínima de Pago',
    'allow_over_payment' => 'Permitir Sobrepago',
    'allow_over_payment_help' => 'Permitir pagos extra para aceptar propinas',
    'allow_under_payment' => 'Permitir Pago de Menos',
    'allow_under_payment_help' => 'Permitir pagar como mínimo la cantidad parcial/depósito',
    'test_mode' => 'Modo Test',
    'calculated_rate' => 'Tasa Calculada',
    'default_task_rate' => 'Tarifa de Tarea por Defecto',
    'clear_cache' => 'Borrar Caché',
    'sort_order' => 'Orden Clasificación',
    'task_status' => 'Estado',
    'task_statuses' => 'Estados de Tarea',
    'new_task_status' => 'Nuevo Estado de Tarea',
    'edit_task_status' => 'Editar Estado de Tarea',
    'created_task_status' => 'Estado de tarea creado correctamente',
    'archived_task_status' => 'Estado de tarea archivado correctamente',
    'deleted_task_status' => 'Estado de tarea borrado correctamente',
    'removed_task_status' => 'Estado de tarea eliminado correctamente',
    'restored_task_status' => 'Estado de tarea restaurado correctamente',
    'search_task_status' => 'Buscar 1 Estado de Tarea',
    'search_task_statuses' => 'Buscar :count Estados de Tarea',
    'show_tasks_table' => 'Mostrar Tabla de Tareas',
    'show_tasks_table_help' => 'Mostrar siempre la sección de tareas cuando se creen facturas',
    'invoice_task_timelog' => 'Registro de Tiempo de Tarea Facturada',
    'invoice_task_timelog_help' => 'Añadir detalles de tiempo a los artículos de línea de factura',
    'auto_start_tasks_help' => 'Empezar tareas antes de guardar',
    'configure_statuses' => 'Configurar Estados',
    'task_settings' => 'Configuración de Tareas',
    'configure_categories' => 'Configurar Categorías',
    'edit_expense_category' => 'Editar Categoría de Gasto',
    'removed_expense_category' => 'Categoría de gasto eliminada correctamente',
    'search_expense_category' => 'Buscar 1 Categoría de Gasto',
    'search_expense_categories' => 'Buscar :count Categorías de Gasto',
    'use_available_credits' => 'Usar Crédito Disponible',
    'show_option' => 'Mostrar Opción',
    'negative_payment_error' => 'La cantidad de crédito no puede exceder la cantidada pagada',
    'should_be_invoiced_help' => 'Activar que los gastos sean facturables',
    'configure_gateways' => 'Configurar Pasarelas',
    'payment_partial' => 'Pago Parcial',
    'is_running' => 'Corriendo',
    'invoice_currency_id' => 'ID de Moneda de Facturación',
    'tax_name1' => 'Nombre de Impuesto 1',
    'tax_name2' => 'Nombre de Impuesto 2',
    'transaction_id' => 'ID de Transacción',
    'invoice_late' => 'Atraso de Factura',
    'quote_expired' => 'Presupuesto Expirado',
    'recurring_invoice_total' => 'Total Factura',
    'actions' => 'Acciones',
    'expense_number' => 'Número de Gasto',
    'task_number' => 'Número de Tarea',
    'project_number' => 'Número de Proyecto',
    'view_settings' => 'Ver Configuración',
    'company_disabled_warning' => 'Advertencia: esta compañía aún no ha sido activada',
    'late_invoice' => 'Factura Atrasada',
    'expired_quote' => 'Presupuesto Expirado',
    'remind_invoice' => 'Recordar Factura',
    'client_phone' => 'Teléfono del Cliente',
    'required_fields' => 'Campos Requeridos',
    'enabled_modules' => 'Modulos Activados',
    'activity_60' => ':contact vió el presupuesto :quote',
    'activity_61' => ':user actualizó el cliente :cliente',
    'activity_62' => ':user actualizó el proveedor :vendor',
    'activity_63' => ':user envió por email el primer recordatorio de la factura :invoice a :contact',
    'activity_64' => ':user envió por email el segundo recordatorio de la factura :invoice a :contact',
    'activity_65' => ':user envió por email el tercer recordatorio de la factura :invoice a :contact',
    'activity_66' => ':user envió por email el recordatorio sin fín de la factura :invoice a :contact',
    'expense_category_id' => 'ID de la Categoría de Gasto',
    'view_licenses' => 'Ver Licencias',
    'fullscreen_editor' => 'Editor a Pantalla Completa',
    'sidebar_editor' => 'Editor de Barra Lateral',
    'please_type_to_confirm' => 'Por favor, escribe ":value" para confirmar',
    'purge' => 'Purgar',
    'clone_to' => 'Clonar a',
    'clone_to_other' => 'Clonar a otra',
    'labels' => 'Etiquetas',
    'add_custom' => 'Añadir Personalizado',
    'payment_tax' => 'Impuesto de Pago',
    'white_label' => 'Marca Blanca',
    'sent_invoices_are_locked' => 'Las facturas enviadas están bloqueadas',
    'paid_invoices_are_locked' => 'Las facturas pagadas están bloqueadas',
    'source_code' => 'Código Fuente',
    'app_platforms' => 'Añadir Plataformas',
    'archived_task_statuses' => ':value estados de tarea archivados correctamente',
    'deleted_task_statuses' => ':value estados de tarea borrados correctamente',
    'restored_task_statuses' => ':value estados de tarea restaurados correctamente',
    'deleted_expense_categories' => ':value categorías de gasto borradas correctamente',
    'restored_expense_categories' => ':value categorías de gasto restauradas correctamente',
    'archived_recurring_invoices' => ':value facturas recurrentes archivadas correctamente',
    'deleted_recurring_invoices' => ':value facturas recurrentes borradas correctamente',
    'restored_recurring_invoices' => ':value facturas recurrentes restauradas correctamente',
    'archived_webhooks' => ':value webhooks archivados correctamente',
    'deleted_webhooks' => ':value webhooks borrados correctamente',
    'removed_webhooks' => ':value webhooks eliminados correctamente',
    'restored_webhooks' => ':value webhooks restaurados correctamente',
    'api_docs' => 'Documentación de API',
    'archived_tokens' => ':value tokens archivados correctamente',
    'deleted_tokens' => ':value tokens borrados correctamente',
    'restored_tokens' => ':value tokens restaurados correctamente',
    'archived_payment_terms' => ':value términos de pago archivados correctamente',
    'deleted_payment_terms' => ':value téminos de pago borrados correctamente',
    'restored_payment_terms' => ':value téminos de pago restaurados correctamente',
    'archived_designs' => ':value diseños archivados correctamente',
    'deleted_designs' => ':value diseños borrados correctamente',
    'restored_designs' => ':value diseños restaurados correctamente',
    'restored_credits' => ':value créditos restaurados correctamente',
    'archived_users' => ':value usuarios archivados correctamente',
    'deleted_users' => ':value usuarios borrados correctamente',
    'removed_users' => ':value usuarios eliminados correctamente',
    'restored_users' => ':value usuarios restaurados correctamente',
    'archived_tax_rates' => ':value tipos impositivos archivados correctamente',
    'deleted_tax_rates' => ':value tipos impositivos borrados correctamente',
    'restored_tax_rates' => ':value tipos impositivos restaurados correctamente',
    'archived_company_gateways' => ':value pasarelas archivadas correctamente',
    'deleted_company_gateways' => ':value pasarelas borradas correctamente',
    'restored_company_gateways' => ':value pasarelas restauradas correctamente',
    'archived_groups' => ':value grupos archivados correctamente',
    'deleted_groups' => ':value grupos borrados correctamente',
    'restored_groups' => ':value grupos restaurados correctamente',
    'archived_documents' => ':value documentos archivados correctamente',
    'deleted_documents' => ':value documentos borrados correctamente',
    'restored_documents' => ':value documentos restaurados correctamente',
    'restored_vendors' => ':value proveedores restaurados correctamente',
    'restored_expenses' => ':value gastos restaurados correctamente',
    'restored_tasks' => ':value tareas restauradas correctamente',
    'restored_projects' => ':value proyectos restaurados correctamente',
    'restored_products' => ':value productos restaurados correctamente',
    'restored_clients' => ':value clientes restaurados correctamente',
    'restored_invoices' => ':value facturas restauradas correctamente',
    'restored_payments' => ':value pagos restaurados correctamente',
    'restored_quotes' => ':value presupuestos restaurados correctamente',
    'update_app' => 'Actualizar App',
    'started_import' => 'Importación iniciada correctamente',
    'duplicate_column_mapping' => 'Mapeo de columnas duplicado',
    'uses_inclusive_taxes' => 'Usar Impuestos Inclusivos',
    'is_amount_discount' => 'Es cantidad de descuento',
    'map_to' => 'Mapear a',
    'first_row_as_column_names' => 'Usar primera fila como nombres de columna',
    'no_file_selected' => 'No hay archivos seleccionados',
    'import_type' => 'Importar Tipo',
    'draft_mode' => 'Modo Borrador',
    'draft_mode_help' => 'Previsualizar actualizaciones más rapido pero menos precisas',
    'show_product_discount' => 'Mostrar Descuento de Producto',
    'show_product_discount_help' => 'Mostrar un campo de descuento en la línea de artículo',
    'tax_name3' => 'Nombre de Impuesto 3',
    'debug_mode_is_enabled' => 'Modo de depuración activo',
    'debug_mode_is_enabled_help' => 'Atención: sólo está destinado para usarse en maquinas locales, puede filtrar credenciales. Pulsa para saber más.',
    'running_tasks' => 'Tareas en Proceso',
    'recent_tasks' => 'Tareas Recientes',
    'recent_expenses' => 'Gastos Recientes',
    'upcoming_expenses' => 'Próximos Gastos',
    'search_payment_term' => 'Buscar 1 Término de Pago',
    'search_payment_terms' => 'Buscar :count Términos de Pago',
    'save_and_preview' => 'Guardar y Previsualizar',
    'save_and_email' => 'Guardar y Enviar',
    'converted_balance' => 'Balance Convertido',
    'is_sent' => 'Enviada',
    'document_upload' => 'Subir Documento',
    'document_upload_help' => 'Activar la subida de documentos de los clientes',
    'expense_total' => 'Gasto Total',
    'enter_taxes' => 'Introducir Impuestos',
    'by_rate' => 'Por Tarifa',
    'by_amount' => 'Por Cantidad',
    'enter_amount' => 'Introduce Cantidad',
    'before_taxes' => 'Antes de Impuestos',
    'after_taxes' => 'Después de Impuestos',
    'color' => 'Color',
    'show' => 'Mostrar',
    'empty_columns' => 'Vaciar Columnas',
    'project_name' => 'Nombre de Proyecto',
    'counter_pattern_error' => 'Para usar :client_counter por favor, añade o bien :client_number o :client_id_number para evitar conflictos',
    'this_quarter' => 'Trimestre Actual',
    'to_update_run' => 'Para actualizar ejecute',
    'registration_url' => 'URL de registro',
    'show_product_cost' => 'Mostrar Coste de Producto',
    'complete' => 'Completar',
     'next' => 'Siguiente',
     'next_step' => 'Siguiente paso',
     'notification_credit_sent_subject' => 'El crédito :invoice fue enviado a :client',
     'notification_credit_viewed_subject' => 'El crédito :invoice fue visto por :client',
     'notification_credit_sent' => 'Al cliente :client le fue enviado un email con el Crédito :invoice de :amount.',
     'notification_credit_viewed' => 'El cliente :client vio el Crédito :credit de :amount.',
     'reset_password_text' => 'Introduce tu email para restablecer la contraseña.',
     'password_reset' => 'Restablecer contraseña',
     'account_login_text' => '¡Bienvenido! Un placer volver a verte.',
     'request_cancellation' => 'Requerir cancelación',
     'delete_payment_method' => 'Borrar Medio de Pago',
     'about_to_delete_payment_method' => 'Estás a punto de borrar el medio de pago.',
     'action_cant_be_reversed' => 'La acción no puede ser revertida',
     'profile_updated_successfully' => 'El perfil ha sido actualizado correctamente.',
     'currency_ethiopian_birr' => 'Birr Etíope',
     'client_information_text' => 'Usa una dirección permanente donde puedas recibir emails.',
     'status_id' => 'Estado de Factura',
     'email_already_register' => 'Este email ya está enlazado con una cuenta',
     'locations' => 'Ubicaciones',
     'freq_indefinitely' => 'Indefinidamente',
     'cycles_remaining' => 'Ciclos restantes',
     'i_understand_delete' => 'Lo entiendo, borrar',
     'download_files' => 'Descargar Archivos',
     'download_timeframe' => 'Usa este enlace para descargar tus archivos, el enlace expirará en 1 hora.',
     'new_signup' => 'Nuevo Registro',
     'new_signup_text' => 'Una nueva cuenta ha sido creada por :user - :email - desde la dirección IP: :ip',
     'notification_payment_paid_subject' => 'Un pago ha sido realizado por :client',
     'notification_partial_payment_paid_subject' => 'Un pago parcial ha sido realizado por :client',
     'notification_payment_paid' => 'Un pago de :amount ha sido realizado por el cliente :client de la factura :invoice',
     'notification_partial_payment_paid' => 'Un pago parcial de :amount ha sido realizado por el cliente :client de la factura :invoice',
     'notification_bot' => 'Bot de notificación',
     'invoice_number_placeholder' => 'Factura # :invoice',
     'entity_number_placeholder' => ':entity # :entity_number',
     'email_link_not_working' => 'Si el botón de arriba no te está funcionando, por favor pulsa en el enlace',
     'display_log' => 'Mostrar Registro',
     'send_fail_logs_to_our_server' => 'Reportar errores en tiempo real',
     'setup' => 'Instalación',
     'quick_overview_statistics' => 'Vistazo rápido y estadísticas',
     'update_your_personal_info' => 'Actualiza tu información personal',
     'name_website_logo' => 'Nombre, página web y logo',
     'make_sure_use_full_link' => 'Asegúrate que usas el enalce completo a tu sitio',
     'personal_address' => 'Dirección personal',
     'enter_your_personal_address' => 'Introduce tu dirección personal',
     'enter_your_shipping_address' => 'Introduce tu dirección de envío',
     'list_of_invoices' => 'Listado de facturas',
     'with_selected' => 'Con seleccionados',
     'invoice_still_unpaid' => 'Esta factura está impagada. Pulsa en el botón para completar el pago',
     'list_of_recurring_invoices' => 'Lista de facturas recurrentes',
     'details_of_recurring_invoice' => 'Aquí tienes algunos detalles de la factura recurrente',
     'cancellation' => 'Cancelación',
     'about_cancellation' => 'In case you want to stop the recurring invoice,\n please click the request the cancellation.',
     'cancellation_warning' => '¡Atención! Estas pidiendo la cancelación de este servicio.\n Tu servicio puede ser cancelado sin que recibas ninguna notificación más.',
     'cancellation_pending' => 'Cancelación pendiente, ¡estaremos en contacto!',
     'list_of_payments' => 'Listado de pagos',
     'payment_details' => 'Detalles del pago',
     'list_of_payment_invoices' => 'Lista de facturas afectadas por el pago',
     'list_of_payment_methods' => 'Lista de medios de pago',
     'payment_method_details' => 'Detalles del medio de pago',
     'permanently_remove_payment_method' => 'Eliminar permanentemente este medio de pago.',
     'warning_action_cannot_be_reversed' => '¡Atención! ¡Esta acción no se puede revertir!',
     'confirmation' => 'Confirmación',
     'list_of_quotes' => 'Presupuestos',
     'waiting_for_approval' => 'Esperando aprobación',
     'quote_still_not_approved' => 'Este presupuesto todavía no está aprobado',
     'list_of_credits' => 'Créditos',
     'required_extensions' => 'Extensiones requeridas',
     'php_version' => 'Versión PHP',
     'writable_env_file' => 'Archivo .env escribible',
     'env_not_writable' => 'El archivo .env no es escribible por el usuario actual.',
     'minumum_php_version' => 'Versión PHP mínima',
     'satisfy_requirements' => 'Asegúrate de que se cumplen todos los requisitos.',
     'oops_issues' => 'uppps, ¡algo no está bien!',
     'open_in_new_tab' => 'Abrir en nueva pestaña',
     'complete_your_payment' => 'Completar pago',
     'authorize_for_future_use' => 'Autorizar método de pago para su uso futuro',
     'page' => 'Página',
     'per_page' => 'Por página',
     'of' => 'De',
     'view_credit' => 'Ver Crédito',
     'to_view_entity_password' => 'Para ver la :entity necesitas introducir la contraseña.',
     'showing_x_of' => 'Mostrando :first - :last de :total resultados',
     'no_results' => 'No se encontraron resultados.',
     'payment_failed_subject' => 'Pago fallido del cliente :client',
     'payment_failed_body' => 'Un pago hecho por el cliente :client falló con el mensaje :message',
     'register' => 'Registrar',
     'register_label' => 'Crea tu cuenta en unos segundos',
     'password_confirmation' => 'Confirma tu contraseña',
     'verification' => 'Verificación',
     'complete_your_bank_account_verification' => 'Antes de usar una cuenta bancaria debe ser verificada.',
     'checkout_com' => 'Checkout.com',
     'footer_label' => 'Copyright © :year :company.',
     'credit_card_invalid' => 'El número de tarjeta de crédito no es válido.',
     'month_invalid' => 'El mes introducido no es válido.',
     'year_invalid' => 'El año introducido no es válido.',
     'https_required' => 'Es requerido HTTPS, el formulario fallará',
     'if_you_need_help' => 'Si necesitas ayuda puedes escribir en nuestro',
     'update_password_on_confirm' => 'Después de actualizar la contraseña, tu cuenta será confirmada.',
     'bank_account_not_linked' => 'Para pagar con una cuenta bancaria, primero debes añadirla como método de pago.',
     'application_settings_label' => 'Vamos a guardar información básica acerca de tu Invoice Ninja',
     'recommended_in_production' => 'Altamente recomendado en producción',
     'enable_only_for_development' => 'Activar solo para desarrollo',
     'test_pdf' => 'Probar PDF',
     'checkout_authorize_label' => 'Checkout.com puede ser guardado como método de pago para su uso futuro, una vez que complete su primera transacción. No olvide marcar "Guardar los datos de la tarjeta de crédito" durante el proceso de pago.',
     'sofort_authorize_label' => 'La cuenta bancaria (SOFORT) puede ser guardada como método de pago para su uso futuro, una vez que complete su primera transacción. No olvide marcar la opción "Guardar datos de pago" durante el proceso de pago.',
     'node_status' => 'Estado Node',
     'npm_status' => 'Estado NPM',
     'node_status_not_found' => 'No puedo encontrar Node. ¿Está instalado?',
     'npm_status_not_found' => 'No puedo encontrar NPM. ¿Está instalado?',
     'locked_invoice' => 'Esta factura está bloqueada y no se puede modificar',
     'downloads' => 'Descargas',
     'resource' => 'Recurso',
     'document_details' => 'Detalles del documento',
     'hash' => 'Hash',
     'resources' => 'Recursos',
     'allowed_file_types' => 'Tipos de archivo permitidos:',
     'common_codes' => 'Códigos comunes y sus significados',
     'payment_error_code_20087' => '20087: Datos inválidos (numero CVV erróneo y/o fecha de caducidad)',
     'download_selected' => 'Descarga seleccionada',
     'to_pay_invoices' => 'Para pagar facturas, debes',
     'add_payment_method_first' => 'añadir método de pago',
     'no_items_selected' => 'No hay elementos seleccionados.',
     'payment_due' => 'Fecha de pago',
     'account_balance' => 'Saldo de cuenta',
     'thanks' => 'Gracias',
     'minimum_required_payment' => 'El mínimo pago requerido es :amount',
     'under_payments_disabled' => 'La compañía no permite pagar por debajo.',
     'over_payments_disabled' => 'La compañía no permite sobrepagos.',
     'saved_at' => 'Guardado el :time',
     'credit_payment' => 'Crédito aplicado a la factura :invoice_number',
     'credit_subject' => 'Nuevo crédito :number de :account',
     'credit_message' => 'Para ver tu crédito de :amount, pulsa en el enlace de abajo.',
     'payment_type_Crypto' => 'Criptomoneda',
     'payment_type_Credit' => 'Crédito',
     'store_for_future_use' => 'Guardar para uso futuro',
     'pay_with_credit' => 'Pagar con crédito',
     'payment_method_saving_failed' => 'El método de pago no se puede guardar para uso futuro.',
     'pay_with' => 'Pagar con',
     'n/a' => 'N/D',
     'by_clicking_next_you_accept_terms' => 'Pulsando "Siguiente paso" aceptas los términos.',
     'not_specified' => 'No especificado',
     'before_proceeding_with_payment_warning' => 'Antes de proceder al pago, debes rellenar los siguientes campos',
     'after_completing_go_back_to_previous_page' => 'Después de completar, vuelve a la página anterior.',
     'pay' => 'Pagar',
     'instructions' => 'Instrucciones',
     'notification_invoice_reminder1_sent_subject' => 'Recordatorio 1 de la factura :invoice fue enviado a :client',
     'notification_invoice_reminder2_sent_subject' => 'Recordatorio 2 de la factura :invoice fue enviado a :client',
     'notification_invoice_reminder3_sent_subject' => 'Recordatorio 3 de la factura :invoice fue enviado a :client',
     'notification_invoice_reminder_endless_sent_subject' => 'Recordatorio sin fín de la factura :invoice fue enviado a :client',
     'assigned_user' => 'Usuario Asignado',
     'setup_steps_notice' => 'Para proceder al siguiente paso, asegúrate de que haces un test a cada sección.',
     'setup_phantomjs_note' => 'Nota acerca de Phantom JS. Leer más.',
     'minimum_payment' => 'Pago Mínimo',
     'no_action_provided' => 'No se ha realizado ninguna acción. Si cree que esto es incorrecto, por favor, póngase en contacto con el soporte.',
     'no_payable_invoices_selected' => 'No se ha seleccionado ninguna factura pagable. Asegúrate que no estás intentando pagar un borrador de factura o una factura con un importe pendiente de 0.',
     'required_payment_information' => 'Detalles de pago requeridos',
     'required_payment_information_more' => 'Para completar el pago necesitamos más detalles.',
     'required_client_info_save_label' => 'Guardaremos esto, de esta forma no lo tendrás que introducir la próxima vez.',
     'notification_credit_bounced' => 'No se pudo entregar el Crédito :invoice a :contact. \n :error',
     'notification_credit_bounced_subject' => 'No se pudo entregar Crédito :invoice',
     'save_payment_method_details' => 'Guardar detalles del método de pago',
     'new_card' => 'Nueva tarjeta',
     'new_bank_account' => 'Nueva cuenta bancaria',
     'company_limit_reached' => 'Límite de 10 compañías por cuenta.',
     'credits_applied_validation' => 'El total de crédito aplicado no puede ser superior que el total de facturas',
     'credit_number_taken' => 'El número de crédito ya existe',
     'credit_not_found' => 'Crédito no encontrado',
     'invoices_dont_match_client' => 'Las facturas seleccionadas no son de un sólo cliente',
     'duplicate_credits_submitted' => 'Créditos duplicados enviados.',
     'duplicate_invoices_submitted' => 'Facturas duplicadas enviadas.',
     'credit_with_no_invoice' => 'Tienes que tener indicada una factura al usar crédito en un pago',
     'client_id_required' => 'El Id de cliente es obligatorio',
     'expense_number_taken' => 'El número de gasto ya existe',
     'invoice_number_taken' => 'El número de factura ya existe',
     'payment_id_required' => 'La Id de pago es obligatoria.',
     'unable_to_retrieve_payment' => 'No se pudo obtener el pago especificado',
     'invoice_not_related_to_payment' => 'La factura de Id :invoice no está relacionada con este pago',
     'credit_not_related_to_payment' => 'El crédito de id :credit no está relacionado con este pago',
     'max_refundable_invoice' => 'Se intentó reembolsar más de lo permitido para la id de factura :invoice, la cantidad máxima reembolsable es :amount',
     'refund_without_invoices' => 'Al intentar reembolsar un pago con facturas adjuntas, especifique la/s factura/s válida/s a reembolsar.',
     'refund_without_credits' => 'Al intentar reembolsar un pago con créditos adjuntos, especifique los créditos válidos que deben reembolsarse.',
     'max_refundable_credit' => 'Se intentó reembolsar más de lo permitido para el crédito :credit, el importe máximo reembolsable es :amount',
     'project_client_do_not_match' => 'El cliente del proyecto no coincide con el cliente de la entidad',
     'quote_number_taken' => 'El número de presupuesto ya existe',
     'recurring_invoice_number_taken' => 'El número de factura recurrente :number ya existe',
     'user_not_associated_with_account' => 'El usuario no está asociado con esta cuenta',
     'amounts_do_not_balance' => 'Cantidades no están correctamente balanceadas',
     'insufficient_applied_amount_remaining' => 'Cantidad aplicada insuficiente para cubrir el pago.',
     'insufficient_credit_balance' => 'Saldo insuficiente en el crédito.',
     'one_or_more_invoices_paid' => 'Una o más de estas facturas han sido pagadas',
     'invoice_cannot_be_refunded' => 'La factura # :number no puede ser reintegrada',
     'attempted_refund_failed' => 'Intento de reembolso de :amount, sólo está disponible :refundable_amount para reembolso',
     'user_not_associated_with_this_account' => 'Este usuario no se puede añadir a esta empresa. ¿Quizá ya está registrado en otra cuenta?',
     'migration_completed' => 'Migración completada',
     'migration_completed_description' => 'Tu migración se ha completado, por favor revisa tus datos antes de registrarte.',
     'api_404' => '404 | ¡Nada que ver por aquí!',
     'large_account_update_parameter' => 'No se puede cargar una cuenta grande sin el parámetro updated_at',
     'no_backup_exists' => 'No existe backup para esta actividad',
     'company_user_not_found' => 'Uauario de Compañía no encontrado',
     'no_credits_found' => 'No se encontraron créditos.',
     'action_unavailable' => 'La acción :action requerida no está disponible.',
     'no_documents_found' => 'No se Encontraron Documentos',
     'no_group_settings_found' => 'No se encontraron opciones de grupo',
     'access_denied' => 'Privilegios insuficientes para acceder / modificar este recurso',
     'invoice_cannot_be_marked_paid' => 'La factura no puede marcarse como pagada',
     'invoice_license_or_environment' => 'Licencia inválida, o entorno :environment inválido',
     'route_not_available' => 'Ruta no disponible',
     'invalid_design_object' => 'Objeto de diseño personalizado no válido',
     'quote_not_found' => 'Presupuesto(s) no encontrado(s)',
     'quote_unapprovable' => 'No se puede aprobar este presupuesto porque ha expirado.',
     'scheduler_has_run' => 'El planificador se ha ejecutado',
     'scheduler_has_never_run' => 'El planificador nunca se ha ejecutado',
     'self_update_not_available' => 'La actualización automática no está disponible en este sistema.',
     'user_detached' => 'Usuario desligado de la compañía',
     'create_webhook_failure' => 'Fallo al crear Webhook',
     'payment_message_extended' => 'Gracias por su pago de :amount para :invoice',
     'online_payments_minimum_note' => 'Nota: Los pagos online están soportados si la cantidad es mayor que $1 o moneda equivalente.',
     'payment_token_not_found' => 'No se ha encontrado el token de pago, inténtelo de nuevo. Si el problema persiste, inténtelo con otro método de pago',
     'vendor_address1' => 'Calle de Proveedor',
     'vendor_address2' => 'Bloq/Pta del Proveedor',
     'partially_unapplied' => 'Parcialmente sin aplicar',
     'select_a_gmail_user' => 'Por favor, selecciona un usuario autenticado con Gmail',
     'list_long_press' => 'Pulsación Larga en Lista',
     'show_actions' => 'Mostrar Acciones',
     'start_multiselect' => 'Iniciar Multiselección',
     'email_sent_to_confirm_email' => 'Un email ha sido enviado para confirmar la dirección de correo',
     'converted_paid_to_date' => 'Pagado a la fecha convertido',
     'converted_credit_balance' => 'Saldo de crédito convertido',
     'converted_total' => 'Total convertido',
     'reply_to_name' => 'Nombre de Responder a',
     'payment_status_-2' => 'Sin aplicar parcialmente',
     'color_theme' => 'Color del Tema',
     'start_migration' => 'Empezar Migración',
     'recurring_cancellation_request' => 'Solicitud de cancelación de factura recurrente de :contact',
     'recurring_cancellation_request_body' => ':contact del cliente :client ha solicitado cancelar la Factura Recurrente :invoice',
     'hello' => 'Hola',
     'group_documents' => 'Documentos de grupo',
     'quote_approval_confirmation_label' => '¿Estás seguro que quieres aprobar este presupuesto?',
     'migration_select_company_label' => 'Selecciona compañías a migrar',
     'force_migration' => 'Forzar migración',
     'require_password_with_social_login' => 'Requerir contraseña con Social Login',
     'stay_logged_in' => 'Permanecer Conectado',
     'session_about_to_expire' => 'Atención: Tu sesión está a punto de expirar',
     'count_hours' => ':count Horas',
     'count_day' => '1 Día',
     'count_days' => ':count Días',
     'web_session_timeout' => 'Tiempo de finalización de la sesión Web',
     'security_settings' => 'Opciones de Seguridad',
     'resend_email' => 'Reenviar Email',
     'confirm_your_email_address' => 'Por favor, confirma tu dirección de email',
     'freshbooks' => 'FreshBooks',
     'invoice2go' => 'Invoice2go',
     'invoicely' => 'Invoicely',
     'waveaccounting' => 'Wave Accounting',
     'zoho' => 'Zoho',
     'accounting' => 'Contabilidad',
     'required_files_missing' => 'Por favor facilita todos los CSVs.',
     'migration_auth_label' => 'Let\'s continue by authenticating. (These credentials should be identical across systems)',
     'api_secret' => 'API secret',
     'migration_api_secret_notice' => 'Puedes encontrar API_SECRET en el archivo .env o en Invoice Ninja v5. Si no está presente, deja el campo vacío.',
     'billing_coupon_notice' => 'El descuento será aplicado en la revisión de pago.',
     'use_last_email' => 'Usar último email',
     'activate_company' => 'Activar Compañía',
     'activate_company_help' => 'Activar emails, facturas recurrentes y notificaciones',
     'an_error_occurred_try_again' => 'Ha ocurrido un error, por favor inténtalo de nuevo',
     'please_first_set_a_password' => 'Por favor, primero establezca una contraseña',
     'changing_phone_disables_two_factor' => 'Atención: Cambiar el número de teléfono desactivará autenticación en 2 pasos',
     'help_translate' => 'Ayuda a Traducir',
     'please_select_a_country' => 'Por favor, indica un país',
     'disabled_two_factor' => 'Autenticación en 2 pasos desactivada correctamente',
     'connected_google' => 'Cuenta conectada correctamente',
     'disconnected_google' => 'Cuenta desconectada correctamente',
     'delivered' => 'Entregado',
     'spam' => 'Spam',
     'view_docs' => 'Ver Documentos',
     'enter_phone_to_enable_two_factor' => 'Por favor, facilita un número de teléfono para activar la autenticación en dos pasos',
     'send_sms' => 'Enviar SMS',
     'sms_code' => 'Código SMS',
     'connect_google' => 'Conectar Google',
     'disconnect_google' => 'Desconectar Google',
     'disable_two_factor' => 'Desactivar Autenticación en 2 Pasos',
     'invoice_task_datelog' => 'Fecha de Tarea en Factura',
     'invoice_task_datelog_help' => 'Añadir detalles de fecha a los artículos de línea de la factura',
     'promo_code' => 'Código promocional',
     'recurring_invoice_issued_to' => 'Factura recurrente emitida a',
     'amount_greater_than_balance_v5' => 'La cantidad es superior al total de factura. No puedes sobrepagar una factura.',
     'move_top' => 'Move Top',
     'move_up' => 'Move Up',
     'move_down' => 'Move Down',
     'move_bottom' => 'Move Bottom',
     'body_variable_missing' => 'Error: the custom email must include a :body variable',
     'add_body_variable_message' => 'Make sure to include a :body variable',
     'view_date_formats' => 'View Date Formats',
     'is_viewed' => 'Is Viewed',
     'letter' => 'Letter',
     'legal' => 'Legal',
     'page_layout' => 'Page Layout',
     'portrait' => 'Portrait',
     'landscape' => 'Landscape',
     'upgrade_to_paid_plan' => 'Upgrade to a paid plan to enable the advanded settings',
     'invoice_payment_terms' => 'Invoice Payment Terms',
     'quote_valid_until' => 'Quote Valid Until',
     'no_headers' => 'No Headers',
     'add_header' => 'Add Header',
     'remove_header' => 'Remove Header',
     'return_url' => 'Return URL',
     'rest_method' => 'REST Method',
     'header_key' => 'Header Key',
     'header_value' => 'Header Value',
     'recurring_products' => 'Recurring Products',
     'promo_discount' => 'Promo Discount',
     'allow_cancellation' => 'Allow Cancellation',
     'per_seat_enabled' => 'Per Seat Enabled',
     'max_seats_limit' => 'Max Seats Limit',
     'trial_enabled' => 'Trial Enabled',
     'trial_duration' => 'Trial Duration',
     'allow_query_overrides' => 'Allow Query Overrides',
     'allow_plan_changes' => 'Allow Plan Changes',
     'plan_map' => 'Plan Map',
     'refund_period' => 'Refund Period',
     'webhook_configuration' => 'Webhook Configuration',
     'purchase_page' => 'Purchase Page',
     'email_bounced' => 'Email Bounced',
     'email_spam_complaint' => 'Spam Complaint',
     'email_delivery' => 'Email Delivery',
     'webhook_response' => 'Webhook Response',
     'pdf_response' => 'PDF Response',
     'authentication_failure' => 'Authentication Failure',
     'pdf_failed' => 'PDF Failed',
     'pdf_success' => 'PDF Success',
     'modified' => 'Modified',
     'subscription' => 'Subscripción',
     'new_subscription' => 'Nueva Subscripción',
     'deleted_subscription' => 'Subscripción borrada correctamente',
     'removed_subscription' => 'Subscripción eliminada correctamente',
     'restored_subscription' => 'Subscripción restaurada correctamente',
     'search_subscription' => 'Buscar 1 Subscripción',
     'search_subscriptions' => 'Buscar :count Subscripciones',
     'subdomain_is_not_available' => 'El subdominio no está disponible',
     'connect_gmail' => 'Conectar Gmail',
     'disconnect_gmail' => 'Desconectar Gmail',
     'connected_gmail' => 'Gmail conectado correctamente',
     'disconnected_gmail' => 'Gmail desconectado correctamente',
     'update_fail_help' => 'Cámbios en el código pueden estar bloqueando la actualización, puedes ejecutar este comando para descartar los cambios:',
     'client_id_number' => 'Número ID Cliente',
     'count_minutes' => ':count Minutos',
     'password_timeout' => 'Caducidad de Contraseña',
     'shared_invoice_credit_counter' => 'Contador de Factura/Crédito Compartido',
    'activity_80' => ':user created subscription :subscription',
    'activity_81' => ':user updated subscription :subscription',
    'activity_82' => ':user archived subscription :subscription',
    'activity_83' => ':user deleted subscription :subscription',
    'activity_84' => ':user restored subscription :subscription',

    'amount_greater_than_balance_v5' => 'La cantidad es superior al total de factura. No puedes sobrepagar una factura.',
    'click_to_continue' => 'Pulsa para continuar',

    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'migration_create_account_notice' => 'Please ensure you have created an account on the new platform first <a href="https://invoicing.co">here</a> , please ensure that the credentials are <b>identical</b> to your v4 credentials. Once the account has been created, you can start the migration process here.',
    'auth' => 'Authentication',
    'companies' => 'Select companies for migration',
    'activity_100' => ':user created recurring invoice :recurring_invoice',
    'activity_101' => ':user updated recurring invoice :recurring_invoice',
    'activity_102' => ':user archived recurring invoice :recurring_invoice',
    'activity_103' => ':user deleted recurring invoice :recurring_invoice',
    'activity_104' => ':user restored recurring invoice :recurring_invoice',

    'import_settings' => 'Import Settings',
    'json_file_missing' => 'Please provide the JSON file',
    'json_option_missing' => 'Please select to import the settings and/or data',
    'json' => 'JSON',
    'no_payment_types_enabled' => 'No payment types enabled',
    'wait_for_data' => 'Please wait for the data to finish loading',
    'net_total' => 'Net Total',
    'has_taxes' => 'Has Taxes',
    'import_customers' => 'Import Customers',
    'imported_customers' => 'Successfully started importing customers',
    'login_success' => 'Successful Login',
    'login_failure' => 'Failed Login',
    'exported_data' => 'Once the file is ready you"ll receive an email with a download link',
    'include_deleted_clients' => 'Include Deleted Clients',
    'include_deleted_clients_help' => 'Load records belonging to deleted clients',
    'step_1_sign_in' => 'Step 1: Sign In',
    'step_2_authorize' => 'Step 2: Authorize',
    'account_id' => 'Account ID',
    'migration_not_yet_completed' => 'The migration has not yet completed',
    'wizard_warning' => 'If you are migrating from the legacy version stop here and begin the migration. Once the migration completes click "Refesh" and use the dropdown in the top left corner to switch companies.',
    'show_task_end_date' => 'Show Task End Date',
    'show_task_end_date_help' => 'Enable specifying the task end date',
    'gateway_setup' => 'Gateway Setup',
    'preview_sidebar' => 'Preview Sidebar',
    'years_data_shown' => 'Years Data Shown',
    'ended_all_sessions' => 'Successfully ended all sessions',
    'end_all_sessions' => 'End All Sessions',
    'count_session' => '1 Session',
    'count_sessions' => ':count Sessions',
    'invoice_created' => 'Invoice Created',
    'quote_created' => 'Quote Created',
    'credit_created' => 'Credit Created',
    'enterprise' => 'Enterprise',
    'invoice_item' => 'Invoice Item',
    'quote_item' => 'Quote Item',
    'order' => 'Order',
    'search_kanban' => 'Search Kanban',
    'search_kanbans' => 'Search Kanban',
    'owner_upgrade_to_paid_plan' => 'The account owner can upgrade to a paid plan to enable the advanced advanced settings',
    'html_mode' => 'HTML Mode',
    'html_mode_help' => 'Preview updates faster but is less accurate',

);

return $LANG;

?>
